(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1205623,      36397]
NotebookOptionsPosition[   1175411,      35723]
NotebookOutlinePosition[   1176073,      35746]
CellTagsIndexPosition[   1176030,      35743]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Properties of Irreducible Representations", "Title",ExpressionUUID->"94300c41-74ea-4fba-8fb6-8204badbfe7c"],

Cell[TextData[{
 "following R. Slansky, ",
 StyleBox["\"Group Theory for Unified Model Building\"",
  FontSlant->"Italic"],
 ", Phys.Rept. ",
 StyleBox["79",
  FontWeight->"Bold"],
 " (1981) 1 - 128"
}], "Subsubtitle",ExpressionUUID->"040792fd-e014-42f8-8e37-c6686aa3648f"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 CellDingbat->None,
 CellGroupingRules->{
  GroupTogetherGrouping, 
   10000.},ExpressionUUID->"38993cd0-07e4-4c04-b156-2b16e24c62c5"],

Cell[BoxData[
 RowBox[{"<<", "LieART`Tables`"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->
  True,ExpressionUUID->"0adc309c-0de1-4386-af43-7fb77264592b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$WriteToLaTeXFile", "=", "False"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "$IrrepPropertiesLaTeXFile", "=", "\"\<IrrepPropertiesTables.tex\>\""}], 
  ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"bd427ca5-7eef-4bc0-a1e6-9c95c75f5ccb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"FileExistsQ", "[", "$IrrepPropertiesLaTeXFile", "]"}], ",", 
    RowBox[{"DeleteFile", "[", "$IrrepPropertiesLaTeXFile", "]"}]}], "]"}], 
  ";"}]], "Input",ExpressionUUID->"02af092e-493c-4608-9d59-bfc66a8e5d40"]
}, Closed]],

Cell[CellGroupData[{

Cell["SU(N)", "Section",ExpressionUUID->"092dd081-03aa-46f7-b6c3-972ccac71954"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU2", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Duality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "47"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "46"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7801612142575808`*^9, 3.7801612208978004`*^9}, {
  3.783522670901204*^9, 
  3.783522675372271*^9}},ExpressionUUID->"9d30ae8e-05c6-44cc-a28a-\
c851e4adfbd4"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "46"}],
   SequenceForm["Number of irreps: ", 46],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615342782397071*^9, 
  3.78352580741101*^9},ExpressionUUID->"8938dacf-a2de-441b-9443-3c50b6aac814"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.0\"\>",
      0.0191484,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.0191484, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615342782397071*^9, 
  3.7835258074140015`*^9},ExpressionUUID->"f5259f61-4dd2-444f-b5c4-\
132c19b0c412"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "10", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SU(2)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Duality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "0"},
         {
          FormBox["\<\"(3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "1"},
         {
          FormBox["\<\"(4)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "0"},
         {
          FormBox["\<\"(5)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "1"},
         {
          FormBox["\<\"(6)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", "0"},
         {
          FormBox["\<\"(7)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "84", "1"},
         {
          FormBox["\<\"(8)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "0"},
         {
          FormBox["\<\"(9)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "1"},
         {
          FormBox["\<\"(10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "0"},
         {
          FormBox["\<\"(11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286", "1"},
         {
          FormBox["\<\"(12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", "0"},
         {
          FormBox["\<\"(13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "455", "1"},
         {
          FormBox["\<\"(14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "560", "0"},
         {
          FormBox["\<\"(15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "680", "1"},
         {
          FormBox["\<\"(16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "816", "0"},
         {
          FormBox["\<\"(17)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "969", "1"},
         {
          FormBox["\<\"(18)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1140", "0"},
         {
          FormBox["\<\"(19)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1330", "1"},
         {
          FormBox["\<\"(20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "0"},
         {
          FormBox["\<\"(21)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1771", "1"},
         {
          FormBox["\<\"(22)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2024", "0"},
         {
          FormBox["\<\"(23)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2300", "1"},
         {
          FormBox["\<\"(24)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"25", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2600", "0"},
         {
          FormBox["\<\"(25)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2925", "1"},
         {
          FormBox["\<\"(26)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3276", "0"},
         {
          FormBox["\<\"(27)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3654", "1"},
         {
          FormBox["\<\"(28)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4060", "0"},
         {
          FormBox["\<\"(29)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4495", "1"},
         {
          FormBox["\<\"(30)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4960", "0"},
         {
          FormBox["\<\"(31)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5456", "1"},
         {
          FormBox["\<\"(32)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5984", "0"},
         {
          FormBox["\<\"(33)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6545", "1"},
         {
          FormBox["\<\"(34)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7140", "0"},
         {
          FormBox["\<\"(35)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7770", "1"},
         {
          FormBox["\<\"(36)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8436", "0"},
         {
          FormBox["\<\"(37)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"38", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9139", "1"},
         {
          FormBox["\<\"(38)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"39", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9880", "0"},
         {
          FormBox["\<\"(39)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10660", "1"},
         {
          FormBox["\<\"(40)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"41", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11480", "0"},
         {
          FormBox["\<\"(41)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12341", "1"},
         {
          FormBox["\<\"(42)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13244", "0"},
         {
          FormBox["\<\"(43)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14190", "1"},
         {
          FormBox["\<\"(44)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15180", "0"},
         {
          FormBox["\<\"(45)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16215", "1"},
         {
          FormBox["\<\"(46)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"47", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17296", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.615342782490079*^9, 
  3.7835258075357084`*^9},ExpressionUUID->"c9a642ba-24e6-4455-8dbb-\
e00e4124677a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU3", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SU2", ",", "U1"}], "]"}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Triality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "520"}], ",", " ", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "31"}]}], "]"}]], "Input",ExpressionUU\
ID->"0a1f6f45-e42b-40e7-a244-fd5296c91eb4"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "93"}],
   SequenceForm["Number of irreps: ", 93],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153427826845627`*^9},ExpressionUUID->"4ed6fc6e-e71b-476a-a08a-\
43b5843e714a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"25.3\"\>",
      25.25567500000000009663381206337362527847`7.422958893526836,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    25.25567500000000009663381206337362527847`7.422958893526836, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615342807763493*^9},ExpressionUUID->"ed9010d4-23e5-4d71-9a48-\
a5069cd1a25b"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(3)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Triality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1"},
         {
          FormBox["\<\"(20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5", "2", "1"},
         {
          FormBox["\<\"(11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(30)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", "0", "1"},
         {
          FormBox["\<\"(21)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "1", "1"},
         {
          FormBox["\<\"(40)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "1", "1"},
         {
          FormBox["\<\"(05)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "70", "1", "1"},
         {
          FormBox["\<\"(13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50", "1", "1"},
         {
          FormBox["\<\"(22)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(60)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "0", "1"},
         {
          FormBox["\<\"(41)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "0", "1"},
         {
          FormBox["\<\"(70)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "1", "1"},
         {
          FormBox["\<\"(32)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "119", "1", "1"},
         {
          FormBox["\<\"(08)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "1", "1"},
         {
          FormBox["\<\"(51)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "196", "1", "1"},
         {
          FormBox["\<\"(90)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", "0", "1"},
         {
          FormBox["\<\"(24)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"60", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "230", "1", "1"},
         {
          FormBox["\<\"(16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"63", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "336", "1", "1"},
         {
          FormBox["\<\"(33)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "240", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(10, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "715", "1", "1"},
         {
          FormBox["\<\"(0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1001", "1", "1"},
         {
          FormBox["\<\"(71)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", "0", "1"},
         {
          FormBox["\<\"(52)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "405", "0", "1"},
         {
          FormBox["\<\"(43)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"90", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "435", "1", "1"},
         {
          FormBox["\<\"(12, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"91", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1365", "0", "1"},
         {
          FormBox["\<\"(81)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"99", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "825", "1", "1"},
         {
          FormBox["\<\"(62)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "665", "1", "1"},
         {
          FormBox["\<\"(13, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1820", "1", "1"},
         {
          FormBox["\<\"(35)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "730", "1", "1"},
         {
          FormBox["\<\"(19)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1210", "1", "1"},
         {
          FormBox["\<\"(0, 14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2380", "1", "1"},
         {
          FormBox["\<\"(44)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"125", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "750", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(27)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"132", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1034", "1", "1"},
         {
          FormBox["\<\"(15, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3060", "0", "1"},
         {
          FormBox["\<\"(10, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"143", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "0", "1"},
         {
          FormBox["\<\"(16, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"153", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3876", "1", "1"},
         {
          FormBox["\<\"(63)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"154", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1155", "0", "1"},
         {
          FormBox["\<\"(82)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"162", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1539", "0", "1"},
         {
          FormBox["\<\"(54)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1210", "1", "1"},
         {
          FormBox["\<\"(11, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2366", "1", "1"},
         {
          FormBox["\<\"(0, 17)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"171", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4845", "1", "1"},
         {
          FormBox["\<\"(18, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"190", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5985", "0", "1"},
         {
          FormBox["\<\"(73)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1744", "1", "1"},
         {
          FormBox["\<\"(92)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"195", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2210", "1", "1"},
         {
          FormBox["\<\"(1, 12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"195", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3185", "1", "1"},
         {
          FormBox["\<\"(46)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1855", "1", "1"},
         {
          FormBox["\<\"(19, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7315", "1", "1"},
         {
          FormBox["\<\"(55)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1890", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(13, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4200", "0", "1"},
         {
          FormBox["\<\"(2, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "1", "1"},
         {
          FormBox["\<\"(0, 20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8855", "1", "1"},
         {
          FormBox["\<\"(38)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"234", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2535", "1", "1"},
         {
          FormBox["\<\"(21, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"253", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10626", "0", "1"},
         {
          FormBox["\<\"(14, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"255", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5440", "1", "1"},
         {
          FormBox["\<\"(74)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2730", "0", "1"},
         {
          FormBox["\<\"(11, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"270", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4185", "0", "1"},
         {
          FormBox["\<\"(65)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"273", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2821", "1", "1"},
         {
          FormBox["\<\"(22, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"276", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12650", "1", "1"},
         {
          FormBox["\<\"(93)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3570", "0", "1"},
         {
          FormBox["\<\"(1, 15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"288", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6936", "1", "1"},
         {
          FormBox["\<\"(0, 23)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14950", "1", "1"},
         {
          FormBox["\<\"(12, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5564", "1", "1"},
         {
          FormBox["\<\"(84)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3885", "1", "1"},
         {
          FormBox["\<\"(16, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"323", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8721", "0", "1"},
         {
          FormBox["\<\"(24, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"325", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17550", "0", "1"},
         {
          FormBox["\<\"(10, 3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4895", "1", "1"},
         {
          FormBox["\<\"(57)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4060", "1", "1"},
         {
          FormBox["\<\"(66)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"343", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4116", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(25, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"351", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20475", "1", "1"},
         {
          FormBox["\<\"(2, 13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"357", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7259", "1", "1"},
         {
          FormBox["\<\"(17, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10830", "1", "1"},
         {
          FormBox["\<\"(49)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"375", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5375", "1", "1"},
         {
          FormBox["\<\"(0, 26)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23751", "1", "1"},
         {
          FormBox["\<\"(3, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6560", "1", "1"},
         {
          FormBox["\<\"(1, 18)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"399", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13300", "1", "1"},
         {
          FormBox["\<\"(85)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5670", "0", "1"},
         {
          FormBox["\<\"(14, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9315", "0", "1"},
         {
          FormBox["\<\"(27, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"406", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27405", "0", "1"},
         {
          FormBox["\<\"(76)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5810", "1", "1"},
         {
          FormBox["\<\"(28, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"435", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31465", "1", "1"},
         {
          FormBox["\<\"(10, 4)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7260", "0", "1"},
         {
          FormBox["\<\"(19, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16170", "0", "1"},
         {
          FormBox["\<\"(12, 3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"442", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8619", "0", "1"},
         {
          FormBox["\<\"(15, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11780", "1", "1"},
         {
          FormBox["\<\"(0, 29)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"465", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35960", "1", "1"},
         {
          FormBox["\<\"(95)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7720", "1", "1"},
         {
          FormBox["\<\"(20, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"483", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19481", "1", "1"},
         {
          FormBox["\<\"(30, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "40920", "0", "1"},
         {
          FormBox["\<\"(68)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7980", "1", "1"},
         {
          FormBox["\<\"(13, 3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11130", "1", "1"},
         {
          FormBox["\<\"(11, 4)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"510", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9605", "1", "1"},
         {
          FormBox["\<\"(2, 16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"510", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14705", "1", "1"},
         {
          FormBox["\<\"(77)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8064", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlet.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615342807863873*^9},ExpressionUUID->"9c1538b1-edfc-44a5-af1c-\
05859051816c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU4", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SU3", ",", "U1"}], "]"}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Quadrality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1200"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "17"}]}], "]"}]], "Input",ExpressionUU\
ID->"42fdf57f-d60c-4c8a-aa3d-365e135daef6"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "94"}],
   SequenceForm["Number of irreps: ", 94],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615342808891501*^9},ExpressionUUID->"cf08f78e-78bc-4700-a340-\
746bc7164a0f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"45.7\"\>",
      45.7425039999999967221810948103666305542`7.680919848006352,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    45.7425039999999967221810948103666305542`7.680919848006352, {3, 1}], "s"],
   
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615342854063599*^9},ExpressionUUID->"8ac7fc21-3ffc-48e7-bb30-\
117437559241"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(4)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Quadrality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1"},
         {
          FormBox["\<\"(010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2", "2", "0"},
         {
          FormBox["\<\"(200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "2", "1"},
         {
          FormBox["\<\"(101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13", "1", "0"},
         {
          FormBox["\<\"(020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "0", "0"},
         {
          FormBox["\<\"(003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "1", "1"},
         {
          FormBox["\<\"(400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", "0", "1"},
         {
          FormBox["\<\"(201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33", "1", "1"},
         {
          FormBox["\<\"(210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "48", "0", "0"},
         {
          FormBox["\<\"(030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "70", "2", "0"},
         {
          FormBox["\<\"(500)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "1", "1"},
         {
          FormBox["\<\"(120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"60", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71", "1", "0"},
         {
          FormBox["\<\"(111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64", "2", "0"},
         {
          FormBox["\<\"(301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98", "2", "1"},
         {
          FormBox["\<\"(202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "112", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(310)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "133", "1", "0"},
         {
          FormBox["\<\"(600)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", "2", "1"},
         {
          FormBox["\<\"(040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "224", "0", "0"},
         {
          FormBox["\<\"(104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "238", "1", "1"},
         {
          FormBox["\<\"(007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "1", "1"},
         {
          FormBox["\<\"(220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "2", "0"},
         {
          FormBox["\<\"(112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "203", "1", "0"},
         {
          FormBox["\<\"(031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "259", "1", "0"},
         {
          FormBox["\<\"(410)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "308", "2", "0"},
         {
          FormBox["\<\"(302)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "296", "1", "1"},
         {
          FormBox["\<\"(800)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0", "1"},
         {
          FormBox["\<\"(121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "280", "0", "0"},
         {
          FormBox["\<\"(501)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "0", "1"},
         {
          FormBox["\<\"(050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"196", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "588", "2", "0"},
         {
          FormBox["\<\"(015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "630", "1", "0"},
         {
          FormBox["\<\"(900)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", "1", "1"},
         {
          FormBox["\<\"(023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "1", "0"},
         {
          FormBox["\<\"(311)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", "0", "0"},
         {
          FormBox["\<\"(402)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"270", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "666", "2", "1"},
         {
          FormBox["\<\"(230)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", "0", "0"},
         {
          FormBox["\<\"(140)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "742", "1", "0"},
         {
          FormBox["\<\"(601)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "966", "1", "1"},
         {
          FormBox["\<\"(10, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "2", "1"},
         {
          FormBox["\<\"(212)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "580", "2", "0"},
         {
          FormBox["\<\"(303)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "720", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(610)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1176", "0", "0"},
         {
          FormBox["\<\"(060)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1344", "0", "0"},
         {
          FormBox["\<\"(221)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "762", "1", "0"},
         {
          FormBox["\<\"(420)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1056", "0", "0"},
         {
          FormBox["\<\"(0, 0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "1", "1"},
         {
          FormBox["\<\"(131)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "896", "2", "0"},
         {
          FormBox["\<\"(701)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"396", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "2", "1"},
         {
          FormBox["\<\"(411)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1113", "1", "0"},
         {
          FormBox["\<\"(205)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1337", "1", "1"},
         {
          FormBox["\<\"(710)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2046", "1", "0"},
         {
          FormBox["\<\"(12, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4368", "0", "1"},
         {
          FormBox["\<\"(330)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1464", "1", "0"},
         {
          FormBox["\<\"(403)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1525", "1", "1"},
         {
          FormBox["\<\"(051)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1806", "1", "0"},
         {
          FormBox["\<\"(213)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1359", "1", "0"},
         {
          FormBox["\<\"(240)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1764", "2", "0"},
         {
          FormBox["\<\"(520)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2007", "1", "0"},
         {
          FormBox["\<\"(070)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2772", "2", "0"},
         {
          FormBox["\<\"(108)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2871", "1", "1"},
         {
          FormBox["\<\"(13, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6188", "1", "1"},
         {
          FormBox["\<\"(810)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3366", "2", "0"},
         {
          FormBox["\<\"(602)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"616", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2464", "0", "1"},
         {
          FormBox["\<\"(321)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"630", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1722", "2", "0"},
         {
          FormBox["\<\"(511)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2176", "2", "0"},
         {
          FormBox["\<\"(14, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8568", "2", "1"},
         {
          FormBox["\<\"(901)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4576", "0", "1"},
         {
          FormBox["\<\"(222)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1944", "0", "0"},
         {
          FormBox["\<\"(141)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"735", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2352", "0", "0"},
         {
          FormBox["\<\"(430)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2850", "2", "0"},
         {
          FormBox["\<\"(132)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2205", "1", "0"},
         {
          FormBox["\<\"(503)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"770", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2926", "2", "1"},
         {
          FormBox["\<\"(620)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"770", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3542", "2", "0"},
         {
          FormBox["\<\"(019)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5291", "1", "0"},
         {
          FormBox["\<\"(0, 0, 15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"816", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11628", "1", "1"},
         {
          FormBox["\<\"(404)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(080)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5280", "0", "0"},
         {
          FormBox["\<\"(160)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3906", "1", "0"},
         {
          FormBox["\<\"(702)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"864", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4248", "1", "1"},
         {
          FormBox["\<\"(412)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2800", "0", "0"},
         {
          FormBox["\<\"(043)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"900", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3585", "1", "0"},
         {
          FormBox["\<\"(116)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3927", "1", "0"},
         {
          FormBox["\<\"(10, 0, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7007", "1", "1"},
         {
          FormBox["\<\"(250)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4032", "0", "0"},
         {
          FormBox["\<\"(313)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3008", "2", "0"},
         {
          FormBox["\<\"(16, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"969", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15504", "0", "1"},
         {
          FormBox["\<\"(124)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3450", "1", "0"},
         {
          FormBox["\<\"(10, 1, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8008", "0", "0"},
         {
          FormBox["\<\"(027)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5896", "1", "0"},
         {
          FormBox["\<\"(035)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5115", "1", "0"},
         {
          FormBox["\<\"(306)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5208", "1", "1"},
         {
          FormBox["\<\"(17, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20349", "1", "1"},
         {
          FormBox["\<\"(802)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1170", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6942", "2", "1"},
         {
          FormBox["\<\"(11, 0, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1170", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10374", "2", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlet.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615342854166127*^9},ExpressionUUID->"0bcd0012-9a52-45b3-878b-\
5e7514296385"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU5", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU2", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Quintality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "3000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "13"}]}], "]"}]], "Input",ExpressionUU\
ID->"5aa0deb0-17ff-46c8-94a3-6429e470f61d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "95"}],
   SequenceForm["Number of irreps: ", 95],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615342857947978*^9},ExpressionUUID->"4a77d756-475a-4b72-b306-\
8dce67f988db"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"109.0\"\>",
      108.80614599999999825286067789420485496521`8.057253340797107,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    108.80614599999999825286067789420485496521`8.057253340797107, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153429630849543`*^9},ExpressionUUID->"511e7ce8-b3bf-4ec4-a664-\
f79dbd2c24f5"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(5)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Quintality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3", "2", "0", "1"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7", "2", "1", "0"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "2", "1", "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22", "2", "0", "0"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", "1", "0", "0"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "1", "0", "1"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "49", "1", "1", "0"},
         {
          FormBox["\<\"(0004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "84", "1", "1", "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"75", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "91", "1", "0", "0"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "0", "0", "0"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "0", "1", "0"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "168", "2", "1", "0"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", "2", "0", "1"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "175", "0", "0", "0"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "1", "0", "1"},
         {
          FormBox["\<\"(2002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "200", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "203", "2", "0", "0"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "1", "1", "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "280", "0", "0", "0"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "266", "1", "0", "0"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "336", "1", "0", "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "357", "2", "0", "1"},
         {
          FormBox["\<\"(1004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "2", "1", "0"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "924", "2", "1", "0"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "574", "1", "0", "0"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "714", "1", "0", "0"},
         {
          FormBox["\<\"(1012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "510", "2", "0", "0"},
         {
          FormBox["\<\"(3002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "615", "1", "1", "0"},
         {
          FormBox["\<\"(1102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "536", "1", "0", "0"},
         {
          FormBox["\<\"(0040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "882", "2", "0", "1"},
         {
          FormBox["\<\"(0008)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "2", "1", "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "882", "2", "0", "0"},
         {
          FormBox["\<\"(0202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "728", "2", "0", "0"},
         {
          FormBox["\<\"(1300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "868", "2", "0", "0"},
         {
          FormBox["\<\"(1005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1092", "1", "1", "0"},
         {
          FormBox["\<\"(2110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "910", "2", "0", "0"},
         {
          FormBox["\<\"(1030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1050", "0", "0", "0"},
         {
          FormBox["\<\"(0009)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "1", "1", "0"},
         {
          FormBox["\<\"(1021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "924", "1", "0", "1"},
         {
          FormBox["\<\"(5100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1596", "2", "0", "0"},
         {
          FormBox["\<\"(3200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1512", "2", "0", "0"},
         {
          FormBox["\<\"(4002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1575", "2", "1", "0"},
         {
          FormBox["\<\"(6001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2310", "0", "1", "0"},
         {
          FormBox["\<\"(1013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1449", "1", "0", "0"},
         {
          FormBox["\<\"(0105)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2016", "2", "0", "0"},
         {
          FormBox["\<\"(0130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1666", "1", "0", "1"},
         {
          FormBox["\<\"(3003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1750", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(10, 0, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5005", "0", "1", "0"},
         {
          FormBox["\<\"(1111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1280", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "2", "0", "0"},
         {
          FormBox["\<\"(3011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1575", "0", "0", "0"},
         {
          FormBox["\<\"(0211)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1624", "1", "0", "0"},
         {
          FormBox["\<\"(0016)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1155", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3234", "2", "0", "0"},
         {
          FormBox["\<\"(0220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1960", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0500)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2940", "0", "0", "1"},
         {
          FormBox["\<\"(0203)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2040", "1", "0", "0"},
         {
          FormBox["\<\"(2102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1215", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", "2", "0", "1"},
         {
          FormBox["\<\"(0032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2478", "2", "0", "0"},
         {
          FormBox["\<\"(11, 0, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1365", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8008", "1", "1", "0"},
         {
          FormBox["\<\"(0113)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2472", "2", "0", "0"},
         {
          FormBox["\<\"(7001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4488", "1", "1", "0"},
         {
          FormBox["\<\"(0041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1470", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3234", "1", "0", "0"},
         {
          FormBox["\<\"(0024)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3450", "2", "0", "0"},
         {
          FormBox["\<\"(2005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3542", "2", "1", "0"},
         {
          FormBox["\<\"(0106)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4158", "1", "0", "0"},
         {
          FormBox["\<\"(2201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1701", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2835", "0", "0", "0"},
         {
          FormBox["\<\"(4101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3500", "0", "0", "0"},
         {
          FormBox["\<\"(0017)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6072", "1", "0", "0"},
         {
          FormBox["\<\"(2030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3360", "1", "0", "0"},
         {
          FormBox["\<\"(12, 0, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1820", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12376", "2", "1", "0"},
         {
          FormBox["\<\"(2021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1890", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3087", "2", "0", "0"},
         {
          FormBox["\<\"(0401)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1890", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4032", "2", "0", "0"},
         {
          FormBox["\<\"(4003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4235", "1", "1", "0"},
         {
          FormBox["\<\"(4011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3900", "1", "0", "0"},
         {
          FormBox["\<\"(8001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2145", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8151", "2", "1", "0"},
         {
          FormBox["\<\"(1301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2205", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4116", "1", "0", "1"},
         {
          FormBox["\<\"(4020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2250", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4875", "0", "0", "0"},
         {
          FormBox["\<\"(7010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7920", "0", "0", "0"},
         {
          FormBox["\<\"(0, 0, 0, 13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18564", "2", "1", "0"},
         {
          FormBox["\<\"(0033)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5880", "1", "0", "0"},
         {
          FormBox["\<\"(0122)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4536", "1", "0", "0"},
         {
          FormBox["\<\"(0025)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2475", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7095", "1", "0", "0"},
         {
          FormBox["\<\"(2111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4074", "1", "0", "0"},
         {
          FormBox["\<\"(2013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4746", "2", "0", "0"},
         {
          FormBox["\<\"(0410)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5964", "1", "0", "1"},
         {
          FormBox["\<\"(2006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7224", "1", "1", "0"},
         {
          FormBox["\<\"(0600)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8316", "2", "0", "1"},
         {
          FormBox["\<\"(8100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2574", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10725", "0", "0", "0"},
         {
          FormBox["\<\"(2103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4900", "1", "0", "0"},
         {
          FormBox["\<\"(0114)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5775", "1", "0", "0"},
         {
          FormBox["\<\"(2120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4950", "0", "0", "0"},
         {
          FormBox["\<\"(5101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2970", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7524", "1", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615342963225059*^9},ExpressionUUID->"90f13432-efc0-4277-b831-\
258adbf9c21f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU6", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU3", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Sextality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "5670"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "11"}]}], "]"}]], "Input",ExpressionUU\
ID->"8d200d55-5d22-49b7-88bc-85e5d23f758e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "96"}],
   SequenceForm["Number of irreps: ", 96],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153429828048058`*^9},ExpressionUUID->"20776992-539e-47c5-8c8f-\
5c4f45b69bac"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"255.0\"\>",
      255.34290200000000936597643885761499404907`8.42772370315837,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    255.34290200000000936597643885761499404907`8.42772370315837, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615343218955316*^9},ExpressionUUID->"bad06a86-c630-4401-b154-\
70aa5ef2f176"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(6)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Sextality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0"},
         {
          FormBox["\<\"(01000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "2", "0", "1", "0"},
         {
          FormBox["\<\"(00100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "3", "0", "0", "2"},
         {
          FormBox["\<\"(20000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "2", "1", "0", "0"},
         {
          FormBox["\<\"(10001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(30000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36", "3", "1", "0", "0"},
         {
          FormBox["\<\"(11000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33", "3", "0", "0", "0"},
         {
          FormBox["\<\"(01001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "38", "1", "0", "0", "0"},
         {
          FormBox["\<\"(00101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "52", "2", "0", "0", "0"},
         {
          FormBox["\<\"(00020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64", "2", "0", "1", "0"},
         {
          FormBox["\<\"(20001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "68", "1", "1", "0", "0"},
         {
          FormBox["\<\"(00004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "2", "1", "0", "0"},
         {
          FormBox["\<\"(00200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "0", "0", "0", 
          FormBox[
           
           TemplateBox[{
            "2","\"+\"",
             TemplateBox[{"1", "\"\[SixPointedStar]\""}, "Superscript"]},
            "RowDefault"],
           TraditionalForm]},
         {
          FormBox["\<\"(01010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "108", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "131", "1", "0", "0", "0"},
         {
          FormBox["\<\"(00012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "152", "2", "0", "0", "0"},
         {
          FormBox["\<\"(00005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "1", "1", "0", "0"},
         {
          FormBox["\<\"(20010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "192", "0", "0", "0", "0"},
         {
          FormBox["\<\"(30001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "264", "2", "1", "0", "0"},
         {
          FormBox["\<\"(00102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "248", "1", "0", "0", "0"},
         {
          FormBox["\<\"(11001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "256", "2", "0", "1", "0"},
         {
          FormBox["\<\"(20002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "358", "1", "0", "0", "0"},
         {
          FormBox["\<\"(60000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0", "1", "0", "0"},
         {
          FormBox["\<\"(03000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "0", "0", "1", "0"},
         {
          FormBox["\<\"(00013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "516", "1", "0", "0", "0"},
         {
          FormBox["\<\"(10101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "378", "3", "0", "0", "2"},
         {
          FormBox["\<\"(10020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "456", "3", "0", "0", "0"},
         {
          FormBox["\<\"(40001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", "3", "1", "0", "0"},
         {
          FormBox["\<\"(30010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "696", "1", "0", "0", "0"},
         {
          FormBox["\<\"(70000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "1", "1", "0", "0"},
         {
          FormBox["\<\"(11010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "668", "1", "0", "0", "0"},
         {
          FormBox["\<\"(10200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "764", "1", "0", "0", "0"},
         {
          FormBox["\<\"(30100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "864", "0", "0", "0", "0"},
         {
          FormBox["\<\"(11100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "768", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1134", "3", "0", "0", "4"},
         {
          FormBox["\<\"(10110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "880", "2", "0", "0", "0"},
         {
          FormBox["\<\"(30002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1135", "1", "1", "0", "0"},
         {
          FormBox["\<\"(41000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1440", "0", "0", "0", "0"},
         {
          FormBox["\<\"(21001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1134", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1053", "3", "0", "0", "0"},
         {
          FormBox["\<\"(22000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1134", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1296", "0", "0", "0", "0"},
         {
          FormBox["\<\"(02010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1120", "2", "0", "1", "0"},
         {
          FormBox["\<\"(02100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1204", "1", "0", "0", "0"},
         {
          FormBox["\<\"(11002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1146", "1", "0", "0", "0"},
         {
          FormBox["\<\"(80000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3432", "2", "1", "0", "0"},
         {
          FormBox["\<\"(10005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2112", "2", "1", "0", "0"},
         {
          FormBox["\<\"(01200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1470", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1568", "2", "0", "0", "0"},
         {
          FormBox["\<\"(40010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1575", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2040", "2", "0", "0", "0"},
         {
          FormBox["\<\"(10102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1701", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1620", "2", "0", "0", "0"},
         {
          FormBox["\<\"(13000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1764", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2310", "1", "0", "0", "0"},
         {
          FormBox["\<\"(04000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1764", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2688", "2", "0", "1", "0"},
         {
          FormBox["\<\"(02002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1920", "2", "0", "0", "0"},
         {
          FormBox["\<\"(40100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2460", "1", "0", "0", "0"},
         {
          FormBox["\<\"(01110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1932", "3", "0", "0", "2"},
         {
          FormBox["\<\"(51000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3498", "1", "0", "0", "0"},
         {
          FormBox["\<\"(90000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6435", "3", "1", "0", "0"},
         {
          FormBox["\<\"(10021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2205", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2352", "2", "0", "1", "0"},
         {
          FormBox["\<\"(40002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3256", "2", "1", "0", "0"},
         {
          FormBox["\<\"(21010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2592", "2", "0", "0", "0"},
         {
          FormBox["\<\"(21100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2868", "1", "0", "0", "0"},
         {
          FormBox["\<\"(20200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2976", "2", "0", "0", "0"},
         {
          FormBox["\<\"(10030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3156", "1", "0", "0", "0"},
         {
          FormBox["\<\"(32000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3732", "1", "0", "0", "0"},
         {
          FormBox["\<\"(10006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4884", "1", "1", "0", "0"},
         {
          FormBox["\<\"(10013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2688", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3328", "2", "0", "0", "0"},
         {
          FormBox["\<\"(30003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2695", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3696", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0, 0, 0, 0, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11440", "2", "1", "0", "0"},
         {
          FormBox["\<\"(50010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "3", "0", "0", "0"},
         {
          FormBox["\<\"(30011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3840", "0", "0", "0", "0"},
         {
          FormBox["\<\"(20110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3564", "3", "0", "0", "0"},
         {
          FormBox["\<\"(50100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3465", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6072", "2", "0", "0", "0"},
         {
          FormBox["\<\"(61000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3465", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7656", "2", "0", "0", "0"},
         {
          FormBox["\<\"(11011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3780", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(21002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4340", "2", "0", "1", "0"},
         {
          FormBox["\<\"(10201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3969", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4536", "0", "0", "0", 
          FormBox[
           
           TemplateBox[{
            "2","\"+\"",
             TemplateBox[{"1", "\"\[SixPointedStar]\""}, "Superscript"]},
            "RowDefault"],
           TraditionalForm]},
         {
          FormBox["\<\"(00400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4116", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7056", "0", "0", "0", 
          FormBox[
           
           TemplateBox[{
            "4","\"+\"",
             TemplateBox[{"1", "\"\[SixPointedStar]\""}, "Superscript"]},
            "RowDefault"],
           TraditionalForm]},
         {
          FormBox["\<\"(10103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5260", "1", "0", "0", "0"},
         {
          FormBox["\<\"(70001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10296", "0", "1", "0", "0"},
         {
          FormBox["\<\"(0, 0, 0, 0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19448", "1", "1", "0", "0"},
         {
          FormBox["\<\"(10111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4767", "1", "0", "0", "0"},
         {
          FormBox["\<\"(12100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5712", "2", "0", "0", "0"},
         {
          FormBox["\<\"(00301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6216", "2", "0", "0", "0"},
         {
          FormBox["\<\"(23000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7224", "2", "0", "0", "0"},
         {
          FormBox["\<\"(02003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6150", "1", "0", "0", "0"},
         {
          FormBox["\<\"(12010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5508", "3", "0", "0", "0"},
         {
          FormBox["\<\"(50002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8100", "3", "1", "0", "0"},
         {
          FormBox["\<\"(03100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4704", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7056", "3", "0", "0", "0"},
         {
          FormBox["\<\"(42000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4950", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9240", "2", "0", "0", "0"},
         {
          FormBox["\<\"(02011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6024", "1", "0", "0", "0"},
         {
          FormBox["\<\"(01030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7104", "2", "0", "1", "0"},
         {
          FormBox["\<\"(20102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5292", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6426", "3", "0", "0", "2"},
         {
          FormBox["\<\"(00050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5292", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11088", "2", "0", "1", "0"},
         {
          FormBox["\<\"(10014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8844", "1", "0", "0", "0"},
         {
          FormBox["\<\"(01006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11616", "2", "0", "0", "0"},
         {
          FormBox["\<\"(10120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5670", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7128", "0", "0", "0", "0"},
         {
          FormBox["\<\"(31010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5670", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7857", "3", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615343219120706*^9},ExpressionUUID->"cc0e1dfc-4dcb-4395-bc1c-\
3b3d956b1d3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU7", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU3", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Septality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "3000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input",ExpressionUUI\
D->"737b12a4-dfa4-4b59-b42d-9d13a4339019"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "47"}],
   SequenceForm["Number of irreps: ", 47],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153432426843233`*^9},ExpressionUUID->"51a5ab97-643b-4b3f-ba8c-\
8855c0b437ed"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"69.2\"\>",
      69.24692699999999945248418953269720077515`7.86100041857488,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    69.24692699999999945248418953269720077515`7.86100041857488, {3, 1}], "s"],
   
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61534329047121*^9},ExpressionUUID->"f1efb965-6fe0-4945-b870-837af091c1da"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(7)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Septality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0"},
         {
          FormBox["\<\"(010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5", "2", "0", "1", "0"},
         {
          FormBox["\<\"(200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "2", "1", "0", "0"},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "3", "0", "0", "1"},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45", "3", "1", "0", "0"},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "46", "3", "0", "0", "0"},
         {
          FormBox["\<\"(010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "90", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"196", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "3", "0", "1", "0"},
         {
          FormBox["\<\"(000101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95", "3", "0", "0", "0"},
         {
          FormBox["\<\"(000004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "3", "1", "0", "0"},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", "2", "0", "0", "0"},
         {
          FormBox["\<\"(000012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "234", "3", "0", "0", "0"},
         {
          FormBox["\<\"(010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"392", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "196", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(000005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", "2", "1", "0", "0"},
         {
          FormBox["\<\"(000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "280", "2", "0", "0", "0"},
         {
          FormBox["\<\"(000200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "315", "1", "0", "0", "1"},
         {
          FormBox["\<\"(200010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "315", "0", "0", "0", "0"},
         {
          FormBox["\<\"(300001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "390", "2", "1", "0", "0"},
         {
          FormBox["\<\"(001010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"588", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "329", "1", "0", "0", "0"},
         {
          FormBox["\<\"(110001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"735", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "420", "2", "0", "1", "0"},
         {
          FormBox["\<\"(200002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"735", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "490", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(000102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", "2", "0", "0", "0"},
         {
          FormBox["\<\"(001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"784", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "490", "0", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(001002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"882", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "651", "2", "0", "0", "0"},
         {
          FormBox["\<\"(000006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "870", "2", "0", "0", "0"},
         {
          FormBox["\<\"(000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1050", "1", "0", "1", "0"},
         {
          FormBox["\<\"(020001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "885", "3", "0", "0", "0"},
         {
          FormBox["\<\"(101001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1323", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "819", "3", "0", "0", "1"},
         {
          FormBox["\<\"(400001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "3", "1", "0", "0"},
         {
          FormBox["\<\"(300010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1575", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1275", "1", "0", "0", "0"},
         {
          FormBox["\<\"(700000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "0", "1", "0", "0"},
         {
          FormBox["\<\"(110010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2016", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1380", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1875", "1", "0", "0", "0"},
         {
          FormBox["\<\"(300002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2156", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1925", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2640", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1806", "1", "0", "0", "0"},
         {
          FormBox["\<\"(300100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", "0", "0", "0", "0"},
         {
          FormBox["\<\"(210001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1925", "3", "0", "0", "0"},
         {
          FormBox["\<\"(102000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2646", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2205", "0", "0", "0", "0"},
         {
          FormBox["\<\"(000022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2646", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2583", "1", "0", "0", "0"},
         {
          FormBox["\<\"(110002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", "1", "0", "0", "0"},
         {
          FormBox["\<\"(110100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2940", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2205", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2940", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2415", "2", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615343290560306*^9},ExpressionUUID->"98c9f178-8fa8-464b-a583-\
45c2866f4b12"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU8", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU4", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Octality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "5500"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input",ExpressionUUI\
D->"5ba0bc71-e6a5-48d9-9f16-453dfd21ff42"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "48"}],
   SequenceForm["Number of irreps: ", 48],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615343478299779*^9},ExpressionUUID->"225db1fe-d96c-44e7-ba3f-\
fe707e79c59f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"280.0\"\>",
      279.78690699999998514613253064453601837158`8.467427300523722,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    279.78690699999998514613253064453601837158`8.467427300523722, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615343572698543*^9},ExpressionUUID->"13a5120a-94cd-4d39-861a-\
cb7d98e1a3d0"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "7", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(8)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Octality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "2", "0", "1", "0", "0"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", "3", "0", "0", "1", "0"},
         {
          FormBox["\<\"(1000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"63", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "4", "0", "0", "0", "2"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "3", "1", "0", "0", "0"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "75", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(2000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "115", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(4000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "4", "1", "0", "0", "0"},
         {
          FormBox["\<\"(0200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "160", "4", "0", "1", "0", "0"},
         {
          FormBox["\<\"(1010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "156", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "170", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "215", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(2100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"630", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "340", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0000005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "715", "3", "1", "0", "0", "0"},
         {
          FormBox["\<\"(3000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "550", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(2000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "526", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "700", "2", "0", "0", "1", "0"},
         {
          FormBox["\<\"(2000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1232", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "704", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(1100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "640", "2", "0", "1", "0", "0"},
         {
          FormBox["\<\"(0010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "680", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0001010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "804", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "885", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1090", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(0002000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1764", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1120", "0", "0", "0", "0", 
          FormBox[
           
           TemplateBox[{
            "2","\"+\"",
             TemplateBox[{"1", "\"\[SixPointedStar]\""}, "Superscript"]},
            "RowDefault"],
           TraditionalForm]},
         {
          FormBox["\<\"(0010002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1025", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1848", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1375", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0001002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1250", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0010100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1344", "0", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1414", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0200001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1555", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1980", "2", "0", "1", "0", "0"},
         {
          FormBox["\<\"(4000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2035", "3", "1", "0", "0", "0"},
         {
          FormBox["\<\"(1010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1550", "3", "0", "0", "1", "0"},
         {
          FormBox["\<\"(3000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2145", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5005", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(1001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3584", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2048", "4", "0", "0", "0", "2"},
         {
          FormBox["\<\"(3000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4032", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3064", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(1100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2525", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3630", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4510", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(2100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3234", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3712", "2", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615343572804041*^9},ExpressionUUID->"772c06d7-0273-4016-90e5-\
1191b7bae9ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU9", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU4", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Nonality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1944"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.782310861951601*^9, {3.783527875302782*^9, 
   3.7835278767879515`*^9}},ExpressionUUID->"3bd2ea26-d679-40a0-83eb-\
ca2b2b8a2987"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "23"}],
   SequenceForm["Number of irreps: ", 23],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615343757375977*^9, 3.78231082923206*^9, 
  3.7823109867141666`*^9, 
  3.783527976243513*^9},ExpressionUUID->"e24832e3-1385-48ad-b1c6-\
31249fddef36"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"118.0\"\>",
      118.4730999,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[118.4730999, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615343757375977*^9, 3.78231082923206*^9, 
  3.7823109867141666`*^9, 
  3.7835279961233687`*^9},ExpressionUUID->"c97f9a30-d86b-42b6-a713-\
48299ff4d818"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "13", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SU(9)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Nonality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(01000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7", "2", "0", "1", "0", "0"},
         {
          FormBox["\<\"(20000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(10000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "3", "0", "0", "1", "0"},
         {
          FormBox["\<\"(00010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "4", "0", "0", "0", "1"},
         {
          FormBox["\<\"(30000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "66", "3", "1", "0", "0", "0"},
         {
          FormBox["\<\"(11000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(20000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"396", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "143", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(40000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286", "4", "1", "0", "0", "0"},
         {
          FormBox["\<\"(02000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "231", "4", "0", "1", "0", "0"},
         {
          FormBox["\<\"(10100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"630", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "238", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "266", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(21000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"990", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "473", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "406", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "420", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1215", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "486", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00000005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1001", "4", "1", "0", "0", "0"},
         {
          FormBox["\<\"(30000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "748", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(20000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "693", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1890", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "903", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(20000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1944", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "972", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript", 
         SyntaxForm -> SuperscriptBox],TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(8)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.615343776849821*^9, 3.7823108486162395`*^9, 
  3.7823109968321123`*^9, 
  3.7835279961951838`*^9},ExpressionUUID->"6be44707-77c1-4354-ab07-\
0f8e4f0eb728"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU10", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "2000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",ExpressionUUI\
D->"179c0c89-de4e-4f5c-8e0c-91de0443a0f7"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "19"}],
   SequenceForm["Number of irreps: ", 19],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615344004723*^9},ExpressionUUID->"ca90d63a-5f1a-4a9e-a2ed-875377d154b9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"231.0\"\>",
      230.53643099999999321880750358104705810547`8.383339478719257,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    230.53643099999999321880750358104705810547`8.383339478719257, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615344023338818*^9},ExpressionUUID->"f6065791-6d7a-4b7d-ba6a-\
4504e0c78b39"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "9", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(10)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"99", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", "4", "0", "0", "0", "1", "0"},
         {
          FormBox["\<\"(300000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78", "3", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(000010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "70", "5", "0", "0", "0", "0", "2"},
         {
          FormBox["\<\"(110000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "97", "3", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "124", "1", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(200000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "174", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(400000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", "4", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(020000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "4", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(101000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"990", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "344", "4", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(001000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1155", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "392", "2", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(210000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1485", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "636", "4", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1848", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "700", "5", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "700", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(000100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "742", "3", "0", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(9)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(8)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6153440234035254`*^9},ExpressionUUID->"03e438c7-dfad-4c71-8f29-\
a11e7e79e8cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU11", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "594"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input",ExpressionUUI\
D->"e55dc956-ad48-4c89-9752-6e4c79538a38"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "10"}],
   SequenceForm["Number of irreps: ", 10],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615344177577381*^9},ExpressionUUID->"84b3a965-34e4-4a37-aaef-\
7e0c452c1f8e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"138.0\"\>",
      137.75572600000000988984538707882165908813`8.159709573206493,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    137.75572600000000988984538707882165908813`8.159709573206493, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615344181083522*^9},ExpressionUUID->"b8418bb4-5edf-4947-bf8f-\
e40a3bd3b6d1"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "10", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(11)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(2000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(1000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(3000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "91", "3", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "84", "4", "0", "0", "0", "1", "0"},
         {
          FormBox["\<\"(1100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "118", "3", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "5", "0", "0", "0", "0", "1"},
         {
          FormBox["\<\"(0100000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "153", "1", "0", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(9)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(8)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615344181119096*^9},ExpressionUUID->"dfe31a7c-1faf-4f15-852e-\
78e118ad2389"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU12", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU11", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU6", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "792"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input",ExpressionUUI\
D->"1001c302-8c17-45b4-9b2b-09aa2c39e2f0"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "10"}],
   SequenceForm["Number of irreps: ", 10],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153447487916937`*^9},ExpressionUUID->"c751300f-716e-4ff6-bd72-\
66537c325b60"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"564.0\"\>",
      563.74461099999996349652064964175224304199`8.771682316637216,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    563.74461099999996349652064964175224304199`8.771682316637216, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61534475414915*^9},ExpressionUUID->"6116b1c5-ea01-4dd1-bd09-2dfc00d6ec42"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "11", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(12)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(11)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(20000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(10000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"143", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(30000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "3", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "4", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(11000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"572", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "141", "3", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "185", "1", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "5", "0", "0", "0", "1", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(11)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(9)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615344754186521*^9},ExpressionUUID->"b5e73edc-a7ef-4e15-826b-\
458517cf6b22"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU13", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU12", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU11", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1170"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774610285049954*^9, 3.774610287193225*^9}, {
   3.7746134037253494`*^9, 3.7746134623549967`*^9}, 3.776736686535551*^9, {
   3.7837696497696457`*^9, 
   3.7837696521482797`*^9}},ExpressionUUID->"10d527db-8d72-4e64-9dba-\
6e10b1ff9911"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "10"}],
   SequenceForm["Number of irreps: ", 10],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767385792918777`*^9, 
  3.7837714874203234`*^9},ExpressionUUID->"a71e1ad1-1115-4a2a-84b4-\
67b0b5807e07"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,142,30,2.880405022486932*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{3.7767385925948615`*^9, 
  3.7837715002138696`*^9},ExpressionUUID->"80d25c09-5680-4464-b81b-\
132b69fff8f5"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1770.0\"\>",
      1767.3983622,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1767.3983622, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767385792918777`*^9, 
  3.783771500216858*^9},ExpressionUUID->"216a622e-989e-4571-ba5d-\
bcd041a14654"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "135", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SU(13)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(12)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(11)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"91", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(300000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "3", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "4", "0", "0", "0", "1", "0"},
         {
          FormBox["\<\"(110000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "166", "3", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "1", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(200000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1170", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "285", "1", "1", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript", 
         SyntaxForm -> SuperscriptBox],TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(12)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(11)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(9)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(8)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.77673666395366*^9, 3.7767385928880806`*^9, 
  3.783771500269683*^9},ExpressionUUID->"c6858f6a-67e9-4d04-a822-\
31ce0578749b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU14", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU13", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU12", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU11", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "910"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7746134757374716`*^9, 3.7746135189449773`*^9}, 
   3.7767366949605827`*^9, {3.783769687409452*^9, 
   3.7837696896185274`*^9}},ExpressionUUID->"c7529044-a07a-49cb-a425-\
afa14f164288"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "6"}],
   SequenceForm["Number of irreps: ", 6],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767660461424923`*^9, 
  3.7838810345283017`*^9},ExpressionUUID->"d266d263-2230-4c3c-b6b8-\
8ad21043d530"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"206.0\"\>",
      206.2610254,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[206.2610254, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767660461424923`*^9, 
  3.7838810366695642`*^9},ExpressionUUID->"7d6fe027-ecb2-4600-bb3d-\
b612739e19fe"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "139", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SU(14)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(13)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(12)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(11)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"91", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(2000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(1000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"195", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "66", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(1100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"910", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "193", "3", "0", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript", 
         SyntaxForm -> SuperscriptBox],TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(13)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(12)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(11)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(9)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.776738649037174*^9, 3.776765652472902*^9, 
  3.7767660480261154`*^9, 
  3.783881036767333*^9},ExpressionUUID->"01320d4a-2598-48bf-8fee-\
7dcbb70c4171"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU15", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU14", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU13", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU12", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU11", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1560"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613527628806*^9, 3.774613545930293*^9}, {
  3.7767367036593995`*^9, 3.7767367048960915`*^9}, {3.7839562969391975`*^9, 
  3.783956297662291*^9}, {3.7839565183535333`*^9, 3.783956519414695*^9}, {
  3.783959364187383*^9, 
  3.7839593651627736`*^9}},ExpressionUUID->"a04ed440-0330-4f29-a9c4-\
e10e6f8ee7bd"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "8"}],
   SequenceForm["Number of irreps: ", 8],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767667374081182`*^9, 3.783957194221631*^9, 
  3.7839600398667765`*^9},ExpressionUUID->"53ae3ae9-3e24-46fc-88c7-\
2a7221ad297b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"679.0\"\>",
      678.6923077,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[678.6923077, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767667374081182`*^9, 3.783957194221631*^9, 
  3.7839600447976265`*^9},ExpressionUUID->"6e1560f5-e7a7-45c1-b4cc-\
c7d3565a8c03"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "256", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SU(15)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(14)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(13)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(12)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(11)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(20000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(10000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(11000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "222", "3", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1365", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286", "4", "0", "0", "0", "1", "0"},
         {
          FormBox["\<\"(01000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "299", "1", "0", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript", 
         SyntaxForm -> SuperscriptBox],TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(14)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(13)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(12)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(11)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767667385690374`*^9, 3.7839571973891897`*^9, 
  3.783960044867442*^9},ExpressionUUID->"2aabda4d-3643-4f8e-b2cb-\
2db340a6c398"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU16", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU15", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU14", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU13", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU12", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU11", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "560"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835293241318054`*^9, 
  3.7835293556584826`*^9}},ExpressionUUID->"67153e7c-b4bd-4b56-9231-\
9c247db545cf"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of irreps: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783680334370702*^9},ExpressionUUID->"0c044a3e-020c-4e8a-a01a-\
67236be6c7a4"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,70,1,2.880405022486932*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.7836803376080046`*^9},ExpressionUUID->"6aa5a738-a523-49c0-bf15-\
2ddeb3d9872e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"2060.0\"\>",
      2056.8418067,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[2056.8418067, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7836803376109967`*^9},ExpressionUUID->"516f73ac-4edf-4621-8463-\
b1d719f93839"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "67", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SU(16)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(15)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(14)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(13)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(12)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(11)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"255", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(001000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "91", "3", "0", "0", "1", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript", 
         SyntaxForm -> SuperscriptBox],TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(15)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(14)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(13)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(12)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(11)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.783680337660894*^9},ExpressionUUID->"131693d4-9a3b-404a-bbb5-\
e7bd233a0688"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SO(N)", "Section",ExpressionUUID->"a24526e5-2b4a-496d-a7c5-458d7a353ffc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO7", ",", 
   RowBox[{"{", "SU4", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "15930"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "13"}]}], "]"}]], "Input",ExpressionUU\
ID->"511e85de-1cc2-446e-a792-20c58310e9ae"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "97"}],
   SequenceForm["Number of irreps: ", 97],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153447980106583`*^9},ExpressionUUID->"5216de20-cbe9-4bef-b31b-\
34b14c72de7d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"666.0\"\>",
      665.77214400000002569868229329586029052734`8.84392553353829,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    665.77214400000002569868229329586029052734`8.84392553353829, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153454634152184`*^9},ExpressionUUID->"84ef07ea-bb6f-4b2a-a946-\
c932f9f12841"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "12", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(7)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(4)\"\>",
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0", "1"},
         {
          FormBox["\<\"(001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "0"},
         {
          FormBox["\<\"(010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5", "0", "0"},
         {
          FormBox["\<\"(200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "0", "1"},
         {
          FormBox["\<\"(002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "0", "0"},
         {
          FormBox["\<\"(101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "1", "0"},
         {
          FormBox["\<\"(300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"77", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "44", "0", "1"},
         {
          FormBox["\<\"(110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45", "0", "0"},
         {
          FormBox["\<\"(011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "46", "1", "0"},
         {
          FormBox["\<\"(003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", "1", "0"},
         {
          FormBox["\<\"(201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "85", "1", "0"},
         {
          FormBox["\<\"(020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "96", "0", "0"},
         {
          FormBox["\<\"(400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"182", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "156", "0", "1"},
         {
          FormBox["\<\"(102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "90", "0", "0"},
         {
          FormBox["\<\"(004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"294", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "0", "0"},
         {
          FormBox["\<\"(210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "0", "0"},
         {
          FormBox["\<\"(012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "234", "0", "0"},
         {
          FormBox["\<\"(500)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "450", "0", "1"},
         {
          FormBox["\<\"(301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"448", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "344", "1", "0"},
         {
          FormBox["\<\"(111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "1", "0"},
         {
          FormBox["\<\"(103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "390", "1", "0"},
         {
          FormBox["\<\"(202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"616", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "440", "0", "0"},
         {
          FormBox["\<\"(005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "660", "1", "0"},
         {
          FormBox["\<\"(120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"693", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "561", "0", "0"},
         {
          FormBox["\<\"(600)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"714", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1122", "0", "1"},
         {
          FormBox["\<\"(021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "570", "1", "0"},
         {
          FormBox["\<\"(310)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"819", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "780", "0", "0"},
         {
          FormBox["\<\"(030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "825", "0", "0"},
         {
          FormBox["\<\"(013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "870", "1", "0"},
         {
          FormBox["\<\"(401)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1086", "1", "0"},
         {
          FormBox["\<\"(700)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1254", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2508", "0", "1"},
         {
          FormBox["\<\"(104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "0", "0"},
         {
          FormBox["\<\"(006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", "0", "0"},
         {
          FormBox["\<\"(211)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1341", "1", "0"},
         {
          FormBox["\<\"(302)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1560", "0", "0"},
         {
          FormBox["\<\"(112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1617", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1386", "0", "0"},
         {
          FormBox["\<\"(203)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1656", "1", "0"},
         {
          FormBox["\<\"(410)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2250", "0", "0"},
         {
          FormBox["\<\"(220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1911", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2093", "0", "0"},
         {
          FormBox["\<\"(501)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2016", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2892", "1", "0"},
         {
          FormBox["\<\"(022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2178", "0", "0"},
         {
          FormBox["\<\"(800)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "0", "1"},
         {
          FormBox["\<\"(014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2640", "0", "0"},
         {
          FormBox["\<\"(007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", "1", "0"},
         {
          FormBox["\<\"(121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2950", "1", "0"},
         {
          FormBox["\<\"(130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3861", "0", "0"},
         {
          FormBox["\<\"(040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4576", "0", "0"},
         {
          FormBox["\<\"(105)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3762", "1", "0"},
         {
          FormBox["\<\"(031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3905", "1", "0"},
         {
          FormBox["\<\"(900)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3289", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9867", "0", "1"},
         {
          FormBox["\<\"(510)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3366", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5610", "0", "0"},
         {
          FormBox["\<\"(402)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3375", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4500", "0", "0"},
         {
          FormBox["\<\"(311)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3584", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4288", "1", "0"},
         {
          FormBox["\<\"(601)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6798", "1", "0"},
         {
          FormBox["\<\"(204)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4095", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5070", "0", "0"},
         {
          FormBox["\<\"(113)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4608", "1", "0"},
         {
          FormBox["\<\"(303)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5325", "1", "0"},
         {
          FormBox["\<\"(320)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6160", "0", "0"},
         {
          FormBox["\<\"(212)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5200", "0", "0"},
         {
          FormBox["\<\"(008)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4719", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9438", "0", "0"},
         {
          FormBox["\<\"(015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6930", "1", "0"},
         {
          FormBox["\<\"(023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6600", "1", "0"},
         {
          FormBox["\<\"(10, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17875", "0", "1"},
         {
          FormBox["\<\"(610)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5985", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12540", "0", "0"},
         {
          FormBox["\<\"(106)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6006", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9438", "0", "0"},
         {
          FormBox["\<\"(701)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14520", "1", "0"},
         {
          FormBox["\<\"(502)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6545", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11220", "0", "0"},
         {
          FormBox["\<\"(11, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30888", "0", "1"},
         {
          FormBox["\<\"(221)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7392", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10076", "1", "0"},
         {
          FormBox["\<\"(411)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7392", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11484", "1", "0"},
         {
          FormBox["\<\"(230)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12240", "0", "0"},
         {
          FormBox["\<\"(122)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10296", "0", "0"},
         {
          FormBox["\<\"(032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12584", "0", "0"},
         {
          FormBox["\<\"(009)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19305", "1", "0"},
         {
          FormBox["\<\"(420)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15504", "0", "0"},
         {
          FormBox["\<\"(205)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8624", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13398", "1", "0"},
         {
          FormBox["\<\"(403)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14300", "1", "0"},
         {
          FormBox["\<\"(050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8918", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19110", "0", "0"},
         {
          FormBox["\<\"(114)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12870", "0", "0"},
         {
          FormBox["\<\"(016)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16302", "0", "0"},
         {
          FormBox["\<\"(304)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15125", "0", "0"},
         {
          FormBox["\<\"(140)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10010", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18590", "0", "0"},
         {
          FormBox["\<\"(710)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10010", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25740", "0", "0"},
         {
          FormBox["\<\"(041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18746", "1", "0"},
         {
          FormBox["\<\"(024)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10296", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17160", "0", "0"},
         {
          FormBox["\<\"(801)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10296", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28743", "1", "0"},
         {
          FormBox["\<\"(312)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10395", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15345", "0", "0"},
         {
          FormBox["\<\"(12, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10556", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51272", "0", "1"},
         {
          FormBox["\<\"(131)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16960", "1", "0"},
         {
          FormBox["\<\"(213)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15906", "1", "0"},
         {
          FormBox["\<\"(107)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21450", "1", "0"},
         {
          FormBox["\<\"(602)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11704", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25080", "0", "0"},
         {
          FormBox["\<\"(0, 0, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13013", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "37180", "0", "0"},
         {
          FormBox["\<\"(511)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27072", "1", "0"},
         {
          FormBox["\<\"(13, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "82212", "0", "1"},
         {
          FormBox["\<\"(520)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15561", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34827", "0", "0"},
         {
          FormBox["\<\"(330)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31824", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615345463528407*^9},ExpressionUUID->"1ad8f23c-a350-4bff-96c5-\
b5084b3b04b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO8", ",", 
   RowBox[{"{", "SO7", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "4600"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input",ExpressionUUI\
D->"df06733c-a807-4449-a013-acd6e0eb8f4a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615345464374362*^9},ExpressionUUID->"5a67cdc6-733d-43a9-82b0-\
f7c4a7eb0dce"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"91.8\"\>",
      91.79897400000000118325260700657963752747`7.983437740574238,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    91.79897400000000118325260700657963752747`7.983437740574238, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615345555447797*^9},ExpressionUUID->"c35994a3-f33f-4620-91c8-\
7b3104cdb114"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "13", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(8)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(7)\"\>",
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(0001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(1010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(3000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"294", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"294", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"294", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"567", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"567", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"567", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "660", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "660", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "660", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "465", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "465", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "465", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1296", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1296", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1296", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0060)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "975", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "975", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "975", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1568", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1260", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1568", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1260", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1568", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1260", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1650", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0070)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3960", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0140)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3960", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3960", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(5010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0051)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(5001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3072", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3807", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3807", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3807", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.61534555556498*^9},ExpressionUUID->"1ee8b9f9-7502-48fa-bea6-099975c07f2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO9", ",", 
   RowBox[{"{", 
    RowBox[{"SO8", ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU2"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "90000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "9"}]}], "]"}]], "Input",ExpressionUUI\
D->"7661c92e-cd9e-4a55-80d7-6f1c9afe14f7"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615345558150434*^9},ExpressionUUID->"1b5b08c3-06eb-4234-bee1-\
4b5a67cb83dd"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1380.0\"\>",
      1378.34542299999998249404598027467727661133`9.159957981724824,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    1378.34542299999998249404598027467727661133`9.159957981724824, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615346936330455*^9},ExpressionUUID->"439246a1-fb5d-4d25-a598-\
bceef68b7504"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "14", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(9)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(8)\"\>",
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0", "1", "0"},
         {
          FormBox["\<\"(0001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2", "1", "0", "0"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7", "0", "0", "0"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11", "0", "1", "1"},
         {
          FormBox["\<\"(0010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "0", "0", "1"},
         {
          FormBox["\<\"(0002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "0", "0", "0"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"128", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", "1", "0", "0"},
         {
          FormBox["\<\"(3000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"156", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65", "0", "1", "0"},
         {
          FormBox["\<\"(1100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77", "0", "0", "0"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "150", "1", "0", "0"},
         {
          FormBox["\<\"(4000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "275", "0", "1", "1"},
         {
          FormBox["\<\"(0200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "0", "0", "1"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"576", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "232", "1", "0", "0"},
         {
          FormBox["\<\"(1010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "231", "0", "0", "0"},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "308", "1", "0", "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"768", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "1", "0", "0"},
         {
          FormBox["\<\"(2100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"910", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "455", "0", "0", "0"},
         {
          FormBox["\<\"(1002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "385", "0", "0", "0"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1122", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "935", "0", "1", "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "825", "0", "0", "0"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1120", "1", "0", "0"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1155", "0", "0", "1"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2457", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1365", "0", "0", "1"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2508", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2717", "0", "1", "1"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1280", "1", "0", "0"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2574", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1573", "0", "0", "0"},
         {
          FormBox["\<\"(0102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2772", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1463", "0", "0", "0"},
         {
          FormBox["\<\"(0004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2772", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1848", "0", "0", "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2772", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1925", "0", "0", "0"},
         {
          FormBox["\<\"(2002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3900", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2275", "0", "0", "0"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "0", "0", "0"},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4158", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2541", "0", "0", "0"},
         {
          FormBox["\<\"(1003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4608", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2816", "1", "0", "0"},
         {
          FormBox["\<\"(0201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "1", "0", "0"},
         {
          FormBox["\<\"(1011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2870", "1", "0", "0"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5148", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7007", "0", "1", "0"},
         {
          FormBox["\<\"(4001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4180", "1", "0", "0"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6545", "0", "0", "0"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5775", "0", "0", "0"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8748", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7047", "0", "0", "1"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6006", "0", "0", "0"},
         {
          FormBox["\<\"(2101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6468", "1", "0", "0"},
         {
          FormBox["\<\"(0005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8580", "1", "0", "0"},
         {
          FormBox["\<\"(8000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9867", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16445", "0", "1", "1"},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12012", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9009", "0", "0", "0"},
         {
          FormBox["\<\"(3002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12375", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9625", "0", "0", "0"},
         {
          FormBox["\<\"(0111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8800", "1", "0", "0"},
         {
          FormBox["\<\"(0103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9328", "1", "0", "0"},
         {
          FormBox["\<\"(5001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13024", "1", "0", "0"},
         {
          FormBox["\<\"(0021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10450", "1", "0", "0"},
         {
          FormBox["\<\"(1102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15444", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10725", "0", "0", "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15444", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12441", "0", "0", "1"},
         {
          FormBox["\<\"(5100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16302", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19019", "0", "0", "0"},
         {
          FormBox["\<\"(0013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14080", "1", "0", "0"},
         {
          FormBox["\<\"(9000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35750", "0", "1", "0"},
         {
          FormBox["\<\"(1004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18018", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15015", "0", "0", "0"},
         {
          FormBox["\<\"(1300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18018", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17017", "0", "0", "0"},
         {
          FormBox["\<\"(2003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14630", "1", "0", "0"},
         {
          FormBox["\<\"(2011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19712", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14784", "1", "0", "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20196", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19635", "0", "0", "1"},
         {
          FormBox["\<\"(0400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22932", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25480", "0", "0", "1"},
         {
          FormBox["\<\"(0030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23595", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23595", "0", "0", "1"},
         {
          FormBox["\<\"(3200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23868", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24531", "0", "0", "0"},
         {
          FormBox["\<\"(1201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19488", "1", "0", "0"},
         {
          FormBox["\<\"(1012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"25740", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20020", "0", "0", "0"},
         {
          FormBox["\<\"(0120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27027", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24024", "0", "0", "0"},
         {
          FormBox["\<\"(0202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22880", "0", "0", "0"},
         {
          FormBox["\<\"(6001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35464", "1", "0", "0"},
         {
          FormBox["\<\"(3101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27648", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24576", "1", "0", "0"},
         {
          FormBox["\<\"(0006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33033", "0", "0", "0"},
         {
          FormBox["\<\"(2110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27125", "0", "0", "0"},
         {
          FormBox["\<\"(4002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32725", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32725", "0", "0", "0"},
         {
          FormBox["\<\"(6100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33957", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "49049", "0", "0", "0"},
         {
          FormBox["\<\"(0301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34944", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33488", "1", "0", "0"},
         {
          FormBox["\<\"(2020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "41888", "0", "0", "1"},
         {
          FormBox["\<\"(0104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46332", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45045", "0", "0", "0"},
         {
          FormBox["\<\"(5010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46683", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "57057", "0", "0", "0"},
         {
          FormBox["\<\"(2102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54675", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "48600", "0", "0", "0"},
         {
          FormBox["\<\"(7001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "86944", "1", "0", "0"},
         {
          FormBox["\<\"(2300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54978", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64141", "0", "0", "0"},
         {
          FormBox["\<\"(3003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56320", "1", "0", "0"},
         {
          FormBox["\<\"(4200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72105", "0", "0", "1"},
         {
          FormBox["\<\"(0022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56628", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "58201", "0", "0", "0"},
         {
          FormBox["\<\"(0014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56628", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61347", "0", "0", "0"},
         {
          FormBox["\<\"(3011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"59136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56672", "1", "0", "0"},
         {
          FormBox["\<\"(1005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"59136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64064", "1", "0", "0"},
         {
          FormBox["\<\"(0112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"60060", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55055", "0", "0", "0"},
         {
          FormBox["\<\"(1111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65536", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "57344", "1", "0", "0"},
         {
          FormBox["\<\"(7100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "115115", "0", "0", "0"},
         {
          FormBox["\<\"(1103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"67200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61600", "1", "0", "0"},
         {
          FormBox["\<\"(4101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"68640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77220", "1", "0", "0"},
         {
          FormBox["\<\"(2004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"69300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71225", "0", "0", "0"},
         {
          FormBox["\<\"(1210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"71500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71500", "0", "0", "0"},
         {
          FormBox["\<\"(0007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"75504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "110110", "1", "0", "0"},
         {
          FormBox["\<\"(1021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76032", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "73920", "1", "0", "0"},
         {
          FormBox["\<\"(5002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76076", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95095", "0", "0", "0"},
         {
          FormBox["\<\"(2201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78624", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "79716", "1", "0", "0"},
         {
          FormBox["\<\"(3110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"87516", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "94809", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6153469363366623`*^9},ExpressionUUID->"de429fe3-e7d3-499f-898f-\
24a1f1760e3c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO10", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU2", ",", "SU2", ",", "SU4"}], "]"}], ",", "SO9", ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU2", ",", "SO7"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "72765"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "10"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.782311384625218*^9, {3.7835280600056696`*^9, 3.7835280612402015`*^9}, 
   3.7835294606933618`*^9, {3.7835295315786753`*^9, 
   3.7835295318589067`*^9}},ExpressionUUID->"91be0769-e12d-45f8-9dfd-\
4bdb7c1b8019"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "96"}],
   SequenceForm["Number of irreps: ", 96],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.61534695952209*^9, 3.782311413234754*^9, 
  3.783528096667676*^9, 3.783529466894099*^9, 
  3.7835295415914526`*^9},ExpressionUUID->"e679827b-84db-4b6b-a2e7-\
cb79c7560780"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,18,3,2.8802839787938062`*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.7835308036898704`*^9},ExpressionUUID->"26896f4f-b039-48fe-906a-\
a93820cca3c2"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1270.0\"\>",
      1268.6799026,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1268.6799026, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.61534695952209*^9, 3.782311413234754*^9, 
  3.783528096667676*^9, 3.783529466894099*^9, 
  3.7835308036898704`*^9},ExpressionUUID->"b0952ee2-9331-49c8-a938-\
b02a36c3439d"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "16", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(10)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(9)\"\>",
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(7)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(00001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(01000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "0", "0"},
         {
          FormBox["\<\"(20000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(00100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(00020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(10010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"144", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "0", "0"},
         {
          FormBox["\<\"(30000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(11000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "96", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "182", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(40000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"660", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "352", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(00030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "308", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(20001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "266", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(02000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"770", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "308", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "0", "1"},
         {
          FormBox["\<\"(10100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "336", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "420", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "470", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(21000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "616", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "628", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(10011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(50000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1782", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(30010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1386", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2772", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1848", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(01100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2970", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1353", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(11010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1694", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1848", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(00200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4125", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2200", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "0", "1"},
         {
          FormBox["\<\"(60000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(20100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2156", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(12000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2401", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(31000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4608", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2816", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(20020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4950", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2695", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3124", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5940", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2904", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "0", "0"},
         {
          FormBox["\<\"(00120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4389", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(03000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7644", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5096", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "0", "0"},
         {
          FormBox["\<\"(40001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5566", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(02001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8064", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4592", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(20011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8085", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4312", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "0", "0"},
         {
          FormBox["\<\"(10101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4620", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8910", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5544", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "0", "0"},
         {
          FormBox["\<\"(70000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9438", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11011", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(00005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8580", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(00111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5984", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6314", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(41000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12870", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10296", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(30100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14784", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9856", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(21001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9282", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(22000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11648", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "0", "1"},
         {
          FormBox["\<\"(01030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12144", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(30020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17325", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12320", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(11100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10752", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(80000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19305", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27456", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(50010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20592", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18590", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20790", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16863", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(11020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14848", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(20030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17754", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"25200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16030", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22660", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(10200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18788", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(30011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19712", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00060)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33033", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(00103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23408", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22330", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(51000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32032", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(02100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34398", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24843", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(01012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34992", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23814", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(11011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23275", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(90000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37180", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "63206", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(13000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37632", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31360", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(20110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"38016", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25872", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"39600", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33110", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(40100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36036", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(12010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31668", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(02020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35880", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(31010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48048", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "38038", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(60001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48048", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54054", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48114", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34749", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(32000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48510", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "43659", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(20012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"49280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35728", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(40020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45045", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50688", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "39424", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(04000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"52920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51744", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "0", "1"},
         {
          FormBox["\<\"(00121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42658", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60060", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(10022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "49588", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10, 0, 0, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"68068", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "136136", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(21100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"68640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "52624", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"68640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72644", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70070", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56056", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70070", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "63063", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(03001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60564", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(61000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70785", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "88088", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"72765", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51744", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript", 
         SyntaxForm -> SuperscriptBox],TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.61534904889154*^9, 3.782312735745655*^9, 
  3.7835294511813364`*^9, 3.783529524597163*^9, 
  3.7835308038342133`*^9},ExpressionUUID->"d2cfb437-4d47-4dff-ba95-\
0f3c041d7534"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO11", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "37752"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "8"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.780161375867087*^9, {3.7801614761657534`*^9, 3.7801614990942383`*^9}, 
   3.78016154419699*^9, {3.7835294922452416`*^9, 3.783529493847684*^9}, 
   3.7835295832720814`*^9},ExpressionUUID->"73501995-0f39-4d66-a339-\
97dff0236b90"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "49"}],
   SequenceForm["Number of irreps: ", 49],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615349055396537*^9, 3.7801613790834904`*^9, {3.7801614775101604`*^9, 
   3.780161508286776*^9}, 3.780161545870515*^9, 
   3.7835308252749443`*^9},ExpressionUUID->"19fddfae-3d8d-4d74-85fa-\
d5fee64b4acf"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"3.5\"\>",
      3.4905838,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[3.4905838, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615349055396537*^9, 3.7801613790834904`*^9, {3.7801614775101604`*^9, 
   3.780161508286776*^9}, 3.780161545870515*^9, 
   3.7835308252779408`*^9},ExpressionUUID->"0b3f6ef5-887a-4a02-bcde-\
5a7434dbfd04"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "17", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(11)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(00001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "1"},
         {
          FormBox["\<\"(01000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "0"},
         {
          FormBox["\<\"(20000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13", "0"},
         {
          FormBox["\<\"(00100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36", "0"},
         {
          FormBox["\<\"(30000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "90", "0"},
         {
          FormBox["\<\"(10001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72", "1"},
         {
          FormBox["\<\"(00010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "84", "0"},
         {
          FormBox["\<\"(11000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"429", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "117", "0"},
         {
          FormBox["\<\"(00002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "0"},
         {
          FormBox["\<\"(40000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"935", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "442", "0"},
         {
          FormBox["\<\"(02000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1144", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "416", "0"},
         {
          FormBox["\<\"(01001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1408", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "432", "1"},
         {
          FormBox["\<\"(10100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "468", "0"},
         {
          FormBox["\<\"(20001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "604", "1"},
         {
          FormBox["\<\"(21000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2025", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", "0"},
         {
          FormBox["\<\"(50000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2717", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1729", "0"},
         {
          FormBox["\<\"(10010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1092", "0"},
         {
          FormBox["\<\"(00101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1304", "1"},
         {
          FormBox["\<\"(00003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1872", "1"},
         {
          FormBox["\<\"(10002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1638", "0"},
         {
          FormBox["\<\"(01100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2093", "0"},
         {
          FormBox["\<\"(00011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2196", "1"},
         {
          FormBox["\<\"(60000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7007", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5733", "0"},
         {
          FormBox["\<\"(30001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3376", "1"},
         {
          FormBox["\<\"(20100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7128", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3240", "0"},
         {
          FormBox["\<\"(12000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7150", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3510", "0"},
         {
          FormBox["\<\"(31000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7293", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3978", "0"},
         {
          FormBox["\<\"(00200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7865", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3861", "0"},
         {
          FormBox["\<\"(11001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4352", "1"},
         {
          FormBox["\<\"(01010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11583", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5265", "0"},
         {
          FormBox["\<\"(03000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8190", "0"},
         {
          FormBox["\<\"(20010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7560", "0"},
         {
          FormBox["\<\"(70000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16445", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16744", "0"},
         {
          FormBox["\<\"(01002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8112", "0"},
         {
          FormBox["\<\"(41000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15561", "0"},
         {
          FormBox["\<\"(20002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11340", "0"},
         {
          FormBox["\<\"(40001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14508", "1"},
         {
          FormBox["\<\"(00110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23595", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12441", "0"},
         {
          FormBox["\<\"(00020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23595", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13728", "0"},
         {
          FormBox["\<\"(02001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13104", "1"},
         {
          FormBox["\<\"(30100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15912", "0"},
         {
          FormBox["\<\"(00004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18018", "0"},
         {
          FormBox["\<\"(10101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13932", "1"},
         {
          FormBox["\<\"(22000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28798", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18326", "0"},
         {
          FormBox["\<\"(11100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33033", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18018", "0"},
         {
          FormBox["\<\"(80000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "44200", "0"},
         {
          FormBox["\<\"(10003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20748", "1"},
         {
          FormBox["\<\"(00102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20592", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615349055448688*^9, 3.780161379169263*^9, {3.7801614775999203`*^9, 
   3.780161508371515*^9}, 3.7801615459602757`*^9, 
   3.7835308253467503`*^9},ExpressionUUID->"4ce16c6d-7421-4123-91ae-\
67ca4f045442"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO12", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "48100"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input",ExpressionUUI\
D->"802cceae-d714-4ba9-97f3-56b278cc7766"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "49"}],
   SequenceForm["Number of irreps: ", 49],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153490770969877`*^9},ExpressionUUID->"8ed04a2a-c8c2-451b-b38c-\
9089c4e8f4bb"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"21.3\"\>",
      21.25915099999999924307303444948047399521`7.348145829940209,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    21.25915099999999924307303444948047399521`7.348145829940209, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153490771157703`*^9},ExpressionUUID->"3257b41f-0daa-40ef-b6e2-\
364c6cb8ed91"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "17", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(12)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"77", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "76", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "104", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(400000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "546", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(020000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1638", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "546", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(101000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "630", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "680", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(210000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2860", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1040", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(500000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2275", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1872", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1764", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1680", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1736", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(011000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3094", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8085", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2940", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3500", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(300001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9152", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4056", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4068", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(600000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11011", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8008", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(120000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4956", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(310000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5460", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(201000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11232", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4680", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(110001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5460", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(002000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14014", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6370", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21021", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8918", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9750", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(030000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12600", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27027", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13104", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12480", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(700000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24752", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18018", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(400010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32032", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18564", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(410000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22750", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36036", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16107", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(020010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18060", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"41184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22620", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(101010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20020", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(301000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45045", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24570", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21840", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48048", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23660", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.61534907714775*^9},ExpressionUUID->"e9505098-498f-4007-b96b-ab6705b1d188"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO13", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "19000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "6"}]}], "]"}]], "Input",ExpressionUUI\
D->"474fc93d-0f99-46fa-b170-5f0bbf6b46b5"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "25"}],
   SequenceForm["Number of irreps: ", 25],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153490899907093`*^9},ExpressionUUID->"a229acf1-8c4e-4a7e-8613-\
14387dc53bca"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"11.0\"\>",
      11.01030300000000039517544792033731937408`7.062399184060397,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    11.01030300000000039517544792033731937408`7.062399184060397, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615349090007143*^9},ExpressionUUID->"bb85cc19-30be-42bd-bec7-\
836e57696f3b"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "18", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(13)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "1"},
         {
          FormBox["\<\"(010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11", "0"},
         {
          FormBox["\<\"(200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"90", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", "0"},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "0"},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"442", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "119", "0"},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "0"},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"768", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "160", "1"},
         {
          FormBox["\<\"(000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "0"},
         {
          FormBox["\<\"(000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "0"},
         {
          FormBox["\<\"(400000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "665", "0"},
         {
          FormBox["\<\"(020000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "700", "0"},
         {
          FormBox["\<\"(101000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "825", "0"},
         {
          FormBox["\<\"(210000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3927", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1309", "0"},
         {
          FormBox["\<\"(010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1160", "1"},
         {
          FormBox["\<\"(200001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4992", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1520", "1"},
         {
          FormBox["\<\"(500000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5733", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2940", "0"},
         {
          FormBox["\<\"(100100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2475", "0"},
         {
          FormBox["\<\"(011000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12285", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4410", "0"},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4480", "1"},
         {
          FormBox["\<\"(100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4950", "0"},
         {
          FormBox["\<\"(310000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16302", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7315", "0"},
         {
          FormBox["\<\"(120000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16575", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6800", "0"},
         {
          FormBox["\<\"(600000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16744", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10948", "0"},
         {
          FormBox["\<\"(201000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17017", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6545", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615349090024762*^9},ExpressionUUID->"224f627b-7956-4615-8ab5-\
c9356b5c13d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO14", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SU2", ",", "SU2", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "8000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",ExpressionUUI\
D->"a488be41-1c98-4b5e-aaea-bb2fc53e2ab2"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "18"}],
   SequenceForm["Number of irreps: ", 18],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61534909833711*^9},ExpressionUUID->"55d7a3a8-c288-4dbb-95fe-c352b36fd5e2"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"22.2\"\>",
      22.21938700000000110890141513664275407791`7.367331986507798,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    22.21938700000000110890141513664275407791`7.367331986507798, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615349113053328*^9},ExpressionUUID->"0a42526f-d14a-4b83-be12-\
99600603e9bc"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "19", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(14)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"91", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"104", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "66", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"546", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "135", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"832", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "168", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "192", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "800", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "880", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(1010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1056", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5265", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1620", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1688", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615349113077724*^9},ExpressionUUID->"158908f0-c94d-48b3-9dec-\
8a629524b159"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO15", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "30000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7746136688547964`*^9, 3.774613694822457*^9}, 
   3.7836807309110613`*^9, {3.7836812069363317`*^9, 3.783681220428235*^9}, {
   3.783681335917408*^9, 3.7836813363223257`*^9}, {3.7836816056627274`*^9, 
   3.7836816184966087`*^9}, {3.783681676708598*^9, 
   3.7836816910564547`*^9}},ExpressionUUID->"b7f40d11-8bec-4348-9df6-\
71dd0f13e889"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "20"}],
   SequenceForm["Number of irreps: ", 20],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767818712650423`*^9, 3.7836809170566998`*^9, 3.783681215123419*^9, {
   3.7836813282538967`*^9, 3.7836813438457775`*^9}, {3.783681612887522*^9, 
   3.7836816263908997`*^9}, {3.783681683839642*^9, 
   3.7836816985315847`*^9}},ExpressionUUID->"5d6b8315-7e48-422a-ba2a-\
bc6628c4641b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"6.5\"\>",
      6.549616,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[6.549616, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767818712650423`*^9, 3.7836809170566998`*^9, 3.783681215123419*^9, {
   3.7836813282538967`*^9, 3.7836813438457775`*^9}, {3.783681612887522*^9, 
   3.7836816263908997`*^9}, {3.783681683839642*^9, 
   3.783681698534576*^9}},ExpressionUUID->"b050c90b-aed6-4f5c-b56a-\
f3de0ff3ad5d"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "82", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(15)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13", "0"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"119", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17", "0"},
         {
          FormBox["\<\"(0000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"128", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "1"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78", "0"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"665", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "152", "0"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "221", "0"},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1365", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286", "0"},
         {
          FormBox["\<\"(1000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "352", "1"},
         {
          FormBox["\<\"(4000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2940", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "952", "0"},
         {
          FormBox["\<\"(0000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "715", "0"},
         {
          FormBox["\<\"(0200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1088", "0"},
         {
          FormBox["\<\"(0000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", "0"},
         {
          FormBox["\<\"(1010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5355", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1326", "0"},
         {
          FormBox["\<\"(0000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6435", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "0"},
         {
          FormBox["\<\"(2100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6916", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1976", "0"},
         {
          FormBox["\<\"(0100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2976", "1"},
         {
          FormBox["\<\"(2000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3728", "1"},
         {
          FormBox["\<\"(1001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17017", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4862", "0"},
         {
          FormBox["\<\"(0110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26180", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8228", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.776781871312914*^9, 3.783680917091606*^9, 3.783681215156353*^9, {
   3.783681328286808*^9, 3.7836813438843713`*^9}, {3.783681612921431*^9, 
   3.7836816264347477`*^9}, {3.7836816838805637`*^9, 
   3.783681698565493*^9}},ExpressionUUID->"d5364552-978c-4abf-a603-\
84708052ba97"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO16", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "25000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613703185351*^9, 3.7746137143823366`*^9}, 
   3.7836813965545244`*^9, {3.783681452604445*^9, 3.7836814534461875`*^9}, 
   3.783681749339305*^9, {3.7836818718674994`*^9, 
   3.783681875787073*^9}},ExpressionUUID->"e99bd73b-31ce-49a7-8483-\
514fe779ffab"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "20"}],
   SequenceForm["Number of irreps: ", 20],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776781890670212*^9, 3.7836814396969166`*^9, 
  3.7836814935033092`*^9, 3.7836817856663074`*^9, 
  3.7836819131513305`*^9},ExpressionUUID->"012a1f68-f821-4b96-9d61-\
30c8c4be6691"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"36.8\"\>",
      36.823463,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[36.823463, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776781890670212*^9, 3.7836814396969166`*^9, 
  3.7836814935033092`*^9, 3.7836817856663074`*^9, 
  3.7836819131553183`*^9},ExpressionUUID->"91511c6d-c99c-451a-94b3-\
80e5c49355d0"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "86", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(16)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(01000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"128", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(20000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"135", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "91", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(30000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "170", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(11000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1820", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(10000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "368", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(40000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3740", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1122", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1001", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(02000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5304", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1326", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6435", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(10100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7020", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1638", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(21000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2380", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(01000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3328", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(20000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4096", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(10010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6552", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.776781890713786*^9, 3.783681439731824*^9, 
  3.783681493538251*^9, 3.7836817857111845`*^9, 
  3.7836819131912518`*^9},ExpressionUUID->"a69fd189-a300-4e0c-959a-\
421b77740723"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO17", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "15000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.77461370583659*^9, 3.7746137235664177`*^9}, {
   3.780161677583985*^9, 3.7801616794001293`*^9}, {3.7801617446946635`*^9, 
   3.7801617450597057`*^9}, 
   3.783681999298676*^9},ExpressionUUID->"771e5c65-a23c-4e3b-a672-\
6f18e6e5dd40"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "15"}],
   SequenceForm["Number of irreps: ", 15],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767819126141944`*^9, 3.7801616873309298`*^9, 
  3.7801617925654387`*^9, 
  3.783682043865011*^9},ExpressionUUID->"15e37967-c4b9-4227-a6b7-\
75bbd73b2150"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"43.6\"\>",
      43.5851709,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[43.5851709, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767819126141944`*^9, 3.7801616873309298`*^9, 
  3.7801617925654387`*^9, 
  3.7836820438690166`*^9},ExpressionUUID->"0b2282c8-a63e-4001-b7fe-\
94657d362bed"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "88", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(17)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(01000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", "0"},
         {
          FormBox["\<\"(20000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"152", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19", "0"},
         {
          FormBox["\<\"(00000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", "1"},
         {
          FormBox["\<\"(00100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "0"},
         {
          FormBox["\<\"(30000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"952", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "189", "0"},
         {
          FormBox["\<\"(11000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1615", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "285", "0"},
         {
          FormBox["\<\"(00010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "455", "0"},
         {
          FormBox["\<\"(10000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "768", "1"},
         {
          FormBox["\<\"(40000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4692", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1311", "0"},
         {
          FormBox["\<\"(00001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6188", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1365", "0"},
         {
          FormBox["\<\"(02000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6783", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1596", "0"},
         {
          FormBox["\<\"(10100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9044", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1995", "0"},
         {
          FormBox["\<\"(21000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11340", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2835", "0"},
         {
          FormBox["\<\"(00000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767819126353827`*^9, 3.780161687357857*^9, 
  3.780161792597351*^9, 
  3.783682043907879*^9},ExpressionUUID->"5ef5dafa-6e4f-4749-8430-\
9f865e01cb4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO18", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO8", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "10000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7801618558249955`*^9, 
  3.780161856126191*^9}},ExpressionUUID->"d26e7062-6899-4af7-92f3-\
ecc2451fd516"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "11"}],
   SequenceForm["Number of irreps: ", 11],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6153491493662033`*^9, 
  3.7801618895860815`*^9},ExpressionUUID->"064ec06d-e4aa-4740-bb13-\
cbc772a9e141"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"46.3\"\>",
      46.2678095,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[46.2678095, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6153491493662033`*^9, 
  3.78016190281918*^9},ExpressionUUID->"322c10c5-4b5e-469a-ae68-1e412a6563ea"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "21", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(18)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SO(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"153", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"170", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"816", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(300000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1122", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "209", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(110000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3060", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "560", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(100000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "800", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(020000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1900", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(000010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1820", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.615349156753117*^9, 
  3.78016190284511*^9},ExpressionUUID->"f1b26440-aa64-40d4-b29c-82c94f6d0c2f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO19", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "10000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7746137322979984`*^9, 3.7746137394077463`*^9}, {
   3.7838849516958036`*^9, 3.7838849523669777`*^9}, 3.7838850797014513`*^9, 
   3.783885140889803*^9, {3.7838852070089397`*^9, 
   3.783885207509633*^9}},ExpressionUUID->"8235e348-f70f-43fb-9a8e-\
cc9e1cc49a4f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "9"}],
   SequenceForm["Number of irreps: ", 9],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776781966623672*^9, 3.783884994982006*^9, 
  3.78388511971044*^9, 3.7838851810254326`*^9, 
  3.783885247908583*^9},ExpressionUUID->"25061e12-5b2e-4544-81f2-\
1f8fa11c06b0"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"36.4\"\>",
      36.4434892,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[36.4434892, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776781966623672*^9, 3.783884994982006*^9, 
  3.78388511971044*^9, 3.7838851810254326`*^9, 
  3.783885247912572*^9},ExpressionUUID->"4f6a578b-9022-4a38-b4df-\
88a2860894c7"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "159", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(19)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"171", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17", "0"},
         {
          FormBox["\<\"(200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "0"},
         {
          FormBox["\<\"(000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64", "1"},
         {
          FormBox["\<\"(001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"969", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "136", "0"},
         {
          FormBox["\<\"(300000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1311", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "230", "0"},
         {
          FormBox["\<\"(110000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2261", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "357", "0"},
         {
          FormBox["\<\"(000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3876", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "680", "0"},
         {
          FormBox["\<\"(100000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1664", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.776781966654917*^9, 3.783884995033904*^9, 
  3.783885119765272*^9, 3.783885181079288*^9, 
  3.7838852479624443`*^9},ExpressionUUID->"4f6cb6e7-e775-48dc-a2ab-\
7f4c5ffa07f8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO20", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "15000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613745351589*^9, 3.7746137546715827`*^9}, {
   3.783885721292697*^9, 3.783885722659067*^9}, {3.783885905406937*^9, 
   3.783885905691161*^9}, 
   3.7838866336567345`*^9},ExpressionUUID->"2ac57a7d-8742-46b2-ac8b-\
d2e7953de01e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "10"}],
   SequenceForm["Number of irreps: ", 10],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776782154149638*^9, 3.783885891393382*^9, 
  3.783886090264877*^9, 
  3.783886786286725*^9},ExpressionUUID->"5eb5015d-a134-48e4-91af-\
d532388b6ef6"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"152.0\"\>",
      151.7953476,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[151.7953476, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776782154149638*^9, 3.783885891393382*^9, 
  3.783886090264877*^9, 
  3.78388678628969*^9},ExpressionUUID->"a7b116d6-b69d-4742-af30-16746220e7a0"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "168", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(20)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"190", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(2000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"209", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0000000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "153", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(3000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(1100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "396", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4845", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "816", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(1000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1728", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13090", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2618", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.776782154180882*^9, 3.7838858914482365`*^9, 
  3.7838860903267217`*^9, 
  3.7838867863405867`*^9},ExpressionUUID->"f89c451d-81de-45f3-9fb9-\
f56822285d24"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO21", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "40000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613763608387*^9, 3.774613779610717*^9}, {
  3.783682121263158*^9, 
  3.7836821587092004`*^9}},ExpressionUUID->"2d4787fe-3dc2-4e65-90f4-\
ca67ea348d53"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "12"}],
   SequenceForm["Number of irreps: ", 12],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7518942259702253`*^9, {3.783682133854278*^9, 
   3.783682170363737*^9}},ExpressionUUID->"4b0d47af-3ffc-4a32-badd-\
49cb554150a7"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"10.6\"\>",
      10.6086496,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[10.6086496, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7518942259702253`*^9, {3.783682133854278*^9, 
   3.7836821703667135`*^9}},ExpressionUUID->"7ea56995-f574-41a2-bc99-\
103a05ca3a34"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "93", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(21)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(0100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19", "0"},
         {
          FormBox["\<\"(2000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"230", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23", "0"},
         {
          FormBox["\<\"(0000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "128", "1"},
         {
          FormBox["\<\"(0010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "171", "0"},
         {
          FormBox["\<\"(1100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3059", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "437", "0"},
         {
          FormBox["\<\"(0001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5985", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "969", "0"},
         {
          FormBox["\<\"(0200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15939", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3036", "0"},
         {
          FormBox["\<\"(0000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20349", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3876", "0"},
         {
          FormBox["\<\"(1000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3584", "1"},
         {
          FormBox["\<\"(1010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21735", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3933", "0"},
         {
          FormBox["\<\"(2100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26125", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5225", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.751894226028042*^9, {3.783682133890182*^9, 
   3.7836821703976297`*^9}},ExpressionUUID->"7ded9aa8-51db-4d3a-a249-\
55e7c61462e4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO22", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO12", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "27000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.783682305427683*^9},ExpressionUUID->"7544a714-78ba-44c8-a1a4-\
99360da79887"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "11"}],
   SequenceForm["Number of irreps: ", 11],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6153491947756987`*^9, 
  3.783682339528924*^9},ExpressionUUID->"20cb5217-29fa-49b2-a6ad-\
096faf7a700b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"105.0\"\>",
      104.6841672,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[104.6841672, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6153491947756987`*^9, 
  3.783682411261841*^9},ExpressionUUID->"da3d900c-b7d1-4985-93d3-\
b650ab7da55f"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "95", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(22)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SO(12)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(01000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(20000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(00000000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "128", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(00100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "190", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(11000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(00010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1140", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(02000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19228", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3496", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(10000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3712", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(10100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26334", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4560", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(00001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26334", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4845", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.615349206398929*^9, 
  3.783682411289767*^9},ExpressionUUID->"68d38470-911c-4b18-8b5a-\
2588fdb0ee08"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO23", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "900000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613787129409*^9, 3.7746138090421696`*^9}, {
   3.78368252070825*^9, 3.7836825219828568`*^9}, 3.78368257855354*^9, 
   3.783682690478818*^9, 3.783682738875692*^9, 
   3.7836827889942417`*^9},ExpressionUUID->"4d926033-b15f-4ad3-9a59-\
92adfe00ea50"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "24"}],
   SequenceForm["Number of irreps: ", 24],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776782584515504*^9, 3.7836825667088614`*^9, 
  3.7836826174708734`*^9, 3.7836827284873548`*^9, 3.7836827776414776`*^9, 
  3.7836828278668003`*^9},ExpressionUUID->"847b0755-9f92-4a25-806a-\
0004315ffb35"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"36.4\"\>",
      36.3604043,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[36.3604043, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776782584515504*^9, 3.7836825667088614`*^9, 
  3.7836826174708734`*^9, 3.7836827284873548`*^9, 3.7836827776414776`*^9, 
  3.783682827869793*^9},ExpressionUUID->"5f2ab0d2-5ea3-4d91-9137-\
0081c74d24d1"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "102", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(23)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(01000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"253", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "0"},
         {
          FormBox["\<\"(20000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25", "0"},
         {
          FormBox["\<\"(00100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1771", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "0"},
         {
          FormBox["\<\"(00000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2048", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "256", "1"},
         {
          FormBox["\<\"(11000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4025", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "525", "0"},
         {
          FormBox["\<\"(00010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8855", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1330", "0"},
         {
          FormBox["\<\"(02000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4000", "0"},
         {
          FormBox["\<\"(10100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5250", "0"},
         {
          FormBox["\<\"(00001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33649", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5985", "0"},
         {
          FormBox["\<\"(21000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37422", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6804", "0"},
         {
          FormBox["\<\"(10000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7680", "1"},
         {
          FormBox["\<\"(00000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"100947", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20349", "0"},
         {
          FormBox["\<\"(10010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168245", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33250", "0"},
         {
          FormBox["\<\"(01100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"240350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50350", "0"},
         {
          FormBox["\<\"(00000010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"245157", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54264", "0"},
         {
          FormBox["\<\"(12000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"284625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64125", "0"},
         {
          FormBox["\<\"(20100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"312984", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "68040", "0"},
         {
          FormBox["\<\"(01000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"471040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "99840", "1"},
         {
          FormBox["\<\"(00000001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "116280", "0"},
         {
          FormBox["\<\"(20000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"518144", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "113920", "1"},
         {
          FormBox["\<\"(10001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"664125", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "149625", "0"},
         {
          FormBox["\<\"(00000000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"817190", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "203490", "0"},
         {
          FormBox["\<\"(00200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"872850", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "217350", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767825845414667`*^9, 3.7836825667407756`*^9, 
  3.78368261750578*^9, 3.7836827285252523`*^9, 3.7836827776754093`*^9, 
  3.783682827919694*^9},ExpressionUUID->"61e709e1-724c-4ef4-a133-\
93dec3482265"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO24", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "134596"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613819734203*^9, 
  3.774613829711014*^9}},ExpressionUUID->"588646f3-d885-414c-a098-\
4b90747a8b5f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "13"}],
   SequenceForm["Number of irreps: ", 13],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767828302180395`*^9},ExpressionUUID->"e0ba67b4-c9d6-446d-9a5a-\
9e682f13eda2"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"120.0\"\>",
      120.2109345,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[120.2109345, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767828302180395`*^9},ExpressionUUID->"ce044a40-ab9a-4a87-b926-\
baca26668858"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "9", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(24)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"276", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"299", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "231", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2048", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "256", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(110000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4576", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "572", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10626", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(020000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4550", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(101000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37674", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6006", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7315", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(210000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7700", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100000000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"47104", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7936", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"134596", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26334", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7767828302492757`*^9},ExpressionUUID->"d4d80125-e200-48a3-aaa7-\
72f97b3618c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO25", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "2000000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613835296771*^9, 3.7746138442760873`*^9}, {
   3.7836828998789406`*^9, 3.7836829012024527`*^9}, 
   3.7836830785417404`*^9},ExpressionUUID->"3936fbdb-1aa1-4e23-af55-\
ddedf6de538d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "23"}],
   SequenceForm["Number of irreps: ", 23],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776783000943224*^9, 3.7836830643519382`*^9, 
  3.7836832160213594`*^9},ExpressionUUID->"7c097a8d-8a56-4307-8b70-\
47d7874bfc14"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"133.0\"\>",
      132.6328982,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[132.6328982, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776783000943224*^9, 3.7836830643519382`*^9, 
  3.783683216024351*^9},ExpressionUUID->"e9de064d-bc84-44a8-8fa6-\
74e8b32b6ddf"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "105", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(25)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"25", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23", "0"},
         {
          FormBox["\<\"(200000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"324", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27", "0"},
         {
          FormBox["\<\"(001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "253", "0"},
         {
          FormBox["\<\"(000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", "1"},
         {
          FormBox["\<\"(110000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "621", "0"},
         {
          FormBox["\<\"(000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1771", "0"},
         {
          FormBox["\<\"(020000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "0"},
         {
          FormBox["\<\"(101000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6831", "0"},
         {
          FormBox["\<\"(210000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"52026", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8671", "0"},
         {
          FormBox["\<\"(000010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"53130", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8855", "0"},
         {
          FormBox["\<\"(100000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"98304", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16384", "1"},
         {
          FormBox["\<\"(000001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"177100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33649", "0"},
         {
          FormBox["\<\"(100100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"260820", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "47817", "0"},
         {
          FormBox["\<\"(011000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"368550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71253", "0"},
         {
          FormBox["\<\"(120000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"430650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "89001", "0"},
         {
          FormBox["\<\"(201000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"476905", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95381", "0"},
         {
          FormBox["\<\"(000000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100947", "0"},
         {
          FormBox["\<\"(000000010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1081575", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "245157", "0"},
         {
          FormBox["\<\"(010000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1126400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "230912", "1"},
         {
          FormBox["\<\"(100010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1138500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "239085", "0"},
         {
          FormBox["\<\"(200000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1228800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "260096", "1"},
         {
          FormBox["\<\"(002000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1462500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "336375", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767830009744377`*^9, 3.783683064385874*^9, 
  3.783683216058261*^9},ExpressionUUID->"7d1d521b-817c-45a8-969a-\
fef1b9e094ee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO26", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO16", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "700000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}]}], "]"}]], "Input",ExpressionUUI\
D->"73c92da6-6393-4543-bf7f-655579206e0d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "13"}],
   SequenceForm["Number of irreps: ", 13],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615349210880025*^9},ExpressionUUID->"3ca12c0c-c49e-4173-ab03-\
20394b55c7af"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1080.0\"\>",
      1081.67226600000003600143827497959136962891`9.05469560785038,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    1081.67226600000003600143827497959136962891`9.05469560785038, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.615350289376862*^9},ExpressionUUID->"5e366efe-d7f8-4dd8-a127-\
2e122198f824"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "22", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(26)\\\"\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SO(16)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"325", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2600", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "276", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14950", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2024", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"52325", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7728", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10626", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1000000000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"102400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16896", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"230230", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42504", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56672", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0110000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"450450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "83853", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"657800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "134596", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615350289396453*^9},ExpressionUUID->"10aa144c-f342-47b3-883a-\
4ca7c0386d8b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO27", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "631098"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.7746138685868235`*^9, {3.7746139013027134`*^9, 
   3.7746139032533255`*^9}},ExpressionUUID->"6d08e66c-7333-4c8d-9d73-\
479717a466f9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "16"}],
   SequenceForm["Number of irreps: ", 16],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767835387346497`*^9},ExpressionUUID->"05a8c905-97d7-46f4-b299-\
b443d92ec308"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"528.0\"\>",
      527.7672835,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[527.7672835, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767835387376623`*^9},ExpressionUUID->"30c4fd37-82e4-4d94-9fea-\
ace5df165088"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "11", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(27)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(0100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"351", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25", "0"},
         {
          FormBox["\<\"(2000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"377", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29", "0"},
         {
          FormBox["\<\"(0010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "300", "0"},
         {
          FormBox["\<\"(1100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6525", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "725", "0"},
         {
          FormBox["\<\"(0000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1024", "1"},
         {
          FormBox["\<\"(0001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2300", "0"},
         {
          FormBox["\<\"(0200000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43848", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6496", "0"},
         {
          FormBox["\<\"(1010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"61074", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8700", "0"},
         {
          FormBox["\<\"(2100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70525", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10850", "0"},
         {
          FormBox["\<\"(0000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80730", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12650", "0"},
         {
          FormBox["\<\"(1000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"212992", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34816", "1"},
         {
          FormBox["\<\"(0000010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"296010", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "53130", "0"},
         {
          FormBox["\<\"(1001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"390195", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "66700", "0"},
         {
          FormBox["\<\"(0110000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"546273", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98049", "0"},
         {
          FormBox["\<\"(1200000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"631098", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120466", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7767835387735715`*^9},ExpressionUUID->"2de9c059-652e-4504-b898-\
906e63dc9dce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO28", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "756000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613907429676*^9, 
  3.7746139200764227`*^9}},ExpressionUUID->"76928609-da2b-46e5-879d-\
28bef608b9fc"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "16"}],
   SequenceForm["Number of irreps: ", 16],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767918129639916`*^9},ExpressionUUID->"497e1c37-144d-484b-bebc-\
fdc7b0e575c2"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,14,1,2.875916414152613*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.7767918133369837`*^9},ExpressionUUID->"5556ac9f-724e-44fe-9c58-\
2ad34129435d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"8250.0\"\>",
      8249.642926,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[8249.642926, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767918133399754`*^9},ExpressionUUID->"42a04753-9843-4291-8f75-\
c0e911cb6e17"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "12", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(28)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(01000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(20000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3276", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "325", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(11000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "780", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00000000000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1024", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20475", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2600", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(02000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7250", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(10100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9750", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(21000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12064", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"98280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14950", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(10000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"221184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35840", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(00000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"376740", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65780", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(10010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"471744", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78000", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(01100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"657720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "113970", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(12000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"756000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "139000", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.776791813353943*^9},ExpressionUUID->"b4b5b67f-f34b-4621-a1c8-\
d400e50e1c75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO29", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "786625"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613928253106*^9, 
  3.7746139358596706`*^9}},ExpressionUUID->"25524dab-bd80-46d4-b31f-\
ed17b7ec4991"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "15"}],
   SequenceForm["Number of irreps: ", 15],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767938194431787`*^9},ExpressionUUID->"166d05c0-5091-41e5-a3b0-\
dbad83c3fc48"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,15,2,2.875916414152613*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.7767938197144527`*^9},ExpressionUUID->"ab18d880-c7bb-4eca-a488-\
2fccc1844b95"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1820.0\"\>",
      1822.8011119,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1822.8011119, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776793819716448*^9},ExpressionUUID->"f4e10a83-8986-4bcf-aeaa-\
37b32bc032b9"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "13", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(29)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(01000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"406", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27", "0"},
         {
          FormBox["\<\"(20000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"434", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31", "0"},
         {
          FormBox["\<\"(00100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3654", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "351", "0"},
         {
          FormBox["\<\"(11000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8091", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "837", "0"},
         {
          FormBox["\<\"(00000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2048", "1"},
         {
          FormBox["\<\"(00010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23751", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2925", "0"},
         {
          FormBox["\<\"(02000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"58435", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8060", "0"},
         {
          FormBox["\<\"(10100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81809", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10881", "0"},
         {
          FormBox["\<\"(21000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"93555", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13365", "0"},
         {
          FormBox["\<\"(00001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"118755", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17550", "0"},
         {
          FormBox["\<\"(10000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"458752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "73728", "1"},
         {
          FormBox["\<\"(00000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"475020", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "80730", "0"},
         {
          FormBox["\<\"(10010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"566370", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "90675", "0"},
         {
          FormBox["\<\"(01100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"786625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "131750", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.776793819740383*^9},ExpressionUUID->"6c691a6a-7e89-432d-a46c-\
9cf3af1be387"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO30", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "100000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783426603757659*^9, 3.783426623091818*^9}, {
  3.7834301115814147`*^9, 3.7834301155105333`*^9}, {3.7834302831490264`*^9, 
  3.783430283587858*^9}},ExpressionUUID->"ad99ada4-90ec-41e9-bf70-\
d9d2bfc22691"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "9"}],
   SequenceForm["Number of irreps: ", 9],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.783430269976364*^9, 
  3.783443468586479*^9},ExpressionUUID->"1017a9a7-fdce-41a4-819d-\
b8325012d809"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,5,1,2.8802839787938062`*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.783443472921889*^9},ExpressionUUID->"c19cdfeb-7b0d-4ec7-a9e3-\
84aec75ae0eb"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"13200.0\"\>",
      13182.2788295,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[13182.2788295, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.783430269976364*^9, 
  3.7834434729538107`*^9},ExpressionUUID->"8568a8d3-32bb-4168-b944-\
5df37f30bf5f"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(30)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"435", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"464", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(001000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4060", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "378", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(110000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "896", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000000000000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2048", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3276", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(020000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8928", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(101000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"93960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12096", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7834266188026395`*^9, 3.783430107359488*^9, 
  3.783430270011304*^9, 
  3.7834434731333237`*^9},ExpressionUUID->"f8b78e65-4307-49e2-bd64-\
878478905eda"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Algebra", "[", "B", "]"}], "[", "15", "]"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "100000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783426628123061*^9, 3.7834266377487206`*^9}, {
  3.783444322759055*^9, 
  3.783444323100162*^9}},ExpressionUUID->"9efc55b6-2e2c-48aa-a1ce-\
c5271060663a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "8"}],
   SequenceForm["Number of irreps: ", 8],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7834671286298623`*^9},ExpressionUUID->"0d262fa0-c2aa-4b77-81e0-\
61ebd75e4da0"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,7,2,2.8802839787938062`*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.7834671339285607`*^9},ExpressionUUID->"212b1fed-2a5b-42d4-805e-\
19c0c06f5540"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"22800.0\"\>",
      22759.506571,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[22759.506571, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783467133933566*^9},ExpressionUUID->"ea66be39-fca8-41d6-ab58-\
3ddf4f6624cf"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(31)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(010000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"465", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29", "0"},
         {
          FormBox["\<\"(200000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33", "0"},
         {
          FormBox["\<\"(001000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "406", "0"},
         {
          FormBox["\<\"(110000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9889", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "957", "0"},
         {
          FormBox["\<\"(000100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31465", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3654", "0"},
         {
          FormBox["\<\"(000000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32768", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4096", "1"},
         {
          FormBox["\<\"(020000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9856", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7834671341270294`*^9},ExpressionUUID->"1e87073a-32c5-4e9c-918a-\
b7b8c28bda72"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Algebra", "[", "D", "]"}], "[", "16", "]"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "500000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.791744029373186*^9, 3.791744030302674*^9}, {
   3.791744097446659*^9, 3.791744098079734*^9}, 3.791744152049265*^9, {
   3.7917475777309713`*^9, 3.7917475859976435`*^9}, {3.7917477806909337`*^9, 
   3.7917477831285105`*^9}, {3.7917478379099507`*^9, 
   3.7611675322437716`*^9}},ExpressionUUID->"0969e006-3568-4e47-a32f-\
564e93179526"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "8"}],
   SequenceForm["Number of irreps: ", 8],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7917476911874013`*^9, 3.7917478126724095`*^9, {3.7917478696033525`*^9, 
   3.761167005622816*^9}, 
   3.76116756037948*^9},ExpressionUUID->"14f06483-8896-49be-9a00-\
becc36f0bfbc"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"26.8\"\>",
      26.7528027,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[26.7528027, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7917476911874013`*^9, 3.7917478126724095`*^9, {3.7917478696033525`*^9, 
   3.761167005622816*^9}, 
   3.7611675603814754`*^9},ExpressionUUID->"a5d5cf63-6573-40df-9b2c-\
bfa70ff76879"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"SO(32)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0100000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0010000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "435", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(1100000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1020", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0000000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32768", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4096", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0001000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4060", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(1010000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"122264", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14790", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(0000100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"201376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27405", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.791744139624708*^9, 3.7917475745344057`*^9, 3.7917476912093782`*^9, 
   3.7917478127132993`*^9, {3.79174786961532*^9, 3.761167005883136*^9}, 
   3.7611675604054503`*^9},ExpressionUUID->"2e7f534b-48f5-436c-9d61-\
0a3ae3a035b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sp(N)", "Section",ExpressionUUID->"8bf7303f-54be-4ad8-bf52-5df079b12632"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp4", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1785"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "20"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.780162031318922*^9, 3.7801620316021986`*^9}, {
  3.783530874976043*^9, 
  3.783530876461076*^9}},ExpressionUUID->"4e934d2e-db07-4974-bfa9-\
d84ed9477a2c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "97"}],
   SequenceForm["Number of irreps: ", 97],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615350289588942*^9, 3.780162032802199*^9, 
  3.783530877474388*^9},ExpressionUUID->"42da8dd1-50e4-43e9-ad83-\
3305142bd58c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.1\"\>",
      0.0627584,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.0627584, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615350289588942*^9, 3.780162032802199*^9, 
  3.783530877496335*^9},ExpressionUUID->"8c6c413f-5899-4abe-b351-\
422a231fc4cd"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "18", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(4)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(01)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2", "0"},
         {
          FormBox["\<\"(20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "0"},
         {
          FormBox["\<\"(02)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0"},
         {
          FormBox["\<\"(11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "1"},
         {
          FormBox["\<\"(30)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "1"},
         {
          FormBox["\<\"(03)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", "0"},
         {
          FormBox["\<\"(21)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42", "0"},
         {
          FormBox["\<\"(40)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", "0"},
         {
          FormBox["\<\"(12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "58", "1"},
         {
          FormBox["\<\"(04)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "154", "0"},
         {
          FormBox["\<\"(50)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "1"},
         {
          FormBox["\<\"(31)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "112", "1"},
         {
          FormBox["\<\"(13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "188", "1"},
         {
          FormBox["\<\"(22)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "162", "0"},
         {
          FormBox["\<\"(60)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", "0"},
         {
          FormBox["\<\"(05)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"91", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", "0"},
         {
          FormBox["\<\"(41)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", "0"},
         {
          FormBox["\<\"(70)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "1"},
         {
          FormBox["\<\"(32)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "371", "1"},
         {
          FormBox["\<\"(14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "483", "1"},
         {
          FormBox["\<\"(06)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "756", "0"},
         {
          FormBox["\<\"(23)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"154", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "0"},
         {
          FormBox["\<\"(51)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "1"},
         {
          FormBox["\<\"(80)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0"},
         {
          FormBox["\<\"(07)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"204", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1428", "0"},
         {
          FormBox["\<\"(42)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "748", "0"},
         {
          FormBox["\<\"(90)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", "1"},
         {
          FormBox["\<\"(15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1064", "1"},
         {
          FormBox["\<\"(61)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "924", "0"},
         {
          FormBox["\<\"(33)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "960", "1"},
         {
          FormBox["\<\"(24)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1092", "0"},
         {
          FormBox["\<\"(08)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"285", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2508", "0"},
         {
          FormBox["\<\"(10, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "0"},
         {
          FormBox["\<\"(71)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1584", "1"},
         {
          FormBox["\<\"(52)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"324", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1377", "1"},
         {
          FormBox["\<\"(16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", "1"},
         {
          FormBox["\<\"(11, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "1"},
         {
          FormBox["\<\"(09)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"385", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4158", "0"},
         {
          FormBox["\<\"(43)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"390", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1794", "0"},
         {
          FormBox["\<\"(25)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2268", "0"},
         {
          FormBox["\<\"(34)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2121", "1"},
         {
          FormBox["\<\"(81)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"429", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2574", "0"},
         {
          FormBox["\<\"(62)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2366", "0"},
         {
          FormBox["\<\"(12, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4368", "0"},
         {
          FormBox["\<\"(17)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3816", "1"},
         {
          FormBox["\<\"(0, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"506", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6578", "0"},
         {
          FormBox["\<\"(53)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3108", "1"},
         {
          FormBox["\<\"(91)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", "1"},
         {
          FormBox["\<\"(13, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6188", "1"},
         {
          FormBox["\<\"(26)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"595", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4284", "0"},
         {
          FormBox["\<\"(72)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"616", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3850", "1"},
         {
          FormBox["\<\"(44)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3750", "0"},
         {
          FormBox["\<\"(35)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4192", "1"},
         {
          FormBox["\<\"(0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "0"},
         {
          FormBox["\<\"(18)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"660", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6501", "1"},
         {
          FormBox["\<\"(14, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8568", "0"},
         {
          FormBox["\<\"(10, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6006", "0"},
         {
          FormBox["\<\"(63)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"770", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5082", "0"},
         {
          FormBox["\<\"(82)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"810", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5994", "0"},
         {
          FormBox["\<\"(15, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"816", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11628", "1"},
         {
          FormBox["\<\"(0, 12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"819", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14742", "0"},
         {
          FormBox["\<\"(27)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"836", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7524", "0"},
         {
          FormBox["\<\"(54)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6204", "1"},
         {
          FormBox["\<\"(19)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10516", "1"},
         {
          FormBox["\<\"(11, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8736", "1"},
         {
          FormBox["\<\"(36)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7623", "1"},
         {
          FormBox["\<\"(45)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"935", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7106", "0"},
         {
          FormBox["\<\"(16, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"969", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15504", "0"},
         {
          FormBox["\<\"(0, 13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1015", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21112", "0"},
         {
          FormBox["\<\"(73)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7936", "1"},
         {
          FormBox["\<\"(92)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8996", "1"},
         {
          FormBox["\<\"(12, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12376", "0"},
         {
          FormBox["\<\"(28)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1134", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12474", "0"},
         {
          FormBox["\<\"(17, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20349", "1"},
         {
          FormBox["\<\"(1, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1144", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16302", "1"},
         {
          FormBox["\<\"(64)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1190", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9758", "0"},
         {
          FormBox["\<\"(0, 14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29512", "0"},
         {
          FormBox["\<\"(37)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12992", "1"},
         {
          FormBox["\<\"(55)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1296", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11340", "1"},
         {
          FormBox["\<\"(10, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1309", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13090", "0"},
         {
          FormBox["\<\"(83)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1326", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11934", "0"},
         {
          FormBox["\<\"(46)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12502", "0"},
         {
          FormBox["\<\"(18, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26334", "0"},
         {
          FormBox["\<\"(13, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17136", "1"},
         {
          FormBox["\<\"(1, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24388", "1"},
         {
          FormBox["\<\"(29)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19734", "0"},
         {
          FormBox["\<\"(0, 15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "40392", "0"},
         {
          FormBox["\<\"(19, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33649", "1"},
         {
          FormBox["\<\"(74)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14742", "1"},
         {
          FormBox["\<\"(14, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1615", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23256", "0"},
         {
          FormBox["\<\"(11, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18549", "1"},
         {
          FormBox["\<\"(93)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17388", "1"},
         {
          FormBox["\<\"(38)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21021", "1"},
         {
          FormBox["\<\"(65)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17290", "0"},
         {
          FormBox["\<\"(20, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1771", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42504", "0"},
         {
          FormBox["\<\"(0, 16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1785", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54264", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6153502896881237`*^9, 3.7801620329268866`*^9, 
  3.783530877601057*^9},ExpressionUUID->"145960c5-399f-4fa6-89ec-\
b93e469a77df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp6", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "15750"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "20"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.7801621143519044`*^9, {3.780162174001089*^9, 3.780162174371131*^9}, {
   3.780162206287122*^9, 3.780162206554454*^9}, {3.783530893687018*^9, 
   3.7835308966630926`*^9}},ExpressionUUID->"a022b127-c1d2-4dc0-945d-\
66c77b142709"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.61535029011917*^9, 3.780162115584797*^9, 
  3.7801621756459455`*^9, 3.7801622069763994`*^9, 
  3.7835308977960606`*^9},ExpressionUUID->"6a4d383a-98ae-4ac8-99bc-\
01eb6ec92d3b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.5\"\>",
      0.4950869,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.4950869, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.61535029011917*^9, 3.780162115584797*^9, 
  3.7801621756459455`*^9, 3.7801622069763994`*^9, 
  3.783530897815979*^9},ExpressionUUID->"92948178-9130-4e3c-b933-\
4845179aeca7"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "19", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(6)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "0"},
         {
          FormBox["\<\"(001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5", "1"},
         {
          FormBox["\<\"(200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "0"},
         {
          FormBox["\<\"(300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36", "1"},
         {
          FormBox["\<\"(110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", "1"},
         {
          FormBox["\<\"(101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "40", "0"},
         {
          FormBox["\<\"(002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72", "0"},
         {
          FormBox["\<\"(020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"90", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", "0"},
         {
          FormBox["\<\"(011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "93", "1"},
         {
          FormBox["\<\"(400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "0"},
         {
          FormBox["\<\"(210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "144", "0"},
         {
          FormBox["\<\"(201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "180", "1"},
         {
          FormBox["\<\"(500)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "1"},
         {
          FormBox["\<\"(003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", "1"},
         {
          FormBox["\<\"(120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "325", "1"},
         {
          FormBox["\<\"(102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "423", "1"},
         {
          FormBox["\<\"(030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"385", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "440", "0"},
         {
          FormBox["\<\"(310)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"448", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", "1"},
         {
          FormBox["\<\"(600)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0"},
         {
          FormBox["\<\"(111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", "0"},
         {
          FormBox["\<\"(301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"525", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "600", "0"},
         {
          FormBox["\<\"(012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0"},
         {
          FormBox["\<\"(021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"616", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "748", "1"},
         {
          FormBox["\<\"(700)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "1"},
         {
          FormBox["\<\"(220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1144", "0"},
         {
          FormBox["\<\"(410)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "0"},
         {
          FormBox["\<\"(004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2288", "0"},
         {
          FormBox["\<\"(202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1078", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "0"},
         {
          FormBox["\<\"(401)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1650", "1"},
         {
          FormBox["\<\"(040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1274", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2184", "0"},
         {
          FormBox["\<\"(800)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3432", "0"},
         {
          FormBox["\<\"(130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1952", "1"},
         {
          FormBox["\<\"(211)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1815", "1"},
         {
          FormBox["\<\"(103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2508", "0"},
         {
          FormBox["\<\"(510)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3168", "1"},
         {
          FormBox["\<\"(013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4147", "1"},
         {
          FormBox["\<\"(900)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6435", "1"},
         {
          FormBox["\<\"(320)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2016", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3216", "1"},
         {
          FormBox["\<\"(501)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3960", "0"},
         {
          FormBox["\<\"(031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3900", "1"},
         {
          FormBox["\<\"(121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2205", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3360", "0"},
         {
          FormBox["\<\"(112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3680", "1"},
         {
          FormBox["\<\"(022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2457", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4680", "0"},
         {
          FormBox["\<\"(302)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2464", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4400", "1"},
         {
          FormBox["\<\"(005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2548", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8190", "1"},
         {
          FormBox["\<\"(610)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6864", "0"},
         {
          FormBox["\<\"(10, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11440", "0"},
         {
          FormBox["\<\"(311)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3072", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5120", "0"},
         {
          FormBox["\<\"(230)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3276", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5928", "0"},
         {
          FormBox["\<\"(050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3528", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8400", "0"},
         {
          FormBox["\<\"(601)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8580", "1"},
         {
          FormBox["\<\"(203)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3744", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8112", "1"},
         {
          FormBox["\<\"(420)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3900", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7800", "0"},
         {
          FormBox["\<\"(104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10582", "1"},
         {
          FormBox["\<\"(140)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4116", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8526", "1"},
         {
          FormBox["\<\"(11, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19448", "1"},
         {
          FormBox["\<\"(402)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4914", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10764", "0"},
         {
          FormBox["\<\"(710)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13728", "1"},
         {
          FormBox["\<\"(221)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5460", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10270", "1"},
         {
          FormBox["\<\"(014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5460", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16120", "0"},
         {
          FormBox["\<\"(006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5712", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24480", "0"},
         {
          FormBox["\<\"(212)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11440", "0"},
         {
          FormBox["\<\"(411)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6006", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12441", "1"},
         {
          FormBox["\<\"(701)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6006", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17160", "0"},
         {
          FormBox["\<\"(12, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6188", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31824", "0"},
         {
          FormBox["\<\"(041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15450", "1"},
         {
          FormBox["\<\"(330)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14880", "1"},
         {
          FormBox["\<\"(520)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16995", "1"},
         {
          FormBox["\<\"(131)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15360", "0"},
         {
          FormBox["\<\"(113)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17408", "0"},
         {
          FormBox["\<\"(023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7392", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20240", "1"},
         {
          FormBox["\<\"(032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19800", "0"},
         {
          FormBox["\<\"(810)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25740", "0"},
         {
          FormBox["\<\"(303)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8190", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21060", "0"},
         {
          FormBox["\<\"(122)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8316", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18810", "1"},
         {
          FormBox["\<\"(060)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26928", "0"},
         {
          FormBox["\<\"(13, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50388", "1"},
         {
          FormBox["\<\"(502)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8918", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23569", "1"},
         {
          FormBox["\<\"(240)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23400", "0"},
         {
          FormBox["\<\"(801)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32175", "1"},
         {
          FormBox["\<\"(105)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9828", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35568", "0"},
         {
          FormBox["\<\"(204)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10395", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31680", "0"},
         {
          FormBox["\<\"(511)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27136", "0"},
         {
          FormBox["\<\"(150)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29952", "1"},
         {
          FormBox["\<\"(321)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11319", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25872", "0"},
         {
          FormBox["\<\"(620)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34100", "0"},
         {
          FormBox["\<\"(007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11628", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "63954", "1"},
         {
          FormBox["\<\"(14, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11628", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77520", "0"},
         {
          FormBox["\<\"(910)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11648", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45760", "1"},
         {
          FormBox["\<\"(312)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29088", "1"},
         {
          FormBox["\<\"(430)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12375", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33000", "0"},
         {
          FormBox["\<\"(015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12852", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51102", "1"},
         {
          FormBox["\<\"(901)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "57200", "0"},
         {
          FormBox["\<\"(602)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15092", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "47432", "0"},
         {
          FormBox["\<\"(15, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "116280", "1"},
         {
          FormBox["\<\"(051)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15708", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50490", "1"},
         {
          FormBox["\<\"(403)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "47625", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.61535029021416*^9, 3.780162115716467*^9, 
  3.7801621757796106`*^9, 3.7801622071180444`*^9, 
  3.7835308979147496`*^9},ExpressionUUID->"25671b72-0603-4e79-96bb-\
6fdea94caf7b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp8", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "12012"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "10"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.780162298375143*^9, 3.7801623184047117`*^9}, {
  3.780162403191533*^9, 3.780162430741689*^9}, {3.783530914630989*^9, 
  3.7835309161659174`*^9}},ExpressionUUID->"fb3dd395-0c45-4640-9e29-\
2c0b16a330c9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "49"}],
   SequenceForm["Number of irreps: ", 49],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61535029133097*^9, {3.780162304340231*^9, 3.780162319452093*^9}, {
   3.7801624049810286`*^9, 3.780162432036453*^9}, 
   3.783530917627013*^9},ExpressionUUID->"b60d7e43-f5e8-4b55-b430-\
e09e384b6143"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.8\"\>",
      0.7966417,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.7966417, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61535029133097*^9, {3.780162304340231*^9, 3.780162319452093*^9}, {
   3.7801624049810286`*^9, 3.780162432036453*^9}, 
   3.783530917629998*^9},ExpressionUUID->"fba11418-71e6-4485-96a4-\
4a3a5e3e1f16"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "20", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(8)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "0"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "0"},
         {
          FormBox["\<\"(0001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0"},
         {
          FormBox["\<\"(0010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "1"},
         {
          FormBox["\<\"(3000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "1"},
         {
          FormBox["\<\"(1100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", "1"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"288", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", "1"},
         {
          FormBox["\<\"(0200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"308", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "154", "0"},
         {
          FormBox["\<\"(1010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", "0"},
         {
          FormBox["\<\"(4000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "0"},
         {
          FormBox["\<\"(2100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "0"},
         {
          FormBox["\<\"(0002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "451", "1"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "484", "0"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "715", "1"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "550", "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "748", "1"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1155", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "770", "0"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1232", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "770", "1"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1029", "1"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "1"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1820", "0"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5005", "1"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "1"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "0"},
         {
          FormBox["\<\"(1002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3542", "1"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3072", "0"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3325", "1"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", "0"},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4719", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6292", "0"},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4026", "1"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4914", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4368", "0"},
         {
          FormBox["\<\"(1011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6237", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5544", "0"},
         {
          FormBox["\<\"(8000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6435", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11440", "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6552", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5915", "1"},
         {
          FormBox["\<\"(0201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7020", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6630", "0"},
         {
          FormBox["\<\"(0030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9009", "1"},
         {
          FormBox["\<\"(4001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "0"},
         {
          FormBox["\<\"(0102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "1"},
         {
          FormBox["\<\"(1300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9408", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9800", "1"},
         {
          FormBox["\<\"(5100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12012", "1"},
         {
          FormBox["\<\"(0120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10010", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "0"},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10296", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12727", "1"},
         {
          FormBox["\<\"(0400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11340", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13860", "0"},
         {
          FormBox["\<\"(9000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24310", "1"},
         {
          FormBox["\<\"(0021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12012", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14014", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6153502913819637`*^9, {3.7801623044240217`*^9, 3.7801623195239477`*^9}, {
   3.780162405082774*^9, 3.780162432128223*^9}, 
   3.783530917693839*^9},ExpressionUUID->"c98e9a60-4ace-4d99-bb40-\
ac3d21ecdd58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp10", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "54912"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "10"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7801626015885983`*^9, 3.780162604693592*^9}, {
  3.7835309288809195`*^9, 
  3.7835309302652245`*^9}},ExpressionUUID->"9627a7a3-bd0c-4472-88d1-\
c46e3fb9322d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "49"}],
   SequenceForm["Number of irreps: ", 49],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6153502995032454`*^9, 3.780162606928007*^9, 
  3.78353094028244*^9},ExpressionUUID->"71993968-4a57-4e9d-b08e-28fafef6fa53"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"9.2\"\>",
      9.1652968,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[9.1652968, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6153502995032454`*^9, 3.780162606928007*^9, 
  3.783530940301401*^9},ExpressionUUID->"38adc620-6bbb-4a98-86b9-\
0abee310ac4b"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "21", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(10)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(01000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "0"},
         {
          FormBox["\<\"(20000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "0"},
         {
          FormBox["\<\"(00100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"110", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27", "1"},
         {
          FormBox["\<\"(00001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"132", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42", "1"},
         {
          FormBox["\<\"(00010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "48", "0"},
         {
          FormBox["\<\"(30000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78", "1"},
         {
          FormBox["\<\"(11000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "96", "1"},
         {
          FormBox["\<\"(40000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", "0"},
         {
          FormBox["\<\"(02000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "312", "0"},
         {
          FormBox["\<\"(10100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"891", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", "0"},
         {
          FormBox["\<\"(10001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1155", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "0"},
         {
          FormBox["\<\"(10010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1408", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "576", "1"},
         {
          FormBox["\<\"(21000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "624", "0"},
         {
          FormBox["\<\"(50000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1365", "1"},
         {
          FormBox["\<\"(01100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2860", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1326", "1"},
         {
          FormBox["\<\"(00200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2184", "0"},
         {
          FormBox["\<\"(20100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4212", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2106", "1"},
         {
          FormBox["\<\"(01001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2301", "1"},
         {
          FormBox["\<\"(12000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2478", "1"},
         {
          FormBox["\<\"(00002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4719", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3432", "0"},
         {
          FormBox["\<\"(31000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2912", "1"},
         {
          FormBox["\<\"(01010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2548", "0"},
         {
          FormBox["\<\"(60000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4368", "0"},
         {
          FormBox["\<\"(20001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3276", "1"},
         {
          FormBox["\<\"(20010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6864", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3744", "0"},
         {
          FormBox["\<\"(00020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7865", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "0"},
         {
          FormBox["\<\"(03000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8250", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5400", "0"},
         {
          FormBox["\<\"(00101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8580", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5304", "0"},
         {
          FormBox["\<\"(00110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9152", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5408", "1"},
         {
          FormBox["\<\"(00011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9438", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6435", "1"},
         {
          FormBox["\<\"(70000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12376", "1"},
         {
          FormBox["\<\"(41000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10920", "0"},
         {
          FormBox["\<\"(30100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15015", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9828", "0"},
         {
          FormBox["\<\"(22000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17820", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12312", "0"},
         {
          FormBox["\<\"(11100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10752", "0"},
         {
          FormBox["\<\"(30001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21021", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15288", "0"},
         {
          FormBox["\<\"(80000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31824", "0"},
         {
          FormBox["\<\"(30010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17472", "1"},
         {
          FormBox["\<\"(10200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28028", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19110", "1"},
         {
          FormBox["\<\"(11001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18944", "0"},
         {
          FormBox["\<\"(11010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32340", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20874", "1"},
         {
          FormBox["\<\"(02100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25596", "1"},
         {
          FormBox["\<\"(51000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36608", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34944", "1"},
         {
          FormBox["\<\"(10002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32604", "1"},
         {
          FormBox["\<\"(13000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34176", "1"},
         {
          FormBox["\<\"(40100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36855", "1"},
         {
          FormBox["\<\"(90000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "75582", "1"},
         {
          FormBox["\<\"(32000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "47424", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.615350299553342*^9, 3.7801626069788795`*^9, 
  3.783530940355245*^9},ExpressionUUID->"8c1a0005-c22b-4d76-a8f7-\
3d97b1daa99c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp12", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "100000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.7823137298658915`*^9, {3.7823137736258144`*^9, 3.7823137738761883`*^9}, {
   3.782314078313467*^9, 3.782314078649582*^9}, {3.7835361881208057`*^9, 
   3.783536192118185*^9}, {3.7835364079972396`*^9, 
   3.783536408588664*^9}},ExpressionUUID->"a5f4d183-bd8a-4966-9b16-\
9b82b594d82d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "43"}],
   SequenceForm["Number of irreps: ", 43],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615350323828272*^9, 3.782313754214781*^9, 
  3.782313802147484*^9, 3.782314081307629*^9, 3.7835362155678062`*^9, 
  3.783536411137909*^9},ExpressionUUID->"99733039-852c-48d9-93e2-\
071e2fb998fe"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.0\"\>",
      0.0093165,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.0093165, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615350323828272*^9, 3.782313754214781*^9, 
  3.782313802147484*^9, 3.782314081307629*^9, 3.7835362155678062`*^9, 
  3.7835364111568656`*^9},ExpressionUUID->"0473210f-d00b-47ac-a29b-\
f378849e6f94"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "44", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(12)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "0"},
         {
          FormBox["\<\"(200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0"},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"208", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "44", "1"},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "1"},
         {
          FormBox["\<\"(000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"429", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "110", "0"},
         {
          FormBox["\<\"(000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"429", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "132", "0"},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", "1"},
         {
          FormBox["\<\"(000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"572", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "1"},
         {
          FormBox["\<\"(400000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1365", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "560", "0"},
         {
          FormBox["\<\"(020000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "550", "0"},
         {
          FormBox["\<\"(101000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "616", "0"},
         {
          FormBox["\<\"(210000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1050", "0"},
         {
          FormBox["\<\"(100100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "1"},
         {
          FormBox["\<\"(500000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2380", "1"},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4576", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1848", "1"},
         {
          FormBox["\<\"(100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6006", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2310", "0"},
         {
          FormBox["\<\"(011000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3050", "1"},
         {
          FormBox["\<\"(201000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4620", "1"},
         {
          FormBox["\<\"(120000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5060", "1"},
         {
          FormBox["\<\"(310000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11648", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5600", "1"},
         {
          FormBox["\<\"(600000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8568", "0"},
         {
          FormBox["\<\"(002000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6300", "0"},
         {
          FormBox["\<\"(010100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18954", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8262", "0"},
         {
          FormBox["\<\"(010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10450", "0"},
         {
          FormBox["\<\"(030000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13090", "0"},
         {
          FormBox["\<\"(200100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"25025", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11550", "0"},
         {
          FormBox["\<\"(200001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27027", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13860", "0"},
         {
          FormBox["\<\"(010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12848", "1"},
         {
          FormBox["\<\"(700000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27132", "1"},
         {
          FormBox["\<\"(200010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17325", "1"},
         {
          FormBox["\<\"(410000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"38675", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23800", "0"},
         {
          FormBox["\<\"(000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40898", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28314", "0"},
         {
          FormBox["\<\"(001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22120", "1"},
         {
          FormBox["\<\"(301000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24640", "0"},
         {
          FormBox["\<\"(000200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"49686", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28028", "0"},
         {
          FormBox["\<\"(220000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"51051", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28798", "0"},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"57200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31900", "1"},
         {
          FormBox["\<\"(111000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"57344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28672", "0"},
         {
          FormBox["\<\"(001010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70070", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "37730", "0"},
         {
          FormBox["\<\"(000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78078", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50050", "0"},
         {
          FormBox["\<\"(000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"89232", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "58916", "1"},
         {
          FormBox["\<\"(000101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"92950", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "57200", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.615350323864009*^9, 3.7823137543125277`*^9, 
  3.782313802280137*^9, 3.7823140813735294`*^9, 3.78353621563865*^9, 
  3.7835364112097197`*^9},ExpressionUUID->"6714a411-8c1b-4f08-b399-\
a4d4af0f8057"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp14", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "30000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.78353656104824*^9, 3.783536561344453*^9}, {
  3.783536613500105*^9, 
  3.7835366142640495`*^9}},ExpressionUUID->"68d2ca47-790e-4517-804f-\
4ec62dfbee53"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "23"}],
   SequenceForm["Number of irreps: ", 23],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615350356413611*^9, 3.783536588838689*^9, 
  3.783536642714692*^9},ExpressionUUID->"262d4120-546c-42fb-ba2c-\
941132b077ab"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"25.1\"\>",
      25.1156202,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[25.1156202, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615350356413611*^9, 3.783536588838689*^9, 
  3.7835366427176847`*^9},ExpressionUUID->"c088337d-1441-4ffa-b1b9-\
2ce87ce17f5a"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "46", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(14)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"90", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "0"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "0"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65", "1"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "136", "1"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "192", "1"},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"910", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "208", "0"},
         {
          FormBox["\<\"(0000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "429", "1"},
         {
          FormBox["\<\"(0000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1638", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "429", "1"},
         {
          FormBox["\<\"(0000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "572", "0"},
         {
          FormBox["\<\"(4000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "816", "0"},
         {
          FormBox["\<\"(0200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3094", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "884", "0"},
         {
          FormBox["\<\"(1010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3900", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1040", "0"},
         {
          FormBox["\<\"(2100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5355", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1632", "0"},
         {
          FormBox["\<\"(5000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3876", "1"},
         {
          FormBox["\<\"(1001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3328", "1"},
         {
          FormBox["\<\"(0110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17850", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6035", "1"},
         {
          FormBox["\<\"(1000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18018", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6864", "0"},
         {
          FormBox["\<\"(1000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20020", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6864", "0"},
         {
          FormBox["\<\"(3100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9792", "1"},
         {
          FormBox["\<\"(1200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24570", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9243", "1"},
         {
          FormBox["\<\"(2010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8840", "1"},
         {
          FormBox["\<\"(1000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9152", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6153503564476767`*^9, 3.783536588871601*^9, 
  3.783536642761568*^9},ExpressionUUID->"e55a4d9a-6a18-4b3c-8359-\
1f3cafb04424"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp16", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "25000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774613969989395*^9, 3.774613996282028*^9}, {
  3.7835367516956396`*^9, 3.783536753266465*^9}, {3.7835368243412504`*^9, 
  3.7835368248518934`*^9}, {3.7835368780573835`*^9, 3.7835368800759897`*^9}, {
  3.783536936024625*^9, 
  3.783536936441517*^9}},ExpressionUUID->"06ae9cc2-7c8f-4991-acc6-\
2ea11dc4edc0"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "16"}],
   SequenceForm["Number of irreps: ", 16],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767939272101154`*^9, 3.7835367984109974`*^9, 
  3.783536869182204*^9, 3.783536925194108*^9, 
  3.783536981085909*^9},ExpressionUUID->"16bde296-f879-4d57-bee2-\
c123c8a8dd45"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"40.8\"\>",
      40.829893,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[40.829893, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767939272101154`*^9, 3.7835367984109974`*^9, 
  3.783536869182204*^9, 3.783536925194108*^9, 
  3.783536981089898*^9},ExpressionUUID->"038d0e03-7586-4a5c-a00a-\
0efcf1c066b1"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "51", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(16)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(01000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"119", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0"},
         {
          FormBox["\<\"(20000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18", "0"},
         {
          FormBox["\<\"(00100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "90", "1"},
         {
          FormBox["\<\"(30000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"816", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "171", "1"},
         {
          FormBox["\<\"(11000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", "1"},
         {
          FormBox["\<\"(00010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "350", "0"},
         {
          FormBox["\<\"(00001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3808", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "910", "1"},
         {
          FormBox["\<\"(40000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3876", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1140", "0"},
         {
          FormBox["\<\"(00000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4862", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1430", "0"},
         {
          FormBox["\<\"(02000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1330", "0"},
         {
          FormBox["\<\"(00000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6188", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1638", "0"},
         {
          FormBox["\<\"(10100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6885", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1620", "0"},
         {
          FormBox["\<\"(00000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7072", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "1"},
         {
          FormBox["\<\"(21000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9044", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2394", "0"},
         {
          FormBox["\<\"(10010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22848", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6300", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767939272413635`*^9, 3.7835367984389505`*^9, 
  3.7835368692111535`*^9, 3.783536925225026*^9, 
  3.783536981114833*^9},ExpressionUUID->"a958f238-aed9-42eb-8227-\
7668c888f819"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp18", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "20000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783529194192991*^9, 3.783529198574318*^9}, {
  3.783535470113508*^9, 
  3.783535470462595*^9}},ExpressionUUID->"e73fd28e-bc0d-4080-8aa8-\
b63e389eda7d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "14"}],
   SequenceForm["Number of irreps: ", 14],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.783531233688199*^9, 
  3.783535747855708*^9},ExpressionUUID->"2464f5d7-7512-480e-a283-\
2fcc6c61af88"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"273.0\"\>",
      273.1847749,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[273.1847749, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.783531233688199*^9, 
  3.783535747859697*^9},ExpressionUUID->"67f387c9-e5a3-4beb-88ce-\
135e0119f011"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "39", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(18)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"152", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "0"},
         {
          FormBox["\<\"(200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"171", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "0"},
         {
          FormBox["\<\"(001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"798", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "119", "1"},
         {
          FormBox["\<\"(300000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "1"},
         {
          FormBox["\<\"(110000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "1"},
         {
          FormBox["\<\"(000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2907", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "544", "0"},
         {
          FormBox["\<\"(400000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5985", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "0"},
         {
          FormBox["\<\"(000010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1700", "1"},
         {
          FormBox["\<\"(020000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1904", "0"},
         {
          FormBox["\<\"(101000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11305", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2380", "0"},
         {
          FormBox["\<\"(210000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3360", "0"},
         {
          FormBox["\<\"(000001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3808", "0"},
         {
          FormBox["\<\"(000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16796", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4862", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7835312337121377`*^9, 
  3.7835357478836374`*^9},ExpressionUUID->"345125a7-c3c8-4213-9db6-\
ebac61307ff8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp20", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "12000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783529213311617*^9, 3.783529219068632*^9}, {
  3.7835312557418528`*^9, 
  3.783531260918015*^9}},ExpressionUUID->"fa2b383e-fb64-401d-88bf-\
d54251cfec61"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "8"}],
   SequenceForm["Number of irreps: ", 8],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783533010896081*^9},ExpressionUUID->"b3ad169e-ad50-4b8c-a3d1-\
abcb2ea39110"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,26,4,2.8802839787938062`*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.7835330109190207`*^9},ExpressionUUID->"d8f55167-632b-4268-bd92-\
737e0025e7b2"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1690.0\"\>",
      1688.2875557,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1688.2875557, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783533010921017*^9},ExpressionUUID->"7b259555-82cf-4394-b957-\
be02b65917af"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "24", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(20)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(0100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18", "0"},
         {
          FormBox["\<\"(2000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22", "0"},
         {
          FormBox["\<\"(0010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "152", "1"},
         {
          FormBox["\<\"(3000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "253", "1"},
         {
          FormBox["\<\"(1100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "396", "1"},
         {
          FormBox["\<\"(0001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4655", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "798", "0"},
         {
          FormBox["\<\"(4000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8855", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2024", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.783533010928993*^9},ExpressionUUID->"b30c5206-3b03-4691-9432-\
57dd7f69678a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp22", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "24794"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835292330477858`*^9, 3.7835292333758345`*^9}, {
  3.7835330517222166`*^9, 3.7835330664915514`*^9}, {3.7839447455107913`*^9, 
  3.783944745866774*^9}, {3.7839465263245873`*^9, 3.7839465281715775`*^9}, {
  3.783946609627557*^9, 
  3.7839466107295504`*^9}},ExpressionUUID->"7c6567e9-09d3-429f-822a-\
4dddcb3c9d86"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "9"}],
   SequenceForm["Number of irreps: ", 9],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783947633692974*^9},ExpressionUUID->"292f0c17-f612-4b0b-b398-\
9cc789958af8"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "NumberForm","sigz",
    "\"In addition to the number of digits requested, one or more zeros will \
appear as placeholders.\"",2,287,49,2.880405022486932*^19,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.7839476340030975`*^9},ExpressionUUID->"573e52ab-b97b-4bc9-b251-\
7a1d2f9882cd"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1020.0\"\>",
      1017.7026402,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1017.7026402, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783947634006089*^9},ExpressionUUID->"b79b3489-621e-47cc-b334-\
14b3fb7af658"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "224", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(22)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(01000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"230", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "0"},
         {
          FormBox["\<\"(20000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"253", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", "0"},
         {
          FormBox["\<\"(00100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1518", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "189", "1"},
         {
          FormBox["\<\"(30000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "300", "1"},
         {
          FormBox["\<\"(11000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", "1"},
         {
          FormBox["\<\"(00010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7084", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1120", "0"},
         {
          FormBox["\<\"(02000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19250", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3500", "0"},
         {
          FormBox["\<\"(00001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24794", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4655", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.783534164181114*^9, 3.783945673468737*^9, 
  3.783946606683593*^9, 
  3.7839476340150642`*^9},ExpressionUUID->"458d9e3d-5b87-4105-9bbc-\
bb5c8c4ed762"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp24", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "30000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783529237853859*^9, 3.783529238458435*^9}, 
   3.7835331078955407`*^9, {3.7835342578869085`*^9, 3.7835342587835727`*^9}, {
   3.783534472574676*^9, 
   3.783534472933735*^9}},ExpressionUUID->"fadf1283-47cc-4567-9ed9-\
9c1868f51456"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of irreps: ", 7],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7835344593761373`*^9, 
  3.783534620993619*^9},ExpressionUUID->"ae0bf407-f535-4885-9452-\
d1737d999b8e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"142.0\"\>",
      142.2463076,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[142.2463076, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7835344593761373`*^9, 
  3.7835346209966116`*^9},ExpressionUUID->"f1c06631-4bf6-48e2-86a8-\
2e1d493aa0fb"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "29", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(24)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22", "0"},
         {
          FormBox["\<\"(200000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26", "0"},
         {
          FormBox["\<\"(001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "230", "1"},
         {
          FormBox["\<\"(110000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4576", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "572", "1"},
         {
          FormBox["\<\"(000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1518", "0"},
         {
          FormBox["\<\"(020000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27324", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4554", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.783534459386113*^9, 
  3.783534621023512*^9},ExpressionUUID->"c4a803e1-fe7a-4fc7-ab77-\
132e349a414f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp26", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "40000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.7835292422273903`*^9, 3.783533106050622*^9, {3.783534481599518*^9, 
   3.7835344824093795`*^9}, {3.7835346766400795`*^9, 
   3.7835346780782995`*^9}},ExpressionUUID->"0b9ebda7-ace4-43b9-8a38-\
3467ac7849ac"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of irreps: ", 7],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7835351717943487`*^9},ExpressionUUID->"bcc8d31d-63b2-47f4-9e57-\
d92db9e20b42"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"493.0\"\>",
      493.0285143,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[493.0285143, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7835351717953463`*^9},ExpressionUUID->"7c25e6f0-f0f3-4f21-92ac-\
bec5dc342bee"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "31", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(26)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(0100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"324", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", "0"},
         {
          FormBox["\<\"(2000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"351", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "0"},
         {
          FormBox["\<\"(0010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2574", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "275", "1"},
         {
          FormBox["\<\"(1100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", "1"},
         {
          FormBox["\<\"(0001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2000", "0"},
         {
          FormBox["\<\"(0200000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5800", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.783535171805319*^9},ExpressionUUID->"a918f6d3-98d4-4abf-8e3c-\
ac62695279eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp28", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "356265"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783529246050071*^9, 3.7835292467441835`*^9}, 
   3.7835331032261763`*^9, {3.7835344853434725`*^9, 3.7835344863388357`*^9}, {
   3.7835346822721586`*^9, 3.783534684256894*^9}, {3.7835352693257084`*^9, 
   3.7835352698373165`*^9}, {3.7839495288335485`*^9, 
   3.783949530818167*^9}},ExpressionUUID->"03320505-2615-46fb-80a8-\
919e6da1b374"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "8"}],
   SequenceForm["Number of irreps: ", 8],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.7835352581971636`*^9, 3.7835352777882814`*^9}, 
   3.783949538505613*^9},ExpressionUUID->"74f7ac3e-bfa7-4d71-b18b-\
7eda3f23968d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"6.4\"\>",
      6.4148689,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[6.4148689, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.7835352581971636`*^9, 3.7835352777882814`*^9}, 
   3.7839495385535116`*^9},ExpressionUUID->"15db824d-6ab0-42c5-b5f4-\
104e28991c85"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "230", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(28)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(01000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"377", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26", "0"},
         {
          FormBox["\<\"(00100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3248", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", "1"},
         {
          FormBox["\<\"(11000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "780", "1"},
         {
          FormBox["\<\"(00010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20097", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2574", "0"},
         {
          FormBox["\<\"(10100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70470", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9720", "0"},
         {
          FormBox["\<\"(00001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"95004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14625", "1"},
         {
          FormBox["\<\"(00000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"356265", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "63180", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{{3.7835352582450714`*^9, 3.7835352778201623`*^9}, 
   3.783949538612364*^9},ExpressionUUID->"17751f55-4deb-4834-bf84-\
6360e782a92b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp30", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "140000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835292522369385`*^9, 3.7835292526670017`*^9}, 
   3.7835330997335134`*^9, {3.7835344893363447`*^9, 3.783534490140256*^9}, {
   3.783534688021964*^9, 3.783534689461103*^9}, {3.7835352942326994`*^9, 
   3.7835352947832465`*^9}, {3.7835353495252037`*^9, 
   3.7835353499979467`*^9}},ExpressionUUID->"f6bd84f6-d19a-48a4-a891-\
bc165c1d76e6"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of irreps: ", 7],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7835353131267133`*^9, 
  3.7835353640864162`*^9},ExpressionUUID->"3585be19-8681-4189-8efe-\
b7ed3403b73b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"13.5\"\>",
      13.5216962,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[13.5216962, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7835353131267133`*^9, 
  3.7835353640894084`*^9},ExpressionUUID->"8d176ab2-e112-4921-8fa8-\
fe6a14f8d48a"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "37", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[\\\"\\\\\\\"Sp(30)\\\\\\\"\\\", \
TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(010000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"434", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "0"},
         {
          FormBox["\<\"(001000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4030", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "377", "1"},
         {
          FormBox["\<\"(110000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "896", "1"},
         {
          FormBox["\<\"(000100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26970", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3248", "0"},
         {
          FormBox["\<\"(101000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"93496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12064", "0"},
         {
          FormBox["\<\"(000010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"138446", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20097", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.783535313154677*^9, 
  3.783535364111348*^9},ExpressionUUID->"d9d10f0e-1afd-4253-adeb-\
6559821f7800"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exceptional Algebras", "Section",ExpressionUUID->"42746faa-31ac-448c-99e3-fb52eb158860"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"E6", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SO10", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU2"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU3", ",", "SU3"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Triality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "853000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "6"}]}], "]"}]], "Input",ExpressionUUI\
D->"2825ae6e-e89e-4068-b6af-06e3d91d4aaa"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "47"}],
   SequenceForm["Number of irreps: ", 47],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615350379509054*^9, 
  3.6153570215149927`*^9},ExpressionUUID->"475e2de8-1a79-4f07-a00b-\
85552062f504"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"4250.0\"\>",
      4252.80072899999959190608933568000793457031`9.649274946987486,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    4252.80072899999959190608933568000793457031`9.649274946987486, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615350379509054*^9, 
  3.615361253467108*^9},ExpressionUUID->"86118b89-f757-4bfd-9e34-\
002062c60fb7"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"E\\\"\\_6\\)\\) \
Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/6\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Triality\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "0"},
         {
          FormBox["\<\"(000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"351", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"351", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "1", "1", "0", "0"},
         {
          FormBox["\<\"(100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "2"},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "160", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "270", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "300", "0", "0", "0", "1"},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "385", "0", "1", "0", "1"},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "840", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "946", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2300", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19305", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2695", "1", "1", "0", "0"},
         {
          FormBox["\<\"(400000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19305", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3520", "1", "1", "0", "0"},
         {
          FormBox["\<\"(020000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34398", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5390", "1", "0", "0", "0"},
         {
          FormBox["\<\"(100011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34749", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4752", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "2"},
         {
          FormBox["\<\"(000003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43758", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7854", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "1"},
         {
          FormBox["\<\"(100002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46332", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7260", "1", "1", "0", "0"},
         {
          FormBox["\<\"(101000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"51975", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7700", "1", "0", "0", "0"},
         {
          FormBox["\<\"(210000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54054", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8932", "1", "0", "0", "0"},
         {
          FormBox["\<\"(100030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"61425", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10675", "1", "1", "0", "0"},
         {
          FormBox["\<\"(010100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70070", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10780", "0", "0", "1", "3"},
         {
          FormBox["\<\"(200100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78975", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12825", "0", "0", "0", "1"},
         {
          FormBox["\<\"(200020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"85293", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14580", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "3"},
         {
          FormBox["\<\"(000050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"100386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24310", "1", "1", "0", "0"},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105600", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17600", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18080", "1", "0", "0", "0"},
         {
          FormBox["\<\"(300001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"146432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28160", "0", "1", "0", "0"},
         {
          FormBox["\<\"(110001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45276", "0", "0", "0", "2"},
         {
          FormBox["\<\"(010011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"314496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56000", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"359424", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "67072", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"359424", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "79360", "1", "0", "0", "0"},
         {
          FormBox["\<\"(400010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"371800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "85800", "0", "1", "0", "2"},
         {
          FormBox["\<\"(001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"386100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "73700", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"393822", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78540", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"412776", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "85848", "1", "0", "0", "0"},
         {
          FormBox["\<\"(600000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"442442", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "136136", "0", "1", "0", "1"},
         {
          FormBox["\<\"(000022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"459459", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95557", "1", "1", "0", "0"},
         {
          FormBox["\<\"(001020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"494208", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98560", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"537966", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "137940", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(300100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"579150", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "125400", "1", "0", "0", "0"},
         {
          FormBox["\<\"(100200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"600600", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "123200", "0", "0", "0", "1"},
         {
          FormBox["\<\"(300020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"638820", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "143780", "1", "1", "0", "0"},
         {
          FormBox["\<\"(100003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"741312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "170016", "1", "1", "0", "0"},
         {
          FormBox["\<\"(100012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"812175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "166600", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "3"},
         {
          FormBox["\<\"(101010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"852930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "167670", "0", "0", "0", "3"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{" and ", "\" and \"", 
          RowBox[{
            FormBox["\"SO(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "RowWithSeparators"],
        "\" singlets resp.\""},
       "RowDefault"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615361253567573*^9},ExpressionUUID->"fa11d5b6-82ec-4b5b-9ba0-\
5bd37544dcc5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"E7", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "3000000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.780162772996763*^9, 
  3.780162773263096*^9}},ExpressionUUID->"ee47c5b8-c6e1-4a36-9983-\
650d48ddb32e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "29"}],
   SequenceForm["Number of irreps: ", 29],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.61536126530761*^9, 
  3.7801627824352665`*^9},ExpressionUUID->"4dc3488d-0b8d-4764-8c75-\
10e2466796f7"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"8.6\"\>",
      8.623575,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[8.623575, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.61536126530761*^9, 
  3.780162782437262*^9},ExpressionUUID->"8a21e550-5c1e-4c88-9cbe-\
27af4fdf6368"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "49", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[SubscriptBox[\\\"\\\\\\\"E\\\\\\\"\\\", \
\\\"7\\\"], TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/12\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(0000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"133", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3", "0"},
         {
          FormBox["\<\"(0000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30", "1"},
         {
          FormBox["\<\"(0000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1463", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "0"},
         {
          FormBox["\<\"(0000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1539", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", "0"},
         {
          FormBox["\<\"(1000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "270", "1"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "351", "0"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8645", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "390", "0"},
         {
          FormBox["\<\"(0000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1440", "1"},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27664", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1430", "1"},
         {
          FormBox["\<\"(0000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40755", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2145", "0"},
         {
          FormBox["\<\"(0000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"51072", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2832", "1"},
         {
          FormBox["\<\"(1000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"86184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4995", "1"},
         {
          FormBox["\<\"(1000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"150822", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9450", "0"},
         {
          FormBox["\<\"(1000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"152152", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9152", "0"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"238602", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17940", "0"},
         {
          FormBox["\<\"(0000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"253935", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17820", "0"},
         {
          FormBox["\<\"(0000040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"293930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24310", "0"},
         {
          FormBox["\<\"(2000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21762", "1"},
         {
          FormBox["\<\"(0100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"362880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23760", "1"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"365750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24750", "0"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"573440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "40960", "0"},
         {
          FormBox["\<\"(0000200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"617253", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "46410", "0"},
         {
          FormBox["\<\"(0000101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"861840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61830", "1"},
         {
          FormBox["\<\"(0000021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"885248", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65728", "1"},
         {
          FormBox["\<\"(0000120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"915705", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71145", "0"},
         {
          FormBox["\<\"(0001010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"980343", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71253", "0"},
         {
          FormBox["\<\"(1000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2273920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "194480", "1"},
         {
          FormBox["\<\"(1001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2282280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "178035", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6153612653436623`*^9, 
  3.7801627825100822`*^9},ExpressionUUID->"cc277b0e-a918-4048-bc48-\
09e6d56e3fd4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"E8", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "120000000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7801627979584627`*^9, 
  3.780162826635441*^9}},ExpressionUUID->"4872f870-b3f5-496b-934b-\
04bc9d4c6e90"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "14"}],
   SequenceForm["Number of irreps: ", 14],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615361284438222*^9, 3.780162814996872*^9, 
  3.7801628450204515`*^9},ExpressionUUID->"e624a91e-0a81-4a98-9468-\
446647cd8611"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"17.4\"\>",
      17.3582393,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[17.3582393, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615361284438222*^9, 3.780162814996872*^9, 
  3.780162845023446*^9},ExpressionUUID->"ece9aa32-87fb-4bdc-b959-\
f0a739d0e778"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "51", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[SubscriptBox[\\\"\\\\\\\"E\\\\\\\"\\\", \
\\\"8\\\"], TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/60\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(00000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"248", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(10000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25", "0"},
         {
          FormBox["\<\"(00000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "225", "0"},
         {
          FormBox["\<\"(00000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "245", "0"},
         {
          FormBox["\<\"(00000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"147250", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1425", "0"},
         {
          FormBox["\<\"(10000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"779247", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8379", "0"},
         {
          FormBox["\<\"(00000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1763125", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22750", "0"},
         {
          FormBox["\<\"(00001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2450240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29640", "0"},
         {
          FormBox["\<\"(00000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51200", "0"},
         {
          FormBox["\<\"(20000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4881384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65610", "0"},
         {
          FormBox["\<\"(01000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6696000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "88200", "0"},
         {
          FormBox["\<\"(00000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26411008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "372736", "0"},
         {
          FormBox["\<\"(10000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70680000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1083000", "0"},
         {
          FormBox["\<\"(10000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76271625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1148175", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.615361284460412*^9, 3.780162815027794*^9, 
  3.7801628450663366`*^9},ExpressionUUID->"adce3bc5-057d-4f01-9dcc-\
5ffd01217565"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"F4", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "31702671"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "9"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.782314138328024*^9, 3.78231415037663*^9}, {
  3.782314284545092*^9, 3.782314284707637*^9}, {3.7835371110250487`*^9, 
  3.783537121600586*^9}},ExpressionUUID->"e9cae6c3-af54-4fe9-b351-\
f9876fc2dcf2"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153612863404503`*^9, {3.7823141413042793`*^9, 3.7823141513092012`*^9}, 
   3.782314285315055*^9, 
   3.783537127903674*^9},ExpressionUUID->"5a573a9e-043d-4394-928e-\
b7fd18865977"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1.2\"\>",
      1.2244192,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1.2244192, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6153612863404503`*^9, {3.7823141413042793`*^9, 3.7823141513092012`*^9}, 
   3.782314285315055*^9, 
   3.7835371279256153`*^9},ExpressionUUID->"fb220a63-01bd-4fd2-9c5a-\
e2936126a9bd"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "53", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[SubscriptBox[\\\"\\\\\\\"F\\\\\\\"\\\", \
\\\"4\\\"], TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/6\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(0001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"52", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3", "0"},
         {
          FormBox["\<\"(0010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"273", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "0"},
         {
          FormBox["\<\"(0002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"324", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27", "0"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1053", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "108", "0"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1053", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "135", "0"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1274", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "147", "0"},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2652", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "357", "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", "0"},
         {
          FormBox["\<\"(1010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8424", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1242", "0"},
         {
          FormBox["\<\"(1002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10829", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1666", "0"},
         {
          FormBox["\<\"(3000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2618", "0"},
         {
          FormBox["\<\"(0004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16302", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3135", "0"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17901", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3213", "0"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19278", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3213", "0"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19448", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3366", "0"},
         {
          FormBox["\<\"(1100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29172", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5610", "0"},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34749", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6237", "0"},
         {
          FormBox["\<\"(1003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76076", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16093", "0"},
         {
          FormBox["\<\"(0005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81081", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20790", "0"},
         {
          FormBox["\<\"(4000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"100776", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31008", "0"},
         {
          FormBox["\<\"(1011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"106496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21504", "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"107406", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23409", "0"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"119119", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27489", "0"},
         {
          FormBox["\<\"(0102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35910", "0"},
         {
          FormBox["\<\"(2002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "37962", "0"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"184756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "49742", "0"},
         {
          FormBox["\<\"(0021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"205751", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "47481", "0"},
         {
          FormBox["\<\"(0013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"212992", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51200", "0"},
         {
          FormBox["\<\"(0200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"226746", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61047", "0"},
         {
          FormBox["\<\"(2100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"340119", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95931", "0"},
         {
          FormBox["\<\"(0006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"342056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "111826", "0"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"379848", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "94962", "0"},
         {
          FormBox["\<\"(1004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"412776", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "113778", "0"},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420147", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "107730", "0"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"627912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "261630", "0"},
         {
          FormBox["\<\"(0030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"629356", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "181545", "0"},
         {
          FormBox["\<\"(1012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"787644", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "207009", "0"},
         {
          FormBox["\<\"(0103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"952952", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "274890", "0"},
         {
          FormBox["\<\"(2003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1002456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "302022", "0"},
         {
          FormBox["\<\"(0014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1042899", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320892", "0"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1074944", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "351424", "0"},
         {
          FormBox["\<\"(0111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1118208", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "311808", "0"},
         {
          FormBox["\<\"(0007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1264120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "510510", "0"},
         {
          FormBox["\<\"(2011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1327104", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "387072", "0"},
         {
          FormBox["\<\"(0022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1341522", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "395577", "0"},
         {
          FormBox["\<\"(4001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1360476", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "505818", "0"},
         {
          FormBox["\<\"(3002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1484406", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "494802", "0"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1801371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "554268", "0"},
         {
          FormBox["\<\"(1005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1850212", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "640458", "0"},
         {
          FormBox["\<\"(0201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2488563", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "829521", "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2674763", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1028755", "0"},
         {
          FormBox["\<\"(1102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2792556", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "877149", "0"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3187041", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716099", "0"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3195192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1167474", "0"},
         {
          FormBox["\<\"(0120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3508596", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1192023", "0"},
         {
          FormBox["\<\"(1021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3921372", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1256850", "0"},
         {
          FormBox["\<\"(2101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3955952", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1369368", "0"},
         {
          FormBox["\<\"(0008)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4188834", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2040714", "0"},
         {
          FormBox["\<\"(1013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4313088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1423872", "0"},
         {
          FormBox["\<\"(0015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4313088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1645056", "0"},
         {
          FormBox["\<\"(0104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4528953", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1625778", "0"},
         {
          FormBox["\<\"(2020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4582656", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1615680", "0"},
         {
          FormBox["\<\"(2004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4940676", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1836918", "0"},
         {
          FormBox["\<\"(0031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5218304", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1856512", "0"},
         {
          FormBox["\<\"(0023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6680856", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2441082", "0"},
         {
          FormBox["\<\"(0112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7113106", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2462229", "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7142499", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3113397", "0"},
         {
          FormBox["\<\"(1006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7147140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3023790", "0"},
         {
          FormBox["\<\"(5001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7822737", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3811077", "0"},
         {
          FormBox["\<\"(3003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8498776", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3432198", "0"},
         {
          FormBox["\<\"(2012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8843094", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3174444", "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9683388", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3848526", "0"},
         {
          FormBox["\<\"(4002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10044008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4442542", "0"},
         {
          FormBox["\<\"(1030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10482472", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4031720", "0"},
         {
          FormBox["\<\"(3011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10862592", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4282368", "0"},
         {
          FormBox["\<\"(0040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11955216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5057976", "0"},
         {
          FormBox["\<\"(0009)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12664184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7306260", "0"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13530946", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6245052", "0"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13748020", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9253475", "0"},
         {
          FormBox["\<\"(1103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15031926", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5781510", "0"},
         {
          FormBox["\<\"(0016)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15611882", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7205484", "0"},
         {
          FormBox["\<\"(0202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15997696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6460608", "0"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16016924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8008462", "0"},
         {
          FormBox["\<\"(2110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16665831", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6837264", "0"},
         {
          FormBox["\<\"(1111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16777216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6291456", "0"},
         {
          FormBox["\<\"(0105)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18206370", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7936110", "0"},
         {
          FormBox["\<\"(1014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19214624", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7759752", "0"},
         {
          FormBox["\<\"(2005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20407140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9157050", "0"},
         {
          FormBox["\<\"(1022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23056488", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9015678", "0"},
         {
          FormBox["\<\"(1007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24488568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12401262", "0"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26108082", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12384603", "0"},
         {
          FormBox["\<\"(2102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26476956", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11032065", "0"},
         {
          FormBox["\<\"(0024)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27625000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12218750", "0"},
         {
          FormBox["\<\"(0032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28068768", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12055176", "0"},
         {
          FormBox["\<\"(0121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28481544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11684736", "0"},
         {
          FormBox["\<\"(3101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28481544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12962754", "0"},
         {
          FormBox["\<\"(1201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31702671", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13819113", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615361286449481*^9, {3.782314141428944*^9, 3.7823141514328437`*^9}, 
   3.7823142854656944`*^9, 
   3.7835371280293393`*^9},ExpressionUUID->"3ca6f3ec-da78-4b8b-9648-\
22a34b4e8e9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"G2", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "95634"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "20"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.782314300173369*^9, 3.782314302619958*^9}, {
  3.78231444796772*^9, 3.7823144482010803`*^9}, {3.7835371451068926`*^9, 
  3.7835371469310465`*^9}},ExpressionUUID->"4c990ef4-28ef-48f1-ab88-\
d1faa44b5ef4"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615361286663022*^9, 3.78231430329323*^9, 
  3.7823144488434396`*^9, 
  3.7835371478186884`*^9},ExpressionUUID->"a1a3fccb-1ff6-4fd3-bdce-\
4bb20eb123e2"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.3\"\>",
      0.3195383,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.3195383, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.615361286663022*^9, 3.78231430329323*^9, 
  3.7823144488434396`*^9, 
  3.7835371478336477`*^9},ExpressionUUID->"c8487a81-32b0-46d3-a5a6-\
bb9299383c91"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "54", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],
        "\"\\!\\(\\*FormBox[FormBox[SubscriptBox[\\\"\\\\\\\"G\\\\\\\"\\\", \
\\\"2\\\"], TraditionalForm], TraditionalForm]\\) Irreps\""},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", Italic, StripOnInput -> False],"\"/2\""},
               "RowDefault"]},
             {"\<\"(index)\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(01)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "0"},
         {
          FormBox["\<\"(20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "0"},
         {
          FormBox["\<\"(11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", "0"},
         {
          FormBox["\<\"(30)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"77", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "44", "0"},
         {
          FormBox["\<\"(02)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"77", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "0"},
         {
          FormBox["\<\"(40)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"182", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "156", "0"},
         {
          FormBox["\<\"(21)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "144", "0"},
         {
          FormBox["\<\"(03)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"273", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "351", "0"},
         {
          FormBox["\<\"(12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286", "0"},
         {
          FormBox["\<\"(50)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "450", "0"},
         {
          FormBox["\<\"(31)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"448", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", "0"},
         {
          FormBox["\<\"(60)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"714", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1122", "0"},
         {
          FormBox["\<\"(22)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "972", "0"},
         {
          FormBox["\<\"(04)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"748", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1496", "0"},
         {
          FormBox["\<\"(13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1472", "0"},
         {
          FormBox["\<\"(41)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "0"},
         {
          FormBox["\<\"(70)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1254", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2508", "0"},
         {
          FormBox["\<\"(32)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1547", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2652", "0"},
         {
          FormBox["\<\"(51)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3168", "0"},
         {
          FormBox["\<\"(05)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4940", "0"},
         {
          FormBox["\<\"(23)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4257", "0"},
         {
          FormBox["\<\"(80)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "0"},
         {
          FormBox["\<\"(14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2261", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5491", "0"},
         {
          FormBox["\<\"(42)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2926", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6270", "0"},
         {
          FormBox["\<\"(61)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6864", "0"},
         {
          FormBox["\<\"(90)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3289", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9867", "0"},
         {
          FormBox["\<\"(06)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3542", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13662", "0"},
         {
          FormBox["\<\"(33)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10240", "0"},
         {
          FormBox["\<\"(24)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4914", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14274", "0"},
         {
          FormBox["\<\"(71)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13728", "0"},
         {
          FormBox["\<\"(15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16544", "0"},
         {
          FormBox["\<\"(10, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17875", "0"},
         {
          FormBox["\<\"(52)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5103", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13365", "0"},
         {
          FormBox["\<\"(07)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6630", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33150", "0"},
         {
          FormBox["\<\"(43)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7293", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21879", "0"},
         {
          FormBox["\<\"(11, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30888", "0"},
         {
          FormBox["\<\"(81)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25740", "0"},
         {
          FormBox["\<\"(62)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8372", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26312", "0"},
         {
          FormBox["\<\"(34)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9177", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31464", "0"},
         {
          FormBox["\<\"(16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9660", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42780", "0"},
         {
          FormBox["\<\"(25)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10206", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "39852", "0"},
         {
          FormBox["\<\"(12, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10556", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51272", "0"},
         {
          FormBox["\<\"(08)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11571", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72732", "0"},
         {
          FormBox["\<\"(91)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11648", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45760", "0"},
         {
          FormBox["\<\"(53)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42912", "0"},
         {
          FormBox["\<\"(72)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13090", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "48620", "0"},
         {
          FormBox["\<\"(13, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "82212", "0"},
         {
          FormBox["\<\"(44)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "62500", "0"},
         {
          FormBox["\<\"(10, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17017", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77792", "0"},
         {
          FormBox["\<\"(17)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17472", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98592", "0"},
         {
          FormBox["\<\"(35)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18304", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "82368", "0"},
         {
          FormBox["\<\"(63)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19019", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78793", "0"},
         {
          FormBox["\<\"(09)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "147312", "0"},
         {
          FormBox["\<\"(26)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19278", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "97308", "0"},
         {
          FormBox["\<\"(82)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19683", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "85293", "0"},
         {
          FormBox["\<\"(14, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20196", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "127908", "0"},
         {
          FormBox["\<\"(11, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "127296", "0"},
         {
          FormBox["\<\"(54)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24948", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "115236", "0"},
         {
          FormBox["\<\"(15, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27132", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "193800", "0"},
         {
          FormBox["\<\"(92)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28652", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "143260", "0"},
         {
          FormBox["\<\"(73)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "137216", "0"},
         {
          FormBox["\<\"(18)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29667", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "207669", "0"},
         {
          FormBox["\<\"(45)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30107", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "154836", "0"},
         {
          FormBox["\<\"(0, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30107", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "279565", "0"},
         {
          FormBox["\<\"(36)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "191400", "0"},
         {
          FormBox["\<\"(12, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33592", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "201552", "0"},
         {
          FormBox["\<\"(27)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33858", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "214434", "0"},
         {
          FormBox["\<\"(16, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35853", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286824", "0"},
         {
          FormBox["\<\"(64)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37961", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "200651", "0"},
         {
          FormBox["\<\"(10, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40579", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "231880", "0"},
         {
          FormBox["\<\"(83)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"41769", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "228735", "0"},
         {
          FormBox["\<\"(0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45695", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "502645", "0"},
         {
          FormBox["\<\"(13, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "310080", "0"},
         {
          FormBox["\<\"(55)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46656", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "272160", "0"},
         {
          FormBox["\<\"(17, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46683", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "415701", "0"},
         {
          FormBox["\<\"(19)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"47872", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "406912", "0"},
         {
          FormBox["\<\"(46)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"53599", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "344565", "0"},
         {
          FormBox["\<\"(74)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55614", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "333684", "0"},
         {
          FormBox["\<\"(11, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56133", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "363528", "0"},
         {
          FormBox["\<\"(28)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56133", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "435699", "0"},
         {
          FormBox["\<\"(37)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"57344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "405504", "0"},
         {
          FormBox["\<\"(93)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"59136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "367488", "0"},
         {
          FormBox["\<\"(18, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"59983", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "591261", "0"},
         {
          FormBox["\<\"(14, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"61047", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "465120", "0"},
         {
          FormBox["\<\"(0, 12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"67158", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "863460", "0"},
         {
          FormBox["\<\"(65)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"69160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "454480", "0"},
         {
          FormBox["\<\"(1, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"74074", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "751322", "0"},
         {
          FormBox["\<\"(12, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76076", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "554268", "0"},
         {
          FormBox["\<\"(19, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76153", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "826804", "0"},
         {
          FormBox["\<\"(84)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"79002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "534204", "0"},
         {
          FormBox["\<\"(15, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "682176", "0"},
         {
          FormBox["\<\"(56)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81081", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "583011", "0"},
         {
          FormBox["\<\"(10, 3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81719", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "572033", "0"},
         {
          FormBox["\<\"(29)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"88803", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "828828", "0"},
         {
          FormBox["\<\"(47)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"89726", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "704990", "0"},
         {
          FormBox["\<\"(38)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"93093", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "797940", "0"},
         {
          FormBox["\<\"(20, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"95634", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1138500", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6153612867672043`*^9, 3.782314303414893*^9, 
  3.7823144490010223`*^9, 
  3.7835371479343796`*^9},ExpressionUUID->"17beb7c6-2540-42fd-bc95-\
daaaede72f02"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{909, 668},
WindowMargins->{{80, Automatic}, {Automatic, 38}},
PrintingOptions->{"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->14.4},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> True}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 113, 0, 83, "Title", "ExpressionUUID" -> \
"94300c41-74ea-4fba-8fb6-8204badbfe7c"],
Cell[695, 24, 273, 8, 30, "Subsubtitle", "ExpressionUUID" -> \
"040792fd-e014-42f8-8e37-c6686aa3648f"],
Cell[CellGroupData[{
Cell[993, 36, 168, 4, 71, "Section", "ExpressionUUID" -> \
"38993cd0-07e4-4c04-b156-2b16e24c62c5",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1164, 42, 196, 4, 29, "Input", "ExpressionUUID" -> \
"0adc309c-0de1-4386-af43-7fb77264592b",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True],
Cell[1363, 48, 414, 12, 68, "Input", "ExpressionUUID" -> \
"bd427ca5-7eef-4bc0-a1e6-9c95c75f5ccb",
 InitializationCell->True],
Cell[1780, 62, 282, 6, 31, "Input", "ExpressionUUID" -> \
"02af092e-493c-4608-9d59-bfc66a8e5d40"]
}, Closed]],
Cell[CellGroupData[{
Cell[2099, 73, 79, 0, 41, "Section", "ExpressionUUID" -> \
"092dd081-03aa-46f7-b6c3-972ccac71954"],
Cell[CellGroupData[{
Cell[2203, 77, 463, 10, 29, "Input", "ExpressionUUID" -> \
"9d30ae8e-05c6-44cc-a28a-c851e4adfbd4"],
Cell[2669, 89, 327, 7, 23, "Print", "ExpressionUUID" -> \
"8938dacf-a2de-441b-9443-3c50b6aac814"],
Cell[2999, 98, 509, 14, 23, "Print", "ExpressionUUID" -> \
"f5259f61-4dd2-444f-b5c4-132c19b0c412"],
Cell[3511, 114, 20146, 632, 864, "Output", "ExpressionUUID" -> \
"c9a642ba-24e6-4455-8dbb-e00e4124677a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23694, 751, 425, 9, 48, "Input", "ExpressionUUID" -> \
"0a1f6f45-e42b-40e7-a244-fd5296c91eb4"],
Cell[24122, 762, 310, 8, 23, "Print", "ExpressionUUID" -> \
"4ed6fc6e-e71b-476a-a08a-43b5843e714a"],
Cell[24435, 772, 591, 15, 23, "Print", "ExpressionUUID" -> \
"ed9010d4-23e5-4d71-9a48-a5069cd1a25b"],
Cell[25029, 789, 40311, 1248, 1682, "Output", "ExpressionUUID" -> \
"9c1538b1-edfc-44a5-af1c-05859051816c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65377, 2042, 423, 9, 48, "Input", "ExpressionUUID" -> \
"42fdf57f-d60c-4c8a-aa3d-365e135daef6"],
Cell[65803, 2053, 308, 8, 23, "Print", "ExpressionUUID" -> \
"cf08f78e-78bc-4700-a340-746bc7164a0f"],
Cell[66114, 2063, 593, 16, 23, "Print", "ExpressionUUID" -> \
"8ac7fc21-3ffc-48e7-bb30-117437559241"],
Cell[66710, 2081, 40522, 1252, 1698, "Output", "ExpressionUUID" -> \
"0bcd0012-9a52-45b3-878b-5e7514296385"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107269, 3338, 536, 12, 48, "Input", "ExpressionUUID" -> \
"5aa0deb0-17ff-46c8-94a3-6429e470f61d"],
Cell[107808, 3352, 308, 8, 23, "Print", "ExpressionUUID" -> \
"4a77d756-475a-4b72-b306-8dce67f988db"],
Cell[108119, 3362, 601, 16, 23, "Print", "ExpressionUUID" -> \
"511e7ce8-b3bf-4ec4-a664-f79dbd2c24f5"],
Cell[108723, 3380, 42860, 1303, 1716, "Output", "ExpressionUUID" -> \
"90f13432-efc0-4277-b831-258adbf9c21f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151620, 4688, 631, 14, 48, "Input", "ExpressionUUID" -> \
"8d200d55-5d22-49b7-88bc-85e5d23f758e"],
Cell[152254, 4704, 310, 8, 23, "Print", "ExpressionUUID" -> \
"20776992-539e-47c5-8c8f-5c4f45b69bac"],
Cell[152567, 4714, 592, 15, 23, "Print", "ExpressionUUID" -> \
"bad06a86-c630-4401-b154-70aa5ef2f176"],
Cell[153162, 4731, 45725, 1373, 1732, "Output", "ExpressionUUID" -> \
"cc0e1dfc-4dcb-4395-bc1c-3b3d956b1d3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[198924, 6109, 630, 14, 48, "Input", "ExpressionUUID" -> \
"737b12a4-dfa4-4b59-b42d-9d13a4339019"],
Cell[199557, 6125, 310, 8, 23, "Print", "ExpressionUUID" -> \
"51a5ab97-643b-4b3f-ba8c-8855c0b437ed"],
Cell[199870, 6135, 590, 15, 23, "Print", "ExpressionUUID" -> \
"f1efb965-6fe0-4945-b870-837af091c1da"],
Cell[200463, 6152, 24855, 742, 900, "Output", "ExpressionUUID" -> \
"98c9f178-8fa8-464b-a583-45c2866f4b12"]
}, Open  ]],
Cell[CellGroupData[{
Cell[225355, 6899, 725, 16, 48, "Input", "ExpressionUUID" -> \
"5ba0bc71-e6a5-48d9-9f16-453dfd21ff42"],
Cell[226083, 6917, 308, 8, 23, "Print", "ExpressionUUID" -> \
"225db1fe-d96c-44e7-ba3f-fe707e79c59f"],
Cell[226394, 6927, 599, 16, 23, "Print", "ExpressionUUID" -> \
"13a5120a-94cd-4d39-861a-cb7d98e1a3d0"],
Cell[226996, 6945, 26980, 796, 916, "Output", "ExpressionUUID" -> \
"772c06d7-0273-4016-90e5-1191b7bae9ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254013, 7746, 822, 19, 48, "Input", "ExpressionUUID" -> \
"3bd2ea26-d679-40a0-83eb-ca2b2b8a2987"],
Cell[254838, 7767, 378, 9, 23, "Print", "ExpressionUUID" -> \
"e24832e3-1385-48ad-b1c6-31249fddef36"],
Cell[255219, 7778, 563, 15, 23, "Print", "ExpressionUUID" -> \
"c97f9a30-d86b-42b6-a713-48299ff4d818"],
Cell[255785, 7795, 16499, 481, 492, "Output", "ExpressionUUID" -> \
"6be44707-77c1-4354-ab07-0f8e4f0eb728"]
}, Open  ]],
Cell[CellGroupData[{
Cell[272321, 8281, 822, 18, 66, "Input", "ExpressionUUID" -> \
"179c0c89-de4e-4f5c-8e0c-91de0443a0f7"],
Cell[273146, 8301, 303, 7, 23, "Print", "ExpressionUUID" -> \
"ca90d63a-5f1a-4a9e-a2ed-875377d154b9"],
Cell[273452, 8310, 599, 16, 23, "Print", "ExpressionUUID" -> \
"f6065791-6d7a-4b7d-ba6a-4504e0c78b39"],
Cell[274054, 8328, 15366, 444, 424, "Output", "ExpressionUUID" -> \
"03e438c7-dfad-4c71-8f29-a11e7e79e8cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289457, 8777, 822, 18, 66, "Input", "ExpressionUUID" -> \
"e55dc956-ad48-4c89-9752-6e4c79538a38"],
Cell[290282, 8797, 308, 8, 23, "Print", "ExpressionUUID" -> \
"84b3a965-34e4-4a37-aaef-7e0c452c1f8e"],
Cell[290593, 8807, 599, 16, 23, "Print", "ExpressionUUID" -> \
"b8418bb4-5edf-4947-bf8f-e40a3bd3b6d1"],
Cell[291195, 8825, 11190, 320, 270, "Output", "ExpressionUUID" -> \
"dfe31a7c-1faf-4f15-852e-78e118ad2389"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302422, 9150, 823, 18, 66, "Input", "ExpressionUUID" -> \
"1001c302-8c17-45b4-9b2b-09aa2c39e2f0"],
Cell[303248, 9170, 310, 8, 23, "Print", "ExpressionUUID" -> \
"c751300f-716e-4ff6-bd72-66537c325b60"],
Cell[303561, 9180, 596, 15, 23, "Print", "ExpressionUUID" -> \
"6116b1c5-ea01-4dd1-bd09-2dfc00d6ec42"],
Cell[304160, 9197, 11205, 320, 270, "Output", "ExpressionUUID" -> \
"b5e73edc-a7ef-4e15-826b-458517cf6b22"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[315414, 9523, 1025, 22, 66, "Input", "ExpressionUUID" -> \
"10d527db-8d72-4e64-9dba-6e10b1ff9911"],
Cell[316442, 9547, 334, 8, 23, "Print", "ExpressionUUID" -> \
"a71e1ad1-1115-4a2a-84b4-67b0b5807e07"],
Cell[316779, 9557, 398, 9, 21, "Message", "ExpressionUUID" -> \
"80d25c09-5680-4464-b81b-132b69fff8f5"],
Cell[317180, 9568, 518, 14, 23, "Print", "ExpressionUUID" -> \
"216a622e-989e-4571-ba5d-bcd041a14654"],
Cell[317701, 9584, 11281, 319, 270, "Output", "ExpressionUUID" -> \
"c6858f6a-67e9-4d04-a822-31ce0578749b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[329019, 9908, 975, 21, 66, "Input", "ExpressionUUID" -> \
"c7529044-a07a-49cb-a425-afa14f164288"],
Cell[329997, 9931, 332, 8, 23, "Print", "ExpressionUUID" -> \
"d266d263-2230-4c3c-b6b8-8ad21043d530"],
Cell[330332, 9941, 517, 14, 23, "Print", "ExpressionUUID" -> \
"7d6fe027-ecb2-4600-bb3d-b612739e19fe"],
Cell[330852, 9957, 9666, 272, 202, "Output", "ExpressionUUID" -> \
"01320d4a-2598-48bf-8fee-7dcbb70c4171"]
}, Open  ]],
Cell[CellGroupData[{
Cell[340555, 10234, 1099, 23, 66, "Input", "ExpressionUUID" -> \
"a04ed440-0330-4f29-a9c4-e10e6f8ee7bd"],
Cell[341657, 10259, 354, 8, 23, "Print", "ExpressionUUID" -> \
"53ae3ae9-3e24-46fc-88c7-2a7221ad297b"],
Cell[342014, 10269, 539, 14, 23, "Print", "ExpressionUUID" -> \
"6e1560f5-e7a7-45c1-b4cc-c7d3565a8c03"],
Cell[342556, 10285, 10483, 295, 236, "Output", "ExpressionUUID" -> \
"2aabda4d-3643-4f8e-b2cb-2db340a6c398"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353076, 10585, 899, 20, 66, "Input", "ExpressionUUID" -> \
"67153e7c-b4bd-4b56-9231-9c247db545cf"],
Cell[353978, 10607, 306, 8, 23, "Print", "ExpressionUUID" -> \
"0c044a3e-020c-4e8a-a01a-67236be6c7a4"],
Cell[354287, 10617, 372, 9, 21, "Message", "ExpressionUUID" -> \
"6aa5a738-a523-49c0-bf15-2ddeb3d9872e"],
Cell[354662, 10628, 496, 14, 23, "Print", "ExpressionUUID" -> \
"516f73ac-4edf-4621-8463-b1d719f93839"],
Cell[355161, 10644, 9194, 259, 186, "Output", "ExpressionUUID" -> \
"131693d4-9a3b-404a-bbb5-e7bd233a0688"]
}, Open  ]],
Cell[CellGroupData[{
Cell[364392, 10908, 79, 0, 71, "Section", "ExpressionUUID" -> \
"a24526e5-2b4a-496d-a7c5-458d7a353ffc"],
Cell[CellGroupData[{
Cell[364496, 10912, 284, 6, 29, "Input", "ExpressionUUID" -> \
"511e85de-1cc2-446e-a792-20c58310e9ae"],
Cell[364783, 10920, 310, 8, 23, "Print", "ExpressionUUID" -> \
"5216de20-cbe9-4bef-b31b-34b14c72de7d"],
Cell[365096, 10930, 594, 15, 23, "Print", "ExpressionUUID" -> \
"84ef07ea-bb6f-4b2a-a946-c932f9f12841"],
Cell[365693, 10947, 40703, 1258, 1732, "Output", "ExpressionUUID" -> \
"1ad8f23c-a350-4bff-96c5-b5084b3b04b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406433, 12210, 282, 6, 29, "Input", "ExpressionUUID" -> \
"df06733c-a807-4449-a013-acd6e0eb8f4a"],
Cell[406718, 12218, 308, 8, 23, "Print", "ExpressionUUID" -> \
"5a67cdc6-733d-43a9-82b0-f7c4a7eb0dce"],
Cell[407029, 12228, 591, 15, 23, "Print", "ExpressionUUID" -> \
"c35994a3-f33f-4620-91c8-7b3104cdb114"],
Cell[407623, 12245, 47615, 1465, 1854, "Output", "ExpressionUUID" -> \
"1ee8b9f9-7502-48fa-bea6-099975c07f2c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455275, 13715, 383, 9, 29, "Input", "ExpressionUUID" -> \
"7661c92e-cd9e-4a55-80d7-6f1c9afe14f7"],
Cell[455661, 13726, 308, 8, 23, "Print", "ExpressionUUID" -> \
"1b5b08c3-06eb-4234-bee1-4b5a67cb83dd"],
Cell[455972, 13736, 602, 16, 23, "Print", "ExpressionUUID" -> \
"439246a1-fb5d-4d25-a598-bceef68b7504"],
Cell[456577, 13754, 42236, 1285, 1748, "Output", "ExpressionUUID" -> \
"de429fe3-e7d3-499f-898f-24a1f1760e3c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498850, 15044, 743, 17, 48, "Input", "ExpressionUUID" -> \
"91be0769-e12d-45f8-9dfd-4bdb7c1b8019"],
Cell[499596, 15063, 400, 9, 23, "Print", "ExpressionUUID" -> \
"e679827b-84db-4b6b-a2e7-cb79c7560780"],
Cell[499999, 15074, 374, 9, 21, "Message", "ExpressionUUID" -> \
"26896f4f-b039-48fe-906a-a93820cca3c2"],
Cell[500376, 15085, 586, 15, 23, "Print", "ExpressionUUID" -> \
"b0952ee2-9331-49c8-a938-b02a36c3439d"],
Cell[500965, 15102, 50522, 1521, 1732, "Output", "ExpressionUUID" -> \
"d2cfb437-4d47-4dff-ba95-0f3c041d7534"]
}, Open  ]],
Cell[CellGroupData[{
Cell[551524, 16628, 473, 10, 29, "Input", "ExpressionUUID" -> \
"73501995-0f39-4d66-a339-97dff0236b90"],
Cell[552000, 16640, 434, 10, 23, "Print", "ExpressionUUID" -> \
"19fddfae-3d8d-4d74-85fa-d5fee64b4acf"],
Cell[552437, 16652, 611, 16, 23, "Print", "ExpressionUUID" -> \
"0b3f6ef5-887a-4a02-bcde-5a7434dbfd04"],
Cell[553051, 16670, 21698, 671, 916, "Output", "ExpressionUUID" -> \
"4ce16c6d-7421-4123-91ae-67ca4f045442"]
}, Open  ]],
Cell[CellGroupData[{
Cell[574786, 17346, 277, 6, 29, "Input", "ExpressionUUID" -> \
"802cceae-d714-4ba9-97f3-56b278cc7766"],
Cell[575066, 17354, 310, 8, 23, "Print", "ExpressionUUID" -> \
"8ed04a2a-c8c2-451b-b38c-9089c4e8f4bb"],
Cell[575379, 17364, 593, 15, 23, "Print", "ExpressionUUID" -> \
"3257b41f-0daa-40ef-b6e2-364c6cb8ed91"],
Cell[575975, 17381, 24552, 767, 916, "Output", "ExpressionUUID" -> \
"e9505098-498f-4007-b96b-ab6705b1d188"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600564, 18153, 277, 6, 29, "Input", "ExpressionUUID" -> \
"474fc93d-0f99-46fa-b170-5f0bbf6b46b5"],
Cell[600844, 18161, 310, 8, 23, "Print", "ExpressionUUID" -> \
"a229acf1-8c4e-4a7e-8613-14387dc53bca"],
Cell[601157, 18171, 591, 15, 23, "Print", "ExpressionUUID" -> \
"bb85cc19-30be-42bd-bec7-836e57696f3b"],
Cell[601751, 18188, 12419, 382, 508, "Output", "ExpressionUUID" -> \
"224f627b-7956-4615-8ab5-c9356b5c13d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[614207, 18575, 367, 8, 29, "Input", "ExpressionUUID" -> \
"a488be41-1c98-4b5e-aaea-bb2fc53e2ab2"],
Cell[614577, 18585, 305, 7, 23, "Print", "ExpressionUUID" -> \
"55d7a3a8-c288-4dbb-95fe-c352b36fd5e2"],
Cell[614885, 18594, 591, 15, 23, "Print", "ExpressionUUID" -> \
"0a42526f-d14a-4b83-be12-99600603e9bc"],
Cell[615479, 18611, 11496, 351, 388, "Output", "ExpressionUUID" -> \
"158908f0-c94d-48b3-9dec-8a629524b159"]
}, Open  ]],
Cell[CellGroupData[{
Cell[627012, 18967, 579, 11, 29, "Input", "ExpressionUUID" -> \
"b7f40d11-8bec-4348-9df6-71dd0f13e889"],
Cell[627594, 18980, 514, 11, 23, "Print", "ExpressionUUID" -> \
"5d6b8315-7e48-422a-ba2a-bc6628c4641b"],
Cell[628111, 18993, 687, 17, 23, "Print", "ExpressionUUID" -> \
"b050c90b-aed6-4f5c-b56a-f3de0ff3ad5d"],
Cell[628801, 19012, 10713, 324, 422, "Output", "ExpressionUUID" -> \
"d5364552-978c-4abf-a603-84708052ba97"]
}, Open  ]],
Cell[CellGroupData[{
Cell[639551, 19341, 499, 10, 29, "Input", "ExpressionUUID" -> \
"e99bd73b-31ce-49a7-8483-514fe779ffab"],
Cell[640053, 19353, 407, 9, 23, "Print", "ExpressionUUID" -> \
"012a1f68-f821-4b96-9d61-30c8c4be6691"],
Cell[640463, 19364, 585, 15, 23, "Print", "ExpressionUUID" -> \
"91511c6d-c99c-451a-94b3-80e5c49355d0"],
Cell[641051, 19381, 11810, 362, 422, "Output", "ExpressionUUID" -> \
"a69fd189-a300-4e0c-959a-421b77740723"]
}, Open  ]],
Cell[CellGroupData[{
Cell[652898, 19748, 476, 10, 29, "Input", "ExpressionUUID" -> \
"771e5c65-a23c-4e3b-a672-6f18e6e5dd40"],
Cell[653377, 19760, 383, 9, 23, "Print", "ExpressionUUID" -> \
"15e37967-c4b9-4227-a6b7-75bbd73b2150"],
Cell[653763, 19771, 565, 15, 23, "Print", "ExpressionUUID" -> \
"0b2282c8-a63e-4001-b7fe-94657d362bed"],
Cell[654331, 19788, 8680, 262, 338, "Output", "ExpressionUUID" -> \
"5ef5dafa-6e4f-4749-8430-9f865e01cb4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[663048, 20055, 427, 10, 29, "Input", "ExpressionUUID" -> \
"d26e7062-6899-4af7-92f3-ecc2451fd516"],
Cell[663478, 20067, 334, 8, 23, "Print", "ExpressionUUID" -> \
"064ec06d-e4aa-4740-bb13-cbc772a9e141"],
Cell[663815, 20077, 509, 13, 23, "Print", "ExpressionUUID" -> \
"322c10c5-4b5e-469a-ae68-1e412a6563ea"],
Cell[664327, 20092, 8311, 249, 270, "Output", "ExpressionUUID" -> \
"f1b26440-aa64-40d4-b29c-82c94f6d0c2f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[672675, 20346, 503, 10, 29, "Input", "ExpressionUUID" -> \
"8235e348-f70f-43fb-9a8e-cc9e1cc49a4f"],
Cell[673181, 20358, 398, 9, 23, "Print", "ExpressionUUID" -> \
"25061e12-5b2e-4544-81f2-1f8fa11c06b0"],
Cell[673582, 20369, 580, 15, 23, "Print", "ExpressionUUID" -> \
"4f6a578b-9022-4a38-b4df-88a2860894c7"],
Cell[674165, 20386, 6402, 190, 236, "Output", "ExpressionUUID" -> \
"4f6cb6e7-e775-48dc-a2ab-7f4c5ffa07f8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[680604, 20581, 473, 10, 29, "Input", "ExpressionUUID" -> \
"2ac57a7d-8742-46b2-ac8b-d2e7953de01e"],
Cell[681080, 20593, 377, 9, 23, "Print", "ExpressionUUID" -> \
"5eb5015d-a134-48e4-91af-d532388b6ef6"],
Cell[681460, 20604, 557, 14, 23, "Print", "ExpressionUUID" -> \
"a7b116d6-b69d-4742-af30-16746220e7a0"],
Cell[682020, 20620, 7372, 222, 252, "Output", "ExpressionUUID" -> \
"f89c451d-81de-45f3-9fb9-f56822285d24"]
}, Open  ]],
Cell[CellGroupData[{
Cell[689429, 20847, 397, 9, 29, "Input", "ExpressionUUID" -> \
"2d4787fe-3dc2-4e65-90f4-ca67ea348d53"],
Cell[689829, 20858, 360, 9, 23, "Print", "ExpressionUUID" -> \
"4b0d47af-3ffc-4a32-badd-49cb554150a7"],
Cell[690192, 20869, 542, 15, 23, "Print", "ExpressionUUID" -> \
"7ea56995-f574-41a2-bc99-103a05ca3a34"],
Cell[690737, 20886, 7539, 226, 286, "Output", "ExpressionUUID" -> \
"7ded9aa8-51db-4d3a-a249-55e7c61462e4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[698313, 21117, 402, 10, 29, "Input", "ExpressionUUID" -> \
"7544a714-78ba-44c8-a1a4-99360da79887"],
Cell[698718, 21129, 332, 8, 23, "Print", "ExpressionUUID" -> \
"20cb5217-29fa-49b2-a6ad-096faf7a700b"],
Cell[699053, 21139, 515, 14, 23, "Print", "ExpressionUUID" -> \
"da3d900c-b7d1-4985-93d3-b650ab7da55f"],
Cell[699571, 21155, 8355, 250, 270, "Output", "ExpressionUUID" -> \
"68d38470-911c-4b18-8b5a-2588fdb0ee08"]
}, Open  ]],
Cell[CellGroupData[{
Cell[707963, 21410, 494, 10, 29, "Input", "ExpressionUUID" -> \
"4d926033-b15f-4ad3-9a59-92adfe00ea50"],
Cell[708460, 21422, 431, 9, 23, "Print", "ExpressionUUID" -> \
"847b0755-9f92-4a25-806a-0004315ffb35"],
Cell[708894, 21433, 609, 15, 23, "Print", "ExpressionUUID" -> \
"5f2ab0d2-5ea3-4d91-9137-0081c74d24d1"],
Cell[709506, 21450, 12318, 370, 490, "Output", "ExpressionUUID" -> \
"61e709e1-724c-4ef4-a133-93dec3482265"]
}, Open  ]],
Cell[CellGroupData[{
Cell[721861, 21825, 347, 8, 29, "Input", "ExpressionUUID" -> \
"588646f3-d885-414c-a098-4b90747a8b5f"],
Cell[722211, 21835, 310, 8, 23, "Print", "ExpressionUUID" -> \
"e0ba67b4-c9d6-446d-9a5a-9e682f13eda2"],
Cell[722524, 21845, 493, 14, 23, "Print", "ExpressionUUID" -> \
"ce044a40-ab9a-4a87-b926-baca26668858"],
Cell[723020, 21861, 8673, 263, 304, "Output", "ExpressionUUID" -> \
"d4d80125-e200-48a3-aaa7-72f97b3618c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[731730, 22129, 429, 9, 29, "Input", "ExpressionUUID" -> \
"3936fbdb-1aa1-4e23-af55-ddedf6de538d"],
Cell[732162, 22140, 356, 8, 23, "Print", "ExpressionUUID" -> \
"7c097a8d-8a56-4307-8b70-47d7874bfc14"],
Cell[732521, 22150, 537, 14, 23, "Print", "ExpressionUUID" -> \
"e9de064d-bc84-44a8-8fa6-74e8b32b6ddf"],
Cell[733061, 22166, 11884, 357, 474, "Output", "ExpressionUUID" -> \
"7d1d521b-817c-45a8-969a-fef1b9e094ee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[744982, 22528, 358, 8, 29, "Input", "ExpressionUUID" -> \
"73c92da6-6393-4543-bf7f-655579206e0d"],
Cell[745343, 22538, 308, 8, 23, "Print", "ExpressionUUID" -> \
"3ca12c0c-c49e-4173-ab03-20394b55c7af"],
Cell[745654, 22548, 600, 16, 23, "Print", "ExpressionUUID" -> \
"5e366efe-d7f8-4dd8-a127-2e122198f824"],
Cell[746257, 22566, 9289, 279, 304, "Output", "ExpressionUUID" -> \
"10aa144c-f342-47b3-883a-4ca7c0386d8b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[755595, 22851, 379, 9, 29, "Input", "ExpressionUUID" -> \
"6d08e66c-7333-4c8d-9d73-479717a466f9"],
Cell[755977, 22862, 310, 8, 23, "Print", "ExpressionUUID" -> \
"05a8c905-97d7-46f4-b299-b443d92ec308"],
Cell[756290, 22872, 493, 14, 23, "Print", "ExpressionUUID" -> \
"30c4fd37-82e4-4d94-9fea-ace5df165088"],
Cell[756786, 22888, 9105, 273, 354, "Output", "ExpressionUUID" -> \
"2de9c059-652e-4504-b898-906e63dc9dce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[765928, 23166, 349, 8, 29, "Input", "ExpressionUUID" -> \
"76928609-da2b-46e5-879d-28bef608b9fc"],
Cell[766280, 23176, 310, 8, 23, "Print", "ExpressionUUID" -> \
"497e1c37-144d-484b-bebc-fdc7b0e575c2"],
Cell[766593, 23186, 372, 9, 21, "Message", "ExpressionUUID" -> \
"5556ac9f-724e-44fe-9c58-2ad34129435d"],
Cell[766968, 23197, 494, 14, 23, "Print", "ExpressionUUID" -> \
"42a04753-9843-4291-8f75-c0e911cb6e17"],
Cell[767465, 23213, 10064, 305, 354, "Output", "ExpressionUUID" -> \
"b4b5b67f-f34b-4621-a1c8-d400e50e1c75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[777566, 23523, 349, 8, 29, "Input", "ExpressionUUID" -> \
"25524dab-bd80-46d4-b31f-ed17b7ec4991"],
Cell[777918, 23533, 310, 8, 23, "Print", "ExpressionUUID" -> \
"166d05c0-5091-41e5-a3b0-dbad83c3fc48"],
Cell[778231, 23543, 372, 9, 21, "Message", "ExpressionUUID" -> \
"ab18d880-c7bb-4eca-a488-2fccc1844b95"],
Cell[778606, 23554, 494, 14, 23, "Print", "ExpressionUUID" -> \
"f4e10a83-8986-4bcf-aeaa-37b32bc032b9"],
Cell[779103, 23570, 8728, 261, 338, "Output", "ExpressionUUID" -> \
"6c691a6a-7e89-432d-a46c-9cf3af1be387"]
}, Open  ]],
Cell[CellGroupData[{
Cell[787868, 23836, 448, 9, 29, "Input", "ExpressionUUID" -> \
"ad99ada4-90ec-41e9-bf70-d9d2bfc22691"],
Cell[788319, 23847, 328, 8, 23, "Print", "ExpressionUUID" -> \
"1017a9a7-fdce-41a4-819d-b8325012d809"],
Cell[788650, 23857, 371, 9, 21, "Message", "ExpressionUUID" -> \
"c19cdfeb-7b0d-4ec7-a9e3-84aec75ae0eb"],
Cell[789024, 23868, 521, 14, 23, "Print", "ExpressionUUID" -> \
"8568a8d3-32bb-4168-b944-5df37f30bf5f"],
Cell[789548, 23884, 6976, 208, 236, "Output", "ExpressionUUID" -> \
"f8b78e65-4307-49e2-bd64-878478905eda"]
}, Open  ]],
Cell[CellGroupData[{
Cell[796561, 24097, 461, 11, 29, "Input", "ExpressionUUID" -> \
"9efc55b6-2e2c-48aa-a1ce-c5271060663a"],
Cell[797025, 24110, 308, 8, 23, "Print", "ExpressionUUID" -> \
"0d262fa0-c2aa-4b77-81e0-61ebd75e4da0"],
Cell[797336, 24120, 373, 9, 21, "Message", "ExpressionUUID" -> \
"212b1fed-2a5b-42d4-805e-19c0c06f5540"],
Cell[797712, 24131, 495, 14, 23, "Print", "ExpressionUUID" -> \
"ea66be39-fca8-41d6-ab58-3ddf4f6624cf"],
Cell[798210, 24147, 5980, 177, 218, "Output", "ExpressionUUID" -> \
"1e87073a-32c5-4e9c-918a-b7b8c28bda72"]
}, Open  ]],
Cell[CellGroupData[{
Cell[804227, 24329, 641, 13, 29, "Input", "ExpressionUUID" -> \
"0969e006-3568-4e47-a32f-564e93179526"],
Cell[804871, 24344, 409, 10, 23, "Print", "ExpressionUUID" -> \
"14f06483-8896-49be-9a00-becc36f0bfbc"],
Cell[805283, 24356, 594, 16, 23, "Print", "ExpressionUUID" -> \
"a5d5cf63-6573-40df-9b2c-bfa70ff76879"],
Cell[805880, 24374, 6617, 195, 218, "Output", "ExpressionUUID" -> \
"2e7f534b-48f5-436c-9d61-0a3ae3a035b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[812534, 24574, 79, 0, 71, "Section", "ExpressionUUID" -> \
"8bf7303f-54be-4ad8-bf52-5df079b12632"],
Cell[CellGroupData[{
Cell[812638, 24578, 396, 9, 29, "Input", "ExpressionUUID" -> \
"4e934d2e-db07-4974-bfa9-d84ed9477a2c"],
Cell[813037, 24589, 352, 8, 23, "Print", "ExpressionUUID" -> \
"42da8dd1-50e4-43e9-ad83-3305142bd58c"],
Cell[813392, 24599, 529, 14, 23, "Print", "ExpressionUUID" -> \
"8c6c413f-5899-4abe-b351-422a231fc4cd"],
Cell[813924, 24615, 39731, 1245, 1732, "Output", "ExpressionUUID" -> \
"145960c5-399f-4fa6-89ec-b93e469a77df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[853692, 25865, 472, 10, 29, "Input", "ExpressionUUID" -> \
"a022b127-c1d2-4dc0-945d-66c77b142709"],
Cell[854167, 25877, 404, 9, 23, "Print", "ExpressionUUID" -> \
"6a4d383a-98ae-4ac8-99bc-01eb6ec92d3b"],
Cell[854574, 25888, 579, 15, 23, "Print", "ExpressionUUID" -> \
"92948178-9130-4e3c-b933-4845179aeca7"],
Cell[855156, 25905, 40306, 1258, 1748, "Output", "ExpressionUUID" -> \
"25671b72-0603-4e79-96bb-6fdea94caf7b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[895499, 27168, 445, 9, 29, "Input", "ExpressionUUID" -> \
"fb3dd395-0c45-4640-9e29-2c0b16a330c9"],
Cell[895947, 27179, 431, 10, 23, "Print", "ExpressionUUID" -> \
"b60d7e43-f5e8-4b55-b430-e09e384b6143"],
Cell[896381, 27191, 608, 16, 23, "Print", "ExpressionUUID" -> \
"fba11418-71e6-4485-96a4-4a3a5e3e1f16"],
Cell[896992, 27209, 21650, 671, 916, "Output", "ExpressionUUID" -> \
"c98e9a60-4ace-4d99-bb40-ac3d21ecdd58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[918679, 27885, 402, 9, 29, "Input", "ExpressionUUID" -> \
"9627a7a3-bd0c-4472-88d1-c46e3fb9322d"],
Cell[919084, 27896, 351, 7, 23, "Print", "ExpressionUUID" -> \
"71993968-4a57-4e9d-b08e-28fafef6fa53"],
Cell[919438, 27905, 531, 14, 23, "Print", "ExpressionUUID" -> \
"38adc620-6bbb-4a98-86b9-0abee310ac4b"],
Cell[919972, 27921, 21620, 669, 916, "Output", "ExpressionUUID" -> \
"8c1a0005-c22b-4d76-a8f7-3d97b1daa99c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[941629, 28595, 529, 11, 29, "Input", "ExpressionUUID" -> \
"a5f4d183-bd8a-4966-9b16-9b82b594d82d"],
Cell[942161, 28608, 423, 9, 23, "Print", "ExpressionUUID" -> \
"99733039-852c-48d9-93e2-071e2fb998fe"],
Cell[942587, 28619, 602, 15, 23, "Print", "ExpressionUUID" -> \
"0473210f-d00b-47ac-a29b-f378849e6f94"],
Cell[943192, 28636, 19469, 598, 814, "Output", "ExpressionUUID" -> \
"6714a411-8c1b-4f08-b399-a4d4af0f8057"]
}, Open  ]],
Cell[CellGroupData[{
Cell[962698, 29239, 396, 9, 29, "Input", "ExpressionUUID" -> \
"68d2ca47-790e-4517-804f-4ec62dfbee53"],
Cell[963097, 29250, 352, 8, 23, "Print", "ExpressionUUID" -> \
"262d4120-546c-42fb-ba2c-941132b077ab"],
Cell[963452, 29260, 534, 14, 23, "Print", "ExpressionUUID" -> \
"c088337d-1441-4ffa-b1b9-2ce87ce17f5a"],
Cell[963989, 29276, 11711, 357, 474, "Output", "ExpressionUUID" -> \
"e55a4d9a-6a18-4b3c-8359-1f3cafb04424"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[975749, 29639, 549, 11, 29, "Input", "ExpressionUUID" -> \
"06ae9cc2-7c8f-4991-acc6-2ea11dc4edc0"],
Cell[976301, 29652, 403, 9, 23, "Print", "ExpressionUUID" -> \
"16bde296-f879-4d57-bee2-c123c8a8dd45"],
Cell[976707, 29663, 581, 15, 23, "Print", "ExpressionUUID" -> \
"038d0e03-7586-4a5c-a00a-0efcf1c066b1"],
Cell[977291, 29680, 9090, 274, 354, "Output", "ExpressionUUID" -> \
"a958f238-aed9-42eb-8227-7668c888f819"]
}, Open  ]],
Cell[CellGroupData[{
Cell[986418, 29959, 395, 9, 29, "Input", "ExpressionUUID" -> \
"e73fd28e-bc0d-4080-8aa8-b63e389eda7d"],
Cell[986816, 29970, 330, 8, 23, "Print", "ExpressionUUID" -> \
"2464f5d7-7512-480e-a283-2fcc6c61af88"],
Cell[987149, 29980, 513, 14, 23, "Print", "ExpressionUUID" -> \
"67f387c9-e5a3-4beb-88ce-135e0119f011"],
Cell[987665, 29996, 8269, 249, 320, "Output", "ExpressionUUID" -> \
"345125a7-c3c8-4213-9db6-ebac61307ff8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[995971, 30250, 397, 9, 29, "Input", "ExpressionUUID" -> \
"fa2b383e-fb64-401d-88bf-d54251cfec61"],
Cell[996371, 30261, 306, 8, 23, "Print", "ExpressionUUID" -> \
"b3ad169e-ad50-4b8c-a3d1-abcb2ea39110"],
Cell[996680, 30271, 374, 9, 21, "Message", "ExpressionUUID" -> \
"d8f55167-632b-4268-bd92-737e0025e7b2"],
Cell[997057, 30282, 494, 14, 23, "Print", "ExpressionUUID" -> \
"7b259555-82cf-4394-b957-be02b65917af"],
Cell[997554, 30298, 5932, 177, 218, "Output", "ExpressionUUID" -> \
"b30c5206-3b03-4691-9432-57dd7f69678a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1003523, 30480, 555, 11, 29, "Input", "ExpressionUUID" -> \
"7c6567e9-09d3-429f-822a-4dddcb3c9d86"],
Cell[1004081, 30493, 306, 8, 23, "Print", "ExpressionUUID" -> \
"292f0c17-f612-4b0b-b398-9cc789958af8"],
Cell[1004390, 30503, 374, 9, 21, "Message", "ExpressionUUID" -> \
"573e52ab-b97b-4bc9-b251-7a1d2f9882cd"],
Cell[1004767, 30514, 494, 14, 23, "Print", "ExpressionUUID" -> \
"b79b3489-621e-47cc-b334-14b3fb7af658"],
Cell[1005264, 30530, 6403, 190, 236, "Output", "ExpressionUUID" -> \
"458d9e3d-5b87-4105-9bbc-bb5c8c4ed762"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1011704, 30725, 475, 10, 29, "Input", "ExpressionUUID" -> \
"fadf1283-47cc-4567-9ed9-9c1868f51456"],
Cell[1012182, 30737, 330, 8, 23, "Print", "ExpressionUUID" -> \
"ae0bf407-f535-4885-9452-d1737d999b8e"],
Cell[1012515, 30747, 517, 14, 23, "Print", "ExpressionUUID" -> \
"f1c06631-4bf6-48e2-86a8-2e1d493aa0fb"],
Cell[1013035, 30763, 5585, 165, 202, "Output", "ExpressionUUID" -> \
"c4a803e1-fe7a-4fc7-ab77-132e349a414f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1018657, 30933, 452, 10, 29, "Input", "ExpressionUUID" -> \
"0b9ebda7-ace4-43b9-8a38-3467ac7849ac"],
Cell[1019112, 30945, 308, 8, 23, "Print", "ExpressionUUID" -> \
"bcc8d31d-63b2-47f4-9e57-d92db9e20b42"],
Cell[1019423, 30955, 493, 14, 23, "Print", "ExpressionUUID" -> \
"7c25e6f0-f0f3-4f21-92ac-bec5dc342bee"],
Cell[1019919, 30971, 5570, 165, 202, "Output", "ExpressionUUID" -> \
"a918f6d3-98d4-4abf-8e3c-ac62695279eb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1025526, 31141, 582, 11, 29, "Input", "ExpressionUUID" -> \
"03320505-2615-46fb-80a8-919e6da1b374"],
Cell[1026111, 31154, 357, 8, 23, "Print", "ExpressionUUID" -> \
"74f7ac3e-bfa7-4d71-b18b-7eda3f23968d"],
Cell[1026471, 31164, 538, 14, 23, "Print", "ExpressionUUID" -> \
"15db824d-6ab0-42c5-b5f4-104e28991c85"],
Cell[1027012, 31180, 6028, 177, 218, "Output", "ExpressionUUID" -> \
"17751f55-4deb-4834-bf84-6360e782a92b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1033077, 31362, 582, 11, 29, "Input", "ExpressionUUID" -> \
"f6bd84f6-d19a-48a4-a891-bc165c1d76e6"],
Cell[1033662, 31375, 332, 8, 23, "Print", "ExpressionUUID" -> \
"3585be19-8681-4189-8efe-b7ed3403b73b"],
Cell[1033997, 31385, 514, 14, 23, "Print", "ExpressionUUID" -> \
"8d176ab2-e112-4921-8fa8-fe6a14f8d48a"],
Cell[1034514, 31401, 5613, 165, 202, "Output", "ExpressionUUID" -> \
"d9d10f0e-1afd-4253-adeb-6559821f7800"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1040164, 31571, 94, 0, 71, "Section", "ExpressionUUID" -> \
"42746faa-31ac-448c-99e3-fb52eb158860"],
Cell[CellGroupData[{
Cell[1040283, 31575, 621, 14, 48, "Input", "ExpressionUUID" -> \
"2825ae6e-e89e-4068-b6af-06e3d91d4aaa"],
Cell[1040907, 31591, 332, 8, 23, "Print", "ExpressionUUID" -> \
"475e2de8-1a79-4f07-a00b-85552062f504"],
Cell[1041242, 31601, 624, 16, 23, "Print", "ExpressionUUID" -> \
"86118b89-f757-4bfd-9e34-002062c60fb7"],
Cell[1041869, 31619, 24546, 732, 900, "Output", "ExpressionUUID" -> \
"fa11d5b6-82ec-4b5b-9ba0-5bd37544dcc5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1066452, 32356, 346, 8, 29, "Input", "ExpressionUUID" -> \
"ee47c5b8-c6e1-4a36-9983-650d48ddb32e"],
Cell[1066801, 32366, 331, 8, 23, "Print", "ExpressionUUID" -> \
"4dc3488d-0b8d-4764-8c75-10e2466796f7"],
Cell[1067135, 32376, 504, 14, 23, "Print", "ExpressionUUID" -> \
"8a21e550-5c1e-4c88-9cbe-27af4fdf6368"],
Cell[1067642, 32392, 14072, 429, 576, "Output", "ExpressionUUID" -> \
"cc277b0e-a918-4048-bc48-09e6d56e3fd4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1081751, 32826, 350, 8, 29, "Input", "ExpressionUUID" -> \
"4872f870-b3f5-496b-934b-04bc9d4c6e90"],
Cell[1082104, 32836, 354, 8, 23, "Print", "ExpressionUUID" -> \
"e624a91e-0a81-4a98-9468-446647cd8611"],
Cell[1082461, 32846, 532, 14, 23, "Print", "ExpressionUUID" -> \
"ece9aa32-87fb-4bdc-b959-f0a739d0e778"],
Cell[1082996, 32862, 8348, 249, 320, "Output", "ExpressionUUID" -> \
"adce3bc5-057d-4f01-9dcc-5ffd01217565"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1091381, 33116, 443, 9, 29, "Input", "ExpressionUUID" -> \
"e9cae6c3-af54-4fe9-b351-f9876fc2dcf2"],
Cell[1091827, 33127, 412, 10, 23, "Print", "ExpressionUUID" -> \
"5a573a9e-043d-4394-928e-b7fd18865977"],
Cell[1092242, 33139, 591, 16, 23, "Print", "ExpressionUUID" -> \
"fb220a63-01bd-4fd2-9c5a-e2936126a9bd"],
Cell[1092836, 33157, 40776, 1259, 1748, "Output", "ExpressionUUID" -> \
"3ca6f3ec-da78-4b8b-9648-22a34b4e8e9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1133649, 34421, 445, 9, 29, "Input", "ExpressionUUID" -> \
"4c990ef4-28ef-48f1-ab88-d1faa44b5ef4"],
Cell[1134097, 34432, 380, 9, 23, "Print", "ExpressionUUID" -> \
"a1a3fccb-1ff6-4fd3-bdce-4bb20eb123e2"],
Cell[1134480, 34443, 557, 15, 23, "Print", "ExpressionUUID" -> \
"c8487a81-32b0-46d3-a5a6-bb9299383c91"],
Cell[1135040, 34460, 40331, 1258, 1748, "Output", "ExpressionUUID" -> \
"17beb7c6-2540-42fd-bc95-daaaede72f02"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

