(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1998170,      67419]
NotebookOptionsPosition[   1968798,      66764]
NotebookOutlinePosition[   1969510,      66788]
CellTagsIndexPosition[   1969467,      66785]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Tables of Tensor Products", "Title",ExpressionUUID->"e5d4ffd4-6386-4fac-bd70-0c1c800a6940"],

Cell[TextData[{
 "following R. Slansky, ",
 StyleBox["\"Group Theory for Unified Model Building\"",
  FontSlant->"Italic"],
 ", Phys.Rept. ",
 StyleBox["79",
  FontWeight->"Bold"],
 " (1981) 1 - 128"
}], "Subsubtitle",ExpressionUUID->"ace8d606-280f-4dbd-894e-acb0acdbcef8"],

Cell[CellGroupData[{

Cell["Initialization", "Section",ExpressionUUID->"d2eb2164-b67a-448d-b12b-54bc20cb8252"],

Cell[BoxData[
 RowBox[{"<<", "LieART`Tables`"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"7fc4d170-2abe-4949-9fff-b187e818401e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$WriteToLaTeXFile", "=", "False"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "$TensorProductsLaTeXFile", "=", "\"\<TensorProductsTables.tex\>\""}], 
  ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"180d65e1-1f5c-49e4-a566-061e1f02364a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"FileExistsQ", "[", "$TensorProductsLaTeXFile", "]"}], ",", 
    RowBox[{"DeleteFile", "[", "$TensorProductsLaTeXFile", "]"}]}], "]"}], 
  ";"}]], "Input",ExpressionUUID->"9ef8c7e4-0b04-4a21-89c3-3f42ae86d650"]
}, Closed]],

Cell[CellGroupData[{

Cell["SU(N)", "Section",ExpressionUUID->"6d3278ed-ec18-4107-aa12-9cdb3be52c6c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU2", ",", 
   RowBox[{"MaxDim", "\[Rule]", "10"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "11"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "100"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.780162920068121*^9, 3.7801629612537165`*^9}, 
   3.7801630947865076`*^9, {3.7835372156923666`*^9, 
   3.7835372163845277`*^9}},ExpressionUUID->"40ab07f8-738d-4ac0-9cdc-\
a65a3f17fe4c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162181358183613`*^9, {3.7801629269844723`*^9, 3.7801629624307747`*^9}, 
   3.780163096588928*^9, 
   3.783537220983342*^9},ExpressionUUID->"5c78ba4c-b6ff-494c-98a0-\
afb3a3d4cac8"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.6\"\>",
      0.5614335,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.5614335, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162181358183613`*^9, {3.7801629269844723`*^9, 3.7801629624307747`*^9}, 
   3.780163096588928*^9, 
   3.783537220987298*^9},ExpressionUUID->"057545bc-987e-47b0-8440-\
e28dc904ba2f"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "55", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(2)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616218135902975*^9, {3.7801629271101556`*^9, 3.7801629625295353`*^9}, 
   3.7801630967634687`*^9, 
   3.7835372210431786`*^9},ExpressionUUID->"299fb113-2e99-465e-ac84-\
57013b42149a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU3", ",", 
   RowBox[{"MaxDim", "\[Rule]", "35"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.780163178109907*^9, 3.780163217398841*^9}, {
  3.7823145105008125`*^9, 
  3.7823145468928585`*^9}},ExpressionUUID->"b80d58a5-50b4-453b-9b19-\
2b8551d60616"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "91"}],
   
   SequenceForm["Number of Tensor Products: ", 91],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616218144085372*^9, {3.7801631850890894`*^9, 3.7801632226810436`*^9}, 
   3.7823145347325554`*^9},ExpressionUUID->"53ea4f2d-1b23-4d64-974a-\
f0ee5ce9cc6d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"4.5\"\>",
      4.4508722,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[4.4508722, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616218144085372*^9, {3.7801631850890894`*^9, 3.7801632226810436`*^9}, 
   3.782314534735511*^9},ExpressionUUID->"a47a0f33-944e-4fba-bf00-\
9a72c86110ae"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "25", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(3)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["24", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["63", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["63", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["63", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["165", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["66", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["99", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["63", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["42", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["99", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["154", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["24", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["42", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["48", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["42",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["42",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["60",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["35", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["154", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["120",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["120",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["192",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["162",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["343",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["143",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["162",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6162181442845373`*^9, {3.780163185292568*^9, 3.780163222781787*^9}, 
   3.782314534948968*^9},ExpressionUUID->"fcfa0e7d-19aa-4cb0-a336-\
816ef31b400d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU4", ",", 
   RowBox[{"MaxDim", "\[Rule]", "50"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1170"}]}], "]"}]], "Input",Expression\
UUID->"df39dbcc-4a8e-4f7a-8cae-84163e70f148"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "94"}],
   
   SequenceForm["Number of Tensor Products: ", 94],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616218154587075*^9},ExpressionUUID->"6bf2bd36-439e-44da-880b-\
c3ac6ed6a296"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"10.2\"\>",
      10.1618969999999997355644154595211148262`7.027574701909566,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    10.1618969999999997355644154595211148262`7.027574701909566, {3, 1}], "s"],
   
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162181546038733`*^9},ExpressionUUID->"a7f67316-8609-41f2-aaea-\
d81a7b1dfdd1"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SU(4)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["20",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["270", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["120",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["360",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["360",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["45", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["270", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["420", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["280",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["270",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["140",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["875",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["360",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["20",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["140",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["60",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["84",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["256",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["360",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["360", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["480", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["360", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["196",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["360", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["540",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["735",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616218154837469*^9},ExpressionUUID->"9fefbf8e-53e1-4457-9aa1-\
aeee67f18689"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU5", ",", 
   RowBox[{"MaxDim", "\[Rule]", "75"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "3000"}]}], "]"}]], "Input",Expression\
UUID->"90f411cd-e3ef-409e-8e53-94596560e0ef"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "91"}],
   
   SequenceForm["Number of Tensor Products: ", 91],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616218168298293*^9},ExpressionUUID->"17c9f149-2484-4f43-8f1c-\
24ea5bb2513a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"13.4\"\>",
      13.38841500000000017678303265711292624474`7.1473290789773625,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    13.38841500000000017678303265711292624474`7.1473290789773625, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616218168322723*^9},ExpressionUUID->"aed12bd5-c14b-444b-a722-\
cb6a9146c3a6"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SU(5)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["70", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["70", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["450", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["315",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["420", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["480", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["420", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["450", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["280",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["700", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["700", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["75",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["700", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["700", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["700", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1176",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["450", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["450",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["315", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["450", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["280",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["450",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["70",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["560",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["875", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1215", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["70",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["450", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1215", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["126", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1701", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1890",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["200",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1050",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["75",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["280",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["280",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["280",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["75",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["700",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["700", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1024",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1176",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616218168761383*^9},ExpressionUUID->"652abb6e-085c-4372-ae08-\
4519cd48b629"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU6", ",", 
   RowBox[{"MaxDim", "\[Rule]", "105"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "5670"}]}], "]"}]], "Input",Expression\
UUID->"5df806de-7931-4477-bcf6-ddb842dc3c47"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "90"}],
   
   SequenceForm["Number of Tensor Products: ", 90],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61621818892944*^9},ExpressionUUID->"0ef916c1-0e45-4cb7-a44f-96bc6defc877"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"20.1\"\>",
      20.07778599999999968872543831821531057358`7.323315734252836,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    20.07778599999999968872543831821531057358`7.323315734252836, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616218188945546*^9},ExpressionUUID->"67e3a996-cb2a-4fc2-9838-\
9909a573df26"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SU(6)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["252", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1134",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2695",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1050",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1134",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1134",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1050",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1134",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3675",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1134",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1134",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1260",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1701", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2688", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1701", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2205", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["384",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1176",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["384",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1176",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1701",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["896", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3675",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1176", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["840", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1701", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1134",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1701",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4500", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2520",
              FontWeight->Bold], "\[Prime]\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1800",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5040", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4410", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1176",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1764",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["840",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1176",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1134", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1960",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4536", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["70", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["540",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1134", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1960",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3240", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2520", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4410", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["840", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4410", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1764", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2520", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4410", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1470", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2430", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4410", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["384", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1470", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2430", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2520", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3675",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5670", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["896", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3675",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3969",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6162181901232367`*^9},ExpressionUUID->"f1c060e7-3d43-49c9-99f6-\
4ee6f02dc6de"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU7", ",", 
   RowBox[{"MaxDim", "\[Rule]", "112"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "10000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.782315915193164*^9, 3.7823159212192326`*^9}, 
   3.7823159755890846`*^9, {3.7823161743524275`*^9, 3.7823161761855564`*^9}, {
   3.782316321820687*^9, 3.7823163222226486`*^9}, 3.7823163820534782`*^9, 
   3.7823164310211525`*^9, {3.7823166320420465`*^9, 3.782316632350232*^9}, {
   3.7835372395110865`*^9, 
   3.7835372466102257`*^9}},ExpressionUUID->"c38f4105-d508-4328-b07d-\
a9b39f7824d1"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "48"}],
   
   SequenceForm["Number of Tensor Products: ", 48],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.61621820950602*^9, 3.782315944389326*^9, 
  3.7823160165085087`*^9, 3.7823162116596594`*^9, 3.782316353943817*^9, 
  3.782316413197131*^9, 3.782316482705033*^9, 3.782316689028406*^9, 
  3.7835372631931577`*^9},ExpressionUUID->"afee6ed5-14fb-4504-a492-\
d7860eaa1353"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"15.6\"\>",
      15.616669,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[15.616669, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.61621820950602*^9, 3.782315944389326*^9, 
  3.7823160165085087`*^9, 3.7823162116596594`*^9, 3.782316353943817*^9, 
  3.782316413197131*^9, 3.782316482705033*^9, 3.782316689028406*^9, 
  3.78353726319615*^9},ExpressionUUID->"1764a028-1cd2-41ec-94a4-88bc49434059"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "56", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(7)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["392",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["196", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["735",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["196", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["588", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["490", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["392",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["784",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["490", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["588", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["735",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["735",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1323",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["392",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["735",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1575", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2156", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["882", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2400", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["735",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6272",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["924", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2310", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2646", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["735", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["196", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2016", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["490", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["882", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["490", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["882", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["392",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2940", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["588", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2352", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1260",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1323",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["735",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2310", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2646", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["490", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["588", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["2352", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2646", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616218217101057*^9, 3.7823159506138687`*^9, 
  3.782316016779751*^9, 3.782316212528333*^9, 3.7823163541592245`*^9, 
  3.7823164133716345`*^9, 3.7823164844424367`*^9, 3.782316689818303*^9, 
  3.783537267066867*^9},ExpressionUUID->"36184501-a77c-4422-9cae-\
607aa680c622"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU8", ",", 
   RowBox[{"MaxDim", "\[Rule]", "168"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "8000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.782316864391313*^9, 3.782316864949834*^9}, {
   3.7823172094037867`*^9, 3.782317209814703*^9}, 3.7823173102172823`*^9, 
   3.7823174446949067`*^9, 3.7823176048808937`*^9, {3.7835373349535074`*^9, 
   3.783537337186576*^9}, 
   3.7835374017265043`*^9},ExpressionUUID->"4f4e35ce-17dd-43f4-b5e2-\
a984c104358a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "53"}],
   
   SequenceForm["Number of Tensor Products: ", 53],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6162183008166447`*^9, 3.782316959371878*^9, 
  3.782317293259508*^9, 3.7823174301304283`*^9, 3.7823175837470627`*^9, 
  3.782317725249118*^9, 
  3.783537484046565*^9},ExpressionUUID->"45db7b40-5ac9-4fb9-b919-\
5edd72100e76"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"81.0\"\>",
      81.0472576,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[81.0472576, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6162183008166447`*^9, 3.782316959371878*^9, 
  3.782317293259508*^9, 3.7823174301304283`*^9, 3.7823175837470627`*^9, 
  3.782317725249118*^9, 
  3.7835374840495563`*^9},ExpressionUUID->"6f43fedf-2b2e-4f78-98fe-\
87b72cc828fa"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "57", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(8)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["945", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1344", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1512", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2352",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1512", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["63",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["945", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1512", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1344", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2352", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3584",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1764",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2352",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["924", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3080", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1512", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1848", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4032", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["792", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1680", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1848", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["945", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5775", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4620", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2520",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6600", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1716", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2520", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4620", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["5544", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["168", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1280", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["168", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1512", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1680", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["168", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5544", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1512", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1680", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1848", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["168", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["945", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7680", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1512", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5376", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4620", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4620", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5376", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["5544", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1512", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2520", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4620", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5376", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["5544", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616218319740636*^9, 3.782317001341858*^9, 
  3.7823172935018682`*^9, 3.7823174305353236`*^9, 3.782317583838832*^9, 
  3.7823177256330748`*^9, 
  3.7835375153504944`*^9},ExpressionUUID->"8a410830-e6a5-4d96-80ed-\
0c5b2b01f18d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU9", ",", 
   RowBox[{"MaxDim", "\[Rule]", "240"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "6000"}]}], "]"}]], "Input",
 CellChangeTimes->{3.7823183753469253`*^9, 3.782319283070651*^9, 
  3.7823198202456903`*^9, 
  3.7823201805728884`*^9},ExpressionUUID->"53878ede-4051-4fab-a88b-\
e3c31c6497a6"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "40"}],
   
   SequenceForm["Number of Tensor Products: ", 40],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616218708060522*^9, 3.7823187183033957`*^9, 
  3.782319626481905*^9, 3.7823201604755116`*^9, 
  3.7823205470226665`*^9},ExpressionUUID->"818af2b8-42b4-4a26-b939-\
ac66c40397a0"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"365.0\"\>",
      365.4991692,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[365.4991692, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616218708060522*^9, 3.7823187183033957`*^9, 
  3.782319626481905*^9, 3.7823201604755116`*^9, 
  3.7823205470256586`*^9},ExpressionUUID->"52247f10-c75e-4a92-bec2-\
7027e2bb7c57"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "48", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(9)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["9", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["9", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["9", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["396", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1540", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1944",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["396",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["80",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1944",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["9", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2700", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1890", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3465", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2772", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5346",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2520", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3402", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3780", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3402", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["165", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["165", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["396", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5544", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2772", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3168", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1287", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2970", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3168", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["240", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2079", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1890", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2772", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2970", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1890", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2772", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2970", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3168", "_"],
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6162187332560663`*^9, 3.78231871841107*^9, 
  3.7823196274044228`*^9, 3.782320160596154*^9, 
  3.7823205479591656`*^9},ExpressionUUID->"3096c180-83f4-4cc9-b23c-\
a71b9fd5b46f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU10", ",", 
   RowBox[{"MaxDim", "\[Rule]", "210"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "2000"}]}], "]"}]], "Input",Expression\
UUID->"b4722304-037a-4c61-b392-60840c4e4790"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "15"}],
   
   SequenceForm["Number of Tensor Products: ", 15],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162187854875298`*^9},ExpressionUUID->"cbdfe3c7-485d-4943-b876-\
09f74146e212"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"49.0\"\>",
      49.00505600000000328009264194406569004059`7.710840803096369,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    49.00505600000000328009264194406569004059`7.710840803096369, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616218785548381*^9},ExpressionUUID->"0191cb55-bbce-484d-ab36-\
29873ddb0b61"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "9", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SU(10)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["440", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["55", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1485",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1485",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1155", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1980", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1848",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616218931785667*^9},ExpressionUUID->"10ca03b7-44e7-41f5-bee1-\
a9da75a59b52"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU11", ",", 
   RowBox[{"MaxDim", "\[Rule]", "165"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1000"}]}], "]"}]], "Input",Expression\
UUID->"e9cd2577-7eaf-47ce-a843-9ff39e5f98ac"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of Tensor Products: ", 7],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616219030229354*^9},ExpressionUUID->"63f61bf5-4b58-4a45-ae1c-\
0866503bb08a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"80.7\"\>",
      80.72253200000000106228981167078018188477`7.927594689109841,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    80.72253200000000106228981167078018188477`7.927594689109841, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616219030257701*^9},ExpressionUUID->"63d67840-beb2-4ef8-9c5e-\
17f57c9b33a3"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "10", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SU(11)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["11", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["55", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["11", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["594", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["66", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["11", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616219118273116*^9},ExpressionUUID->"cdbf481f-bf83-4719-b8a3-\
5d3a3afaf7b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU12", ",", 
   RowBox[{"MaxDim", "\[Rule]", "220"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1300"}]}], "]"}]], "Input",Expression\
UUID->"8a4bb30e-3510-4f70-a053-4b4c661e8c1c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of Tensor Products: ", 7],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162231506138487`*^9},ExpressionUUID->"67191569-3884-4607-9e49-\
3c7456d16459"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"230.0\"\>",
      230.47705199999998626481101382523775100708`8.383227603587036,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    230.47705199999998626481101382523775100708`8.383227603587036, {3, 1}], 
    "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162231506532593`*^9},ExpressionUUID->"7f4a714d-8c68-4982-841b-\
f30e0020fa74"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SU(12)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["12", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["143",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["66", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["12", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["780", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["78", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["12", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["924", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["143",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6162235375415707`*^9},ExpressionUUID->"fe3ed4f5-0a42-418e-b595-\
8433b03e4801"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU13", ",", 
   RowBox[{"MaxDim", "\[Rule]", "168"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1170"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783537587175191*^9, 3.7835375874713993`*^9}, {
  3.7835377052894564`*^9, 3.783537714307413*^9}, {3.7835378181164913`*^9, 
  3.7835378252893405`*^9}},ExpressionUUID->"bfe47237-cebc-4496-9e52-\
b2ac46dc58db"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of Tensor Products: ", 7],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767152509324074`*^9, 3.7835376041556387`*^9, 
  3.7835383609740458`*^9},ExpressionUUID->"1a94eb90-9ea4-44f1-88d9-\
5b72dec117d9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"528.0\"\>",
      527.5436651,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[527.5436651, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767152509324074`*^9, 3.7835376041556387`*^9, 
  3.7835383609770384`*^9},ExpressionUUID->"835ce9db-18a2-4601-a087-\
e6879b8c62f1"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "59", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(13)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["13", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["78", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["13", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1001", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["91", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["13", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1170", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["455",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1170",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767153109955807`*^9, 3.7835376508869596`*^9, 
  3.7835397201296153`*^9},ExpressionUUID->"42b5f1fc-35e5-4502-ac55-\
f66143b4df67"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU14", ",", 
   RowBox[{"MaxDim", "\[Rule]", "364"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "15000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783540056385822*^9, 3.7835400566825895`*^9}, {
  3.783540685557063*^9, 3.78354068602845*^9}, {3.78354073156966*^9, 
  3.783540754252716*^9}},ExpressionUUID->"6e172edf-26d1-48b3-a68b-\
327477b634b5"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "11"}],
   
   SequenceForm["Number of Tensor Products: ", 11],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767153586031003`*^9, 3.783540481156803*^9, 3.7835407180158134`*^9, {
   3.7835407493253345`*^9, 
   3.783540770648018*^9}},ExpressionUUID->"f742ccce-8987-4252-bf5c-\
ee581ab89f59"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"15.8\"\>",
      15.7726735,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[15.7726735, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767153586031003`*^9, 3.783540481156803*^9, 3.7835407180158134`*^9, {
   3.7835407493253345`*^9, 
   3.7835407706510105`*^9}},ExpressionUUID->"fe3ae5da-336b-412a-ac4c-\
fb43a1fb19ba"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "63", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(14)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["14", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["195",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["91", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["14", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["91", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["195",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3185",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4095",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["195",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1260",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["195",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12544",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["195",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["195",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["195",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9360",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["9360", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["364", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["91", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5005", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4095",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767153586140404`*^9, 3.783540666667404*^9, 
  3.7835407180782614`*^9, 3.7835407494190316`*^9, 
  3.783540922221715*^9},ExpressionUUID->"0f7acd41-503a-421b-8c08-\
745a6b853241"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU15", ",", 
   RowBox[{"MaxDim", "\[Rule]", "455"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "17000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835416196063704`*^9, 
  3.783541621370804*^9}},ExpressionUUID->"b8db2eab-d5fe-42aa-8e1c-\
c250d188648b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "11"}],
   
   SequenceForm["Number of Tensor Products: ", 11],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776715413477965*^9, 
  3.783541664694786*^9},ExpressionUUID->"82aff1a3-cb5e-459a-83f6-\
1ab109f815e6"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"41.9\"\>",
      41.8949719,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[41.8949719, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776715413477965*^9, 
  3.7835416646978164`*^9},ExpressionUUID->"af475e40-6916-40b5-88b6-\
38bde0125d8f"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "65", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(15)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1560", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["455",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5460",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1785",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16575",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["224",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["12376", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["455", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6720", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["455",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5460",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.776715413632543*^9, 
  3.7835421742800465`*^9},ExpressionUUID->"b0f15af7-973a-4d75-a61e-\
ea3821f5a407"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU16", ",", 
   RowBox[{"MaxDim", "\[Rule]", "120"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "10000"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.783530482392804*^9, {3.7835305127057285`*^9, 3.783530527067353*^9}, {
   3.7835422301006346`*^9, 
   3.783542275283678*^9}},ExpressionUUID->"c8bfe028-9fb8-47ea-921f-\
0565a32b3263"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7835424090040727`*^9},ExpressionUUID->"7d21fa0a-17c5-4d85-9245-\
468316c7eda8"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"16.4\"\>",
      16.3905566,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[16.3905566, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7835424090040727`*^9},ExpressionUUID->"3e6f18b6-40ba-41e5-b218-\
9ba8da86e958"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "67", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SU(16)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["255",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1904", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1360",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7835443958291225`*^9},ExpressionUUID->"708e7974-08bb-4472-af2b-\
bb59acb1078f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SO(N)", "Section",ExpressionUUID->"d371eded-dfa3-4fcb-92c2-e205d3da51b7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO7", ",", 
   RowBox[{"MaxDim", "\[Rule]", "168"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "5000"}]}], "]"}]], "Input",Expression\
UUID->"a0c96267-4ca8-40be-8e66-1e3ba42023aa"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "76"}],
   
   SequenceForm["Number of Tensor Products: ", 76],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6162235781373158`*^9, 
  3.616224176084648*^9},ExpressionUUID->"2c64429c-56b5-4704-8a7e-\
bfe9f8290e1a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"4.2\"\>",
      4.22157400000000038176040106918662786484`6.64607431970658,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    4.22157400000000038176040106918662786484`6.64607431970658, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6162235781373158`*^9, 
  3.6162241761141157`*^9},ExpressionUUID->"12cafcec-3793-4939-9b8b-\
103764844d23"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SO(7)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["378",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1008",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["168",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3584",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["112",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1386",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2310",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2310",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["168",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1008",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1008",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2016",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3584",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["693",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1008",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3584",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["720",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4095",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["168",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["378",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["693",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["819",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3375",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616224176368766*^9},ExpressionUUID->"a24daaf6-6fd7-4676-bba6-\
57b4058f9690"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO8", ",", 
   RowBox[{"MaxDim", "\[Rule]", "160"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "4600"}]}], "]"}]], "Input",Expression\
UUID->"93a4c5d6-5579-40c6-adb8-37e19451015f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "92"}],
   
   SequenceForm["Number of Tensor Products: ", 92],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616224185311417*^9},ExpressionUUID->"c27024c3-cff7-4d22-ac39-\
33ade91fc1b8"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"8.9\"\>",
      8.86062699999999914268755674129351973534`6.968064368011541,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    8.86062699999999914268755674129351973534`6.968064368011541, {3, 1}], "s"],
   
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616224185331415*^9},ExpressionUUID->"fdbd4f7f-d834-46a3-aa3d-\
c62cafda40de"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SO(8)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["28",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["28",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "sc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["672",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["672",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1680",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1680",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1680",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1386",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1386",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "cs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["224",
               FontWeight->Bold], "cv"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["840",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["224",
               FontWeight->Bold], "vs"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["840",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["224",
               FontWeight->Bold], "vc"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["840",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["567",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["567",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["28",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["35",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["300",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["567",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["28",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["35",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["300",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["567",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "v"],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6162192387834263`*^9, 
  3.616224185795022*^9},ExpressionUUID->"39c9c31c-f5b1-4329-ab31-\
2174034e8785"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO9", ",", 
   RowBox[{"MaxDim", "\[Rule]", "495"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "90000"}]}], "]"}]], "Input",Expressio\
nUUID->"07801df0-2bc4-44b4-9bbc-91122aa857f3"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "78"}],
   
   SequenceForm["Number of Tensor Products: ", 78],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616224198814884*^9},ExpressionUUID->"81ecee6d-77c5-4eab-9863-\
d29db18eccac"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"12.5\"\>",
      12.46156000000000041438852349529042840004`7.116172326147207,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    12.46156000000000041438852349529042840004`7.116172326147207, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616224198840033*^9},ExpressionUUID->"8737cee0-b739-429e-9413-\
bf976e376df9"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SO(9)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4158",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4158",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12375",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2508",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["576",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["910",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["44",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["910",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["9009",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5040",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["12672",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2772",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4158",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19712",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27648",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["576",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5040",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19712",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2457",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["2772",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3900",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4158",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["9009",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12012",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15444",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15444",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25740",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2508",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12375",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20196",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12375",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["32725",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["12672",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27648",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5148",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["18018",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23868",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["2772",
               FontWeight->Bold], "\[Prime]\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20196",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23868",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19712",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27648",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["59136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["68640",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2508",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9867",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["22932",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33957",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54978",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15444",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12012",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23868",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2457",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2574",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4158",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12012",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15444",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["18018",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4928",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5040",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["12672",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19712",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34944",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65536",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["87516",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["9009",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["22932",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25740",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["71500",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616219238808076*^9, 
  3.616224199755629*^9},ExpressionUUID->"b825f0d9-1ade-438c-99dd-\
2a52844067bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO10", ",", 
   RowBox[{"MaxDim", "\[Rule]", "660"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "80000"}]}], "]"}]], "Input",Expressio\
nUUID->"ba056756-7f1d-45df-8fcd-26618e30daab"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "85"}],
   
   SequenceForm["Number of Tensor Products: ", 85],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616224253877178*^9},ExpressionUUID->"4fd909fa-0001-479b-9bde-\
0e59a5f8b3b7"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"54.0\"\>",
      54.00927000000000077761797001585364341736`7.753068220590177,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    54.00927000000000077761797001585364341736`7.753068220590177, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616224253903105*^9},ExpressionUUID->"302b8e2e-4441-4519-b27c-\
175929fae27f"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SO(10)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["672", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["144",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["144", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["120",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1782",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["120",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14784",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["6930",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17325",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["144",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1200",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7920", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15120", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5940",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6930", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12870",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16380",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["144", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["720", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8064", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15120", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1386",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12870",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14784",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["54",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["770",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1386",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14784",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17920",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8064",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["144", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["672", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1200", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8064", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["11088", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["25200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8064", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["11088", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34992", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1200",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["120",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2970",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1050",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5940",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["144",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1200",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1440",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3696",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8064",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8800",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["38016", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48048", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["144", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["720", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1200", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8064", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["8800", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["11088", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["25200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["38016", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["43680", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["120",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["126", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2970",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox[
               OverscriptBox["3696", "_"],
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4312",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["6930", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34398",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36750",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["46800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48114", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["770",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1050",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["5940",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6930", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8085",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17920",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["23040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["23040", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["72765",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["73710",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1782",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12870",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14784",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12870",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16380",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20592",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48048",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1782",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9438",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37632",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48510",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1782",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4608",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["31680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48510",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["68640",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6162192388311367`*^9, 
  3.616224256386231*^9},ExpressionUUID->"f38cfafe-36cf-415b-80a4-\
194cae4f2550"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO11", ",", 
   RowBox[{"MaxDim", "\[Rule]", "462"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "40000"}]}], "]"}]], "Input",Expressio\
nUUID->"a2f05b34-4f1c-4c81-92bd-888c6e8a832c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616224268791657*^9},ExpressionUUID->"160fbade-e511-4f55-b5b1-\
3dab21aeaa24"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"12.1\"\>",
      12.10058500000000059060312196379527449608`7.103406279970497,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    12.10058500000000059060312196379527449608`7.103406279970497, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162242688383512`*^9},ExpressionUUID->"4ef275ca-3931-4363-b92e-\
117f1dd4ac73"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SO(11)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2717",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7150",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7007",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28798",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1408",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["55",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["165",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["429",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["462",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3003",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4290",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["22275",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23595",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["23595",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["429",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7150",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["429",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7150",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33033",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2025",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["21945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33033",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["55",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["65",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1144",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2025",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["33033",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4224",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["22275",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37752",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616219238853858*^9, 
  3.616224270162588*^9},ExpressionUUID->"16c20894-6449-46e4-9e0f-\
1acf1d5900b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO12", ",", 
   RowBox[{"MaxDim", "\[Rule]", "560"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "100000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7823215209576473`*^9, 3.7823215226401634`*^9}, 
   3.782321615234487*^9, {3.7823218868838873`*^9, 3.7823218871491814`*^9}, 
   3.782322023103853*^9, {3.78232227972147*^9, 3.782322280176259*^9}, 
   3.782322346184007*^9, {3.782322399212721*^9, 3.7823223999048767`*^9}, {
   3.7835439626516156`*^9, 
   3.7835439635083094`*^9}},ExpressionUUID->"c84e3bb5-5241-4ad2-8945-\
1f90b04da381"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "57"}],
   
   SequenceForm["Number of Tensor Products: ", 57],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616224313894742*^9, 3.7823215614547415`*^9, 
  3.7823216501499662`*^9, 3.7823219219627666`*^9, 3.7823220565402713`*^9, 
  3.7823223205113244`*^9, 3.7823223899215107`*^9, 3.782322443320242*^9, 
  3.7835447883545914`*^9},ExpressionUUID->"1c269f81-c5c1-4136-a765-\
9e387eb7748c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"47.6\"\>",
      47.613535,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[47.613535, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616224313894742*^9, 3.7823215614547415`*^9, 
  3.7823216501499662`*^9, 3.7823219219627666`*^9, 3.7823220565402713`*^9, 
  3.7823223205113244`*^9, 3.7823223899215107`*^9, 3.782322443320242*^9, 
  3.7835447883545914`*^9},ExpressionUUID->"50435ee2-257a-4820-91f5-\
aa2c4b93cdb7"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "69", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(12)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2112",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4928", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14014",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["9152", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["352",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4928",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["11088",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["11088",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["352", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4928", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["13728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["43680", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45045",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["66",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2079",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8085",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21450", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["27027", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["220",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["792",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4752", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4928",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36036",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["9152", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["13728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["32032", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["66528", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11011",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23100",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48114",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4928",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4224",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27027",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36036",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54912",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4928",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["41184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["82368",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4928",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14014",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90090",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99099",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28314",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55055",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84942",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4928",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["792",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4752", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36036",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48048",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["352",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["4928",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["82368",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84942",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90090",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8085",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["14014",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21450", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55055",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90090",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["13728", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["11088",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2079",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["57344",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["352", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["2112", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4928", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["9152", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["13728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36960", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["43680", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["66528", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2860",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45045",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48114",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["57344",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["66",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1638",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2079",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2860",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["14014",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23100",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45045",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48114",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["57344",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6162192388769608`*^9, 3.6162243168903503`*^9, 
  3.7823215675005817`*^9, 3.7823216507503376`*^9, 3.782321922087694*^9, 
  3.7823220566629114`*^9, 3.7823223206339684`*^9, 3.782322390048172*^9, 
  3.7823224439734783`*^9, 
  3.783544794404001*^9},ExpressionUUID->"a9aa4356-753c-4405-a70c-\
3edd36e669fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO13", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1716"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "40000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7823226449126997`*^9, 3.7823226453993683`*^9}, 
   3.782322877587384*^9, {3.78232307967127*^9, 3.7823230799575415`*^9}, {
   3.7823233024183216`*^9, 3.7823233042434196`*^9}, {3.7835449629679284`*^9, 
   3.7835449657644215`*^9}},ExpressionUUID->"ede2f952-ddb2-44d9-b668-\
f8c48e657257"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "31"}],
   
   SequenceForm["Number of Tensor Products: ", 31],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616224547898735*^9, 3.7823228595805426`*^9, 
  3.7823230646054134`*^9, 3.7823232858236256`*^9, 3.782323489175948*^9, 
  3.783545024632572*^9},ExpressionUUID->"9eb0e8ad-a5f0-4033-9807-\
8c0583de34e9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"45.4\"\>",
      45.3633905,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[45.3633905, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616224547898735*^9, 3.7823228595805426`*^9, 
  3.7823230646054134`*^9, 3.7823232858236256`*^9, 3.782323489175948*^9, 
  3.783545024637561*^9},ExpressionUUID->"79b245c9-2b3b-4685-9f3d-\
d4239a734eaa"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "70", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(13)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3927",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3927",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13312",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12285",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36036",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3927",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23296",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5733",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16575",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3927",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["715",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12285",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["715",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12285",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23296",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["27456",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36608",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616219238900237*^9, 3.616224550907241*^9, 
  3.7823228616020823`*^9, 3.782323064675226*^9, 3.7823232858854947`*^9, 
  3.7823234892667427`*^9, 
  3.7835450268157396`*^9},ExpressionUUID->"f3a3d216-19eb-458c-8000-\
7b12e170f3c8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO14", ",", 
   RowBox[{"MaxDim", "\[Rule]", "104"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "8000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835450592473755`*^9, 
  3.7835450619428673`*^9}},ExpressionUUID->"92bc05d4-6ff7-4ea5-bd59-\
e145e1c9ac7c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "11"}],
   
   SequenceForm["Number of Tensor Products: ", 11],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6162246055155487`*^9, 
  3.7835450767042093`*^9},ExpressionUUID->"669cb79c-d4bf-49ee-8f8a-\
2dc297d3c24b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"2.4\"\>",
      2.4193684,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[2.4193684, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6162246055155487`*^9, 
  3.7835450767072334`*^9},ExpressionUUID->"48088893-d67c-443e-a292-\
72cbf00866f5"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "71", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(14)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["64", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["832", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["64", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["832",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["546",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["832",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5265",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5265",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616219238926488*^9, 3.616224611284068*^9, 
  3.7835450801962223`*^9},ExpressionUUID->"7bbdc2a1-7d50-464e-9aa6-\
371470b188e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO15", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1105"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "8000"}]}], "]"}]], "Input",Expression\
UUID->"59057413-748a-4c01-bae6-bdf411d4618b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "11"}],
   
   SequenceForm["Number of Tensor Products: ", 11],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767154540973206`*^9},ExpressionUUID->"b223fad6-be58-4c7b-bdfb-\
aa527d3a037b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"27.0\"\>",
      27.0125491,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[27.0125491, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767154541129093`*^9},ExpressionUUID->"d19ff8c1-3019-4c1a-8eeb-\
d920fd5171ce"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "27", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(15)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["455",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["665",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6916",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6916",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1792",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["455",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6435",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["455",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["665",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6916",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6916",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7767154588676443`*^9},ExpressionUUID->"22daf28a-64e4-48b8-acdd-\
45e051c352ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO16", ",", 
   RowBox[{"MaxDim", "\[Rule]", "560"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "50000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835451686819725`*^9, 
  3.7835451766390696`*^9}},ExpressionUUID->"45ad9805-9904-41a8-9ab6-\
e81b6beb4350"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "14"}],
   
   SequenceForm["Number of Tensor Products: ", 14],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776715688987219*^9, 
  3.783545191701851*^9},ExpressionUUID->"ddd034cf-9323-45ce-a6d3-\
6860093faeca"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"12.0\"\>",
      12.035052,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[12.035052, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776715688987219*^9, 
  3.7835451917048492`*^9},ExpressionUUID->"2b6da083-ebed-4998-b394-\
5551a6c853a3"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "72", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(16)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5304",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7020",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["128", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1920", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13312",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6435", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["128", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7020",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15360",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3740",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5304",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7020",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["135",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["49504",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767156892574973`*^9, 
  3.783545220819136*^9},ExpressionUUID->"2975874e-5c49-454d-851a-\
2b6d0f575eef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO17", ",", 
   RowBox[{"MaxDim", "\[Rule]", "680"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "51000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835452396551104`*^9, 
  3.7835452409980774`*^9}},ExpressionUUID->"676ce662-c7bb-4613-b5bf-\
240e4ffa6f32"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "12"}],
   
   SequenceForm["Number of Tensor Products: ", 12],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767157236416163`*^9, 
  3.7835452516014743`*^9},ExpressionUUID->"a53065e9-3c7f-437a-bd3c-\
0ff001138155"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"6.2\"\>",
      6.2260281,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[6.2260281, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767157236416163`*^9, 
  3.783545251609459*^9},ExpressionUUID->"4e8c5399-7939-47b8-b320-\
09894e86141f"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "73", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(17)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1615",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6783",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["952",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1615",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11340",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4692",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6783",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11340",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30464",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34816",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6188",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24310",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["680",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["680",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1615",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6188",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33592",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50388",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.776715729377633*^9, 
  3.78354529065331*^9},ExpressionUUID->"acbd7e8e-29ad-47a5-9684-f41109eda627"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO18", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1122"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "500000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783545333682583*^9, 3.7835453495034385`*^9}, {
   3.7837034320049653`*^9, 3.7837034337233715`*^9}, {3.7839622768627477`*^9, 
   3.783962279713259*^9}, {3.783962842846562*^9, 3.783962843400053*^9}, 
   3.7839689337032824`*^9},ExpressionUUID->"c5551688-ac18-4b66-a850-\
ebf850d1f0bd"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "20"}],
   
   SequenceForm["Number of Tensor Products: ", 20],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6162271459361067`*^9, 3.783545450888566*^9, 
  3.7837037121660876`*^9, 3.7839628320463853`*^9, 3.783963363202391*^9, 
  3.7840033787721086`*^9},ExpressionUUID->"02f0c2bd-f46b-439f-97f7-\
58c9bbdb1661"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"414.0\"\>",
      413.7325699,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[413.7325699, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.6162271459361067`*^9, 3.783545450888566*^9, 
  3.7837037121660876`*^9, 3.7839628320463853`*^9, 3.783963363202391*^9, 
  3.784003379610752*^9},ExpressionUUID->"f8ee3e34-cab0-4e1d-8327-\
e956efe0ac0e"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "264", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(18)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3060",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11475",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11475",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14212",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5814",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14212",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4352", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["39168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8568",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24310", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3060",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18564",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43758",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3060",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11475",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8568",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["67830",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90288",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["169728", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3060",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11475",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18564",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["188955",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["302328",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5814",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14212",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90288",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25194",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84150",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["39168", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["248064", "_"],
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6162192389298983`*^9, 3.616225113216341*^9, 
  3.6162266658999157`*^9, 3.616227146884817*^9, 3.783545623137415*^9, 
  3.783719988129778*^9, 3.783962832118193*^9, 3.7839689264517965`*^9, 
  3.7840033806430955`*^9},ExpressionUUID->"5228b17f-eaa3-4623-aa62-\
b935b7298575"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO19", ",", 
   RowBox[{"MaxDim", "\[Rule]", "969"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "938961"}]}], "]"}]], "Input",Expressi\
onUUID->"9242ff4c-341a-4a09-93a4-e556d5f324a9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "15"}],
   
   SequenceForm["Number of Tensor Products: ", 15],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776715761161767*^9},ExpressionUUID->"c93397f5-ccab-4130-a636-\
aec9e1577301"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"17.2\"\>",
      17.1717473,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[17.1717473, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776715761161767*^9},ExpressionUUID->"0d00a32c-d1f0-4bac-9ec9-\
18713d47b95f"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "30", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(19)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2261",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1311",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2261",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17595",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17595",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9216",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["87552",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11628",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50388",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75582",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["92378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2261",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11628",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["61047",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["89775",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2261",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["61047",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["118864",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["408576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["969",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["265335",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["427329",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7767160123204856`*^9},ExpressionUUID->"55cac42a-8217-4fb6-9da0-\
3d01d9625701"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO20", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1140"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1000000"}]}], "]"}]], "Input",Express\
ionUUID->"c94dac0d-c199-4642-9e3d-2cace2d0ef9f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "16"}],
   
   SequenceForm["Number of Tensor Products: ", 16],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767161181905985`*^9},ExpressionUUID->"a1924bfe-cc8d-4bb3-b6e5-\
67ba8fb58b2c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"69.6\"\>",
      69.6392738,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[69.6392738, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767161181905985`*^9},ExpressionUUID->"b408b3bc-69d8-43f5-a368-\
b0a00a98b08b"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "31", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(20)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4845",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13090",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17765",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17765",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21546",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13090",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21546",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["512", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["9728", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["87040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["97280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["512", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["167960",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4845",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["38760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["92378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125970",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4845",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17765",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["117040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["512", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["9728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["87040", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["486400", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["190",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["209",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4845",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13090",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17765",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["38760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["266475",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["365750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["592515",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.776717421668425*^9},ExpressionUUID->"f8a7b61b-cde9-4c79-b501-\
086338b3bdee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO21", ",", 
   RowBox[{"MaxDim", "\[Rule]", "5985"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "2000000"}]}], "]"}]], "Input",Express\
ionUUID->"2448ed5f-cbcd-45a3-a30e-bac6f7b93dc7"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "23"}],
   
   SequenceForm["Number of Tensor Products: ", 23],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767178059262304`*^9},ExpressionUUID->"63dcbe97-752b-4252-9f30-\
85e823255721"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"167.0\"\>",
      167.2602203,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[167.2602203, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767178059750686`*^9},ExpressionUUID->"ab6f951e-8a3a-4da7-b087-\
5ac0e4e0e6b2"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "32", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(21)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15939",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10395",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15939",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["193536",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["215040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20349",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54264",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["116280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["203490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["293930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352716",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20349",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150535",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["197505",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["193536",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1146880",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15939",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54264",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["367080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495880",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["807576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15939",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3059",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["104006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150535",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["181125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["197505",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3059",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["150535",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165186",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["181125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["197505",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15939",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21735",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["26125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["367080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["807576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["981750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1820105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3059",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["230",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10395",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15939",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["21735",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["26125",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["495880",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["655500",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["807576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["981750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1285956",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1297890",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1820105",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20349",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104006",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54264",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["367080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["807576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["367080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["981750",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7767195576487675`*^9},ExpressionUUID->"c5470ec1-833c-40fd-9cc3-\
ca2c2b6d63e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO22", ",", 
   RowBox[{"MaxDim", "\[Rule]", "7315"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "646646"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.7746142028205256`*^9, {3.7835457143969684`*^9, 
   3.783545718795679*^9}},ExpressionUUID->"e63cfbf1-fd64-43c5-a7ab-\
a11fda8cb941"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "12"}],
   
   SequenceForm["Number of Tensor Products: ", 12],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616227360175891*^9, 3.616227545343337*^9, 
  3.7835457691493006`*^9},ExpressionUUID->"953ff989-ee3d-4eab-84ba-\
013d0f100e12"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"23.8\"\>",
      23.7735667,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[23.7735667, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616227360175891*^9, 3.616227545343337*^9, 
  3.7835457691648855`*^9},ExpressionUUID->"f8817cae-fb0e-4b6e-8298-\
6ca61859aac6"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "75", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(22)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19228",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26334",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1024", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["214016",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1024", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["74613",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["319770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["646646",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["26334",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["170544",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["497420",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26334",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["26334",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["191268",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19228",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26334",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31395",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3520",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["133056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["191268",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["228228",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["249964",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7315",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["26334",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133056",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616219238953658*^9, 3.6162252277561293`*^9, 
  3.616226286963456*^9, 3.616227400653014*^9, 3.616228304203558*^9, 
  3.7835464250827246`*^9},ExpressionUUID->"084e1b41-0742-4558-aea5-\
3eee790cc7f0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO23", ",", 
   RowBox[{"MaxDim", "\[Rule]", "100947"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1000000"}]}], "]"}]], "Input",Express\
ionUUID->"f6b4181a-c588-41c9-ba2e-f9763fa182f0"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "13"}],
   
   SequenceForm["Number of Tensor Products: ", 13],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767207474223003`*^9},ExpressionUUID->"fb482fc1-1003-4924-a6a9-\
f58c2000031c"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"647.0\"\>",
      646.5419545,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[646.5419545, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767207477031775`*^9},ExpressionUUID->"3130a8c4-2588-4657-a026-\
b5769a1e9531"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "33", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(23)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1771",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8855",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31625",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1771",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8855",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31625",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1771",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1771",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33649",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168245",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["240350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2048",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2048",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45056",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2048",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2048",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["471040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4025",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31625",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37422",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4025",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1771",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2277",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4025",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["168245",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["240350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["284625",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["312984",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8855",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1771",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33649",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168245",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["31625",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1771",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168245",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["240350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["312984",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["33649",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8855",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["100947",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["664125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45056",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["23",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2048",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["471040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["518144",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.776721638418189*^9},ExpressionUUID->"c79f2017-0cfa-46f4-ad48-\
e9d99ab0b0b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO24", ",", 
   RowBox[{"MaxDim", "\[Rule]", "134596"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1000000"}]}], "]"}]], "Input",Express\
ionUUID->"6e45c10e-0fd0-4614-aa5a-2e66f2e8e8b3"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "13"}],
   
   SequenceForm["Number of Tensor Products: ", 13],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776722431647123*^9},ExpressionUUID->"37e4cdbd-cfe7-437c-b7fd-\
53f81a4647b0"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"730.0\"\>",
      729.8215121,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[729.8215121, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7767224316501*^9},ExpressionUUID->"95c82327-1f51-4fef-b3a7-8b6a796bd5d1"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "34", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(24)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["299",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["299",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10626",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37674",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10626",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37674",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2024",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["299000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2048",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2048", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["47104", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2048",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2048",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["47104",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["516096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["299",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37674",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44275",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["276",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4576",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["299000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351624",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["388080",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10626",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210496",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["37674",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["299000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["388080",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42504",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10626",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["134596",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["874874",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["47104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2048", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["47104", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["516096", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["565248", "_"],
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.776726378827416*^9},ExpressionUUID->"fab02d63-c52e-4d8b-a532-\
a909269de8f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO25", ",", 
   RowBox[{"MaxDim", "\[Rule]", "2300"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "690000"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.774614230209036*^9, {3.776727114958946*^9, 
   3.7767271434229455`*^9}},ExpressionUUID->"81ffc95b-57e4-4043-a216-\
2fce92aaccd9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776732484789028*^9},ExpressionUUID->"bcffac61-e058-4ae6-8885-\
e1af16d8a827"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"12.2\"\>",
      12.2238823,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[12.2238823, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776732484880808*^9},ExpressionUUID->"0c927fa2-ceeb-426e-918f-\
f8bd3a4330ad"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "35", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(25)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["25",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["25",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["25",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["25",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["32175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2300",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["25",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2300",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["25",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["53130",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["260820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["368550",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.776732448913681*^9, 
  3.776732486749782*^9},ExpressionUUID->"d4503551-6879-4a36-8308-\
93537d6b45c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO26", ",", 
   RowBox[{"MaxDim", "\[Rule]", "657800"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1000000"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.774614243636736*^9},ExpressionUUID->"6d790813-b4af-4278-adc8-\
41650a4d16bf"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616228334170198*^9, 3.6162301510940123`*^9, 
  3.6162303655655947`*^9},ExpressionUUID->"ceb2a6b0-8ac9-4edb-b3ff-\
c885664a4820"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"4.2\"\>",
      4.19048300000000040199665818363428115845`6.642863996423833,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[
    4.19048300000000040199665818363428115845`6.642863996423833, {3, 1}], "s"],
   
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616228334170198*^9, 3.6162301510940123`*^9, 
  3.616230365583729*^9},ExpressionUUID->"fec21fcd-d7b5-4d37-b00e-\
48262e14774a"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, 
          "RowDefault"], StripOnInput -> False, FontWeight -> Bold],
        TemplateBox[{
          FormBox["\"SO(26)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37674",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52325",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52325",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450450",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.6162303526137257`*^9, 
  3.6162307562936993`*^9},ExpressionUUID->"1820677d-2e60-4c29-a857-\
16ac33af900b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO27", ",", 
   RowBox[{"MaxDim", "\[Rule]", "2925"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1026675"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.77461435801268*^9, 3.7746143654227667`*^9}, {
  3.774614458549138*^9, 
  3.7746144766427307`*^9}},ExpressionUUID->"75f98951-1bec-4bd5-89f1-\
cba9c11768d9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776732534127638*^9},ExpressionUUID->"25a42df3-3871-4d30-9799-\
cf22caf06982"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"12.3\"\>",
      12.2959194,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[12.2959194, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776732534127638*^9},ExpressionUUID->"a8785466-bf40-4356-a787-\
557a7bd550a2"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "36", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(27)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["377",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6525",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["377",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["61074",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["61074",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80730",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["390195",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["546273",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.776732534447447*^9},ExpressionUUID->"6d4233d1-2bf6-415c-a259-\
dde5bbe23cc9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO28", ",", 
   RowBox[{"MaxDim", "\[Rule]", "3276"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1238328"}]}], "]"}]], "Input",Express\
ionUUID->"c195bbb4-c7e6-43bd-836f-6f1948924d09"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776732551162197*^9},ExpressionUUID->"b6766fa4-69ef-4c90-8304-\
feebc20d2f71"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"12.5\"\>",
      12.4631903,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[12.4631903, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.776732551162197*^9},ExpressionUUID->"5f985b7e-1525-4d34-a80a-\
0cc798935305"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "37", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(28)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3276",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20475",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70875",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3276",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20475",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70875",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3276",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3276",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["98280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["471744",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["657720",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7767325515423923`*^9},ExpressionUUID->"107c34cd-6abe-48ef-8c46-\
d46ac47788d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO29", ",", 
   RowBox[{"MaxDim", "\[Rule]", "3654"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1238328"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7746144841825404`*^9, 3.7746145095681305`*^9}, 
   3.774614548184679*^9},ExpressionUUID->"6bc89afa-0c4c-4955-996e-\
4410a5077310"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767325913099265`*^9, 
  3.7767342848264785`*^9},ExpressionUUID->"c649f900-daac-44c8-bb09-\
7b5f8626f5d4"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"11.9\"\>",
      11.8762447,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[11.8762447, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7767325913099265`*^9, 
  3.776734284830467*^9},ExpressionUUID->"56911eaf-66fd-4864-8a95-\
a20cc0df3f42"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "39", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(29)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["29",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["29",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["434",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["29",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["29",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3654",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8091",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["434",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["58435",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81809",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3654",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["29",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81809",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3654",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["29",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3654",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8091",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["118755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["566370",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["786625",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7767342193738747`*^9, 
  3.7767363840475917`*^9},ExpressionUUID->"8f0322b4-f5ec-47b7-8408-\
05bba2b372a6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO30", ",", 
   RowBox[{"MaxDim", "\[Rule]", "4060"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1238328"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835306245679693`*^9, 3.783530624802327*^9}, {
  3.7835306720712347`*^9, 3.78353067284813*^9}, {3.7835307226091*^9, 
  3.783530723668295*^9}, {3.7837215612124825`*^9, 
  3.783721561645258*^9}},ExpressionUUID->"9b6b7ab9-1ee2-4b66-aef5-\
0e6dbab5f7f7"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7835466022386913`*^9, 3.7837212423945074`*^9, 
  3.7837216029578776`*^9},ExpressionUUID->"11649daa-daa6-447b-95e3-\
ab3c78a7ba63"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"23.1\"\>",
      23.1181724,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[23.1181724, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7835466022386913`*^9, 3.7837212423945074`*^9, 
  3.7837216032291136`*^9},ExpressionUUID->"75e21ead-eaff-4a9c-8092-\
9e8748f1e525"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "110", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(30)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["435",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["464",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["435",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4060",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8960",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["435",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["435",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["435",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["464",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66960",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["93960",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4060",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["435",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["93960",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4060",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["435",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4060",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8960",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["142506",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["675584",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["934960",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.783721569501099*^9, 
  3.783735385038963*^9},ExpressionUUID->"9eee4ff7-8054-4f60-9560-\
447510e4318b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Algebra", "[", "B", "]"}], "[", "15", "]"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "4495"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1238328"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7835306890597906`*^9, 3.7835307305229893`*^9}, {
  3.783545603661854*^9, 3.7835456290163107`*^9}, {3.7837215852826543`*^9, 
  3.783721587259736*^9}},ExpressionUUID->"5e9f7f6d-5094-447c-869c-\
816254ff57cc"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783900021740613*^9},ExpressionUUID->"537d5310-f97d-4f70-96ce-\
72a40b177ae5"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"43.4\"\>",
      43.4118305,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[43.4118305, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783900021756242*^9},ExpressionUUID->"3ab08816-db6d-4276-b214-\
b1a753b8d4d0"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "180", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"SO(31)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["31",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["31",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["31",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["31",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9889",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31465",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["107415",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["31",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31465",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["107415",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["31",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9889",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["169911",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["801009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1104840",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7839054017252746`*^9},ExpressionUUID->"cd3a2807-c2dd-490f-8553-\
dcfc8eca9e23"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DecomposeProduct", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", 
     RowBox[{
      RowBox[{"Algebra", "[", "D", "]"}], "[", "16", "]"}], "]"}], "[", "32", 
    "]"}], ",", 
   RowBox[{
    RowBox[{"Irrep", "[", 
     RowBox[{
      RowBox[{"Algebra", "[", "D", "]"}], "[", "16", "]"}], "]"}], "[", "32", 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.761063561175576*^9, 3.7610636132379103`*^9}, {
  3.7926824594908724`*^9, 
  3.792682462460075*^9}},ExpressionUUID->"22ad743d-9e50-4883-b849-\
4ba78c892bd7"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    StyleBox["1",
     FontWeight->Bold],
    TraditionalForm], "+", 
   FormBox[
    StyleBox["496",
     FontWeight->Bold],
    TraditionalForm], "+", 
   FormBox[
    StyleBox["527",
     FontWeight->Bold],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.792682446901945*^9, 
  3.792697861233492*^9},ExpressionUUID->"2c10be6e-1004-4319-ae15-\
dc520076ecca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DecomposeProduct", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", 
     RowBox[{
      RowBox[{"Algebra", "[", "D", "]"}], "[", "16", "]"}], "]"}], "[", "496",
     "]"}], ",", 
   RowBox[{
    RowBox[{"Irrep", "[", 
     RowBox[{
      RowBox[{"Algebra", "[", "D", "]"}], "[", "16", "]"}], "]"}], "[", "32", 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7927018132504854`*^9, 
  3.792701827502215*^9}},ExpressionUUID->"612beb4f-1afa-4de6-bfb2-\
a5f88b00a581"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    StyleBox["32",
     FontWeight->Bold],
    TraditionalForm], "+", 
   FormBox[
    StyleBox["4960",
     FontWeight->Bold],
    TraditionalForm], "+", 
   FormBox[
    StyleBox["10880",
     FontWeight->Bold],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7927052033110647`*^9},ExpressionUUID->"c69be5cc-1563-4448-803c-\
5c8dc8c88510"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sp(N)", "Section",ExpressionUUID->"23407dd1-953a-419c-952b-0e9b7142e493"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp4", ",", 
   RowBox[{"MaxDim", "\[Rule]", "35"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1800"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7823239302298293`*^9, 3.7823239527699833`*^9}, {
  3.783603587790374*^9, 
  3.783603588157921*^9}},ExpressionUUID->"9c5c7e4a-f76e-4e59-85d8-\
ff554f277703"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226294513503*^9, {3.78232393251071*^9, 3.7823239544195843`*^9}, 
   3.7836035955168514`*^9},ExpressionUUID->"4ca7d217-896f-42e4-bbb3-\
9faf52ce109b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"3.2\"\>",
      3.1587078,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[3.1587078, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226294513503*^9, {3.78232393251071*^9, 3.7823239544195843`*^9}, 
   3.7836035955168514`*^9},ExpressionUUID->"4c4afb14-e17e-4f57-8d9c-\
160dd97f295b"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(4)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["260",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["20",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["81",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["260",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["390",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["14",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["35",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["81",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["81",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6162192390011*^9, 3.616226294658813*^9, {3.78232393262843*^9, 
   3.7823239545382338`*^9}, 
   3.783603595719904*^9},ExpressionUUID->"010ccd07-dfd2-48f2-b846-\
329662fd1881"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp6", ",", 
   RowBox[{"MaxDim", "\[Rule]", "90"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "16000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.782324024745905*^9, 3.7823240325680437`*^9}, {
  3.7823241754779773`*^9, 3.782324176590034*^9}, {3.7823242083324537`*^9, 
  3.7823242086795025`*^9}, {3.78354423387438*^9, 
  3.783544235049363*^9}},ExpressionUUID->"4dbb660e-7225-4ffe-bbad-\
b1274c0d9b3b"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162262964113092`*^9, {3.7823240262339306`*^9, 3.782324034117905*^9}, 
   3.7823242106322947`*^9, 
   3.7836036190363064`*^9},ExpressionUUID->"477d1e2d-aaa0-4436-801c-\
fe75fbcc8132"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.9\"\>",
      0.8537893,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.8537893, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162262964113092`*^9, {3.7823240262339306`*^9, 3.782324034117905*^9}, 
   3.7823242106322947`*^9, 
   3.7836036190363064`*^9},ExpressionUUID->"5f130c4c-79dc-4fff-8e5c-\
edcdad62f46b"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(6)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["924",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["924",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["14",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["90",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["216",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1100",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["216",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["90",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2464",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1386",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2016",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["216",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["90",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.61621923902485*^9, 3.616226296565468*^9, {3.7823240263396764`*^9, 
   3.7823240342306037`*^9}, 3.782324210775931*^9, 
   3.783603619119094*^9},ExpressionUUID->"8d37c469-dc30-4095-b60e-\
7357f077f8d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp8", ",", 
   RowBox[{"MaxDim", "\[Rule]", "308"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "29000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.780163473640563*^9, 3.780163481144211*^9}, {
  3.7823242409814644`*^9, 3.7823242422819996`*^9}, {3.783603629855006*^9, 
  3.7836036305014353`*^9}, {3.783603663120879*^9, 
  3.7836036647177086`*^9}},ExpressionUUID->"cd6af121-8253-4417-babf-\
095a4ac5eb55"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "43"}],
   
   SequenceForm["Number of Tensor Products: ", 43],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616226299680443*^9, 3.78016348859523*^9, 
  3.782324249241397*^9, 3.783603633072039*^9, 
  3.7836036666288424`*^9},ExpressionUUID->"375c51a3-6384-493b-bfc9-\
04ab8bf275b5"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1.4\"\>",
      1.3916469,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1.3916469, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616226299680443*^9, 3.78016348859523*^9, 
  3.782324249241397*^9, 3.783603633072039*^9, 
  3.783603666644438*^9},ExpressionUUID->"674d616f-8cab-46a5-b534-\
e5ad0f2076cd"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(8)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["594",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1056",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["315",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["308",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["315",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["288",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["594",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6237",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1155",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["315",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["792",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1155",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6237",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7020",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["308",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["594",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["825",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["6237",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10010",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["13728",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16848",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7020",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6552",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12936",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["792",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1232",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6552",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13728",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616219239049893*^9, 3.616226300017581*^9, 
  3.7801634887341394`*^9, 3.7823242497610087`*^9, 3.7836036332750874`*^9, 
  3.783603666722581*^9},ExpressionUUID->"68629fac-513f-440f-bc0e-\
dcd78b08f12d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp10", ",", 
   RowBox[{"MaxDim", "\[Rule]", "780"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "100000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.780163578888698*^9, 3.780163596456333*^9}, {
  3.783603686032982*^9, 
  3.783603686611015*^9}},ExpressionUUID->"9441210d-7e4e-4338-bd03-\
59b54dec59d2"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "52"}],
   
   SequenceForm["Number of Tensor Products: ", 52],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616226304538096*^9, 3.780163588044776*^9, 
  3.780163620946418*^9, 
  3.783603702632905*^9},ExpressionUUID->"f7da22ac-3481-4165-b406-\
fdfd4b31d3a8"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"14.6\"\>",
      14.635994,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[14.635994, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.616226304538096*^9, 3.780163588044776*^9, 
  3.780163620946418*^9, 
  3.7836037026485004`*^9},ExpressionUUID->"884db197-3a62-4783-a942-\
95574856706a"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(10)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8580",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4719",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9152",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9438",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8580",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15015",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24960",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["5005",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17820",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["891",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1408",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["32340",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15015",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["44",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["55",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["780",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["891",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15015",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17920",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15015",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["5005",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17820",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24960",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24960",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63700",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15015",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75075",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54912",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4928",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["36608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["71500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["32340",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35640",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["32340",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["67760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28028",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["71500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2860",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4212",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4620",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28028",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["32340",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["71500",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.616219239079124*^9, 3.616226305782612*^9, 
  3.7801635881225786`*^9, 3.780163621082071*^9, 
  3.7836037039609423`*^9},ExpressionUUID->"c79d2fee-b29d-4b36-bfc4-\
fa30f2ab7b50"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp12", ",", 
   RowBox[{"MaxDim", "\[Rule]", "429"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "100000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783673160975658*^9, 
  3.7836731997979565`*^9}},ExpressionUUID->"7c0d839c-3787-45b2-b693-\
95c637d136d0"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "26"}],
   
   SequenceForm["Number of Tensor Products: ", 26],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226316778021*^9, {3.7836731703007283`*^9, 
   3.7836732077985697`*^9}},ExpressionUUID->"978317a7-dea9-4e09-ae09-\
32de7d545686"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"6.2\"\>",
      6.234487,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[6.234487, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226316778021*^9, {3.7836731703007283`*^9, 
   3.7836732078015623`*^9}},ExpressionUUID->"12c6141a-45ad-47b4-a8e6-\
14606e5e8fd9"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "27", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(12)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18954",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11648",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4368",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11648",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24310",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["38675",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51051",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18954",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27027",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["57200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43680",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40898",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["49686",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78078",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18954",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["92950",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18954",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["49686",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.61621923910837*^9, 3.616226320426228*^9, {3.7836731727501793`*^9, 
   3.7836732078624*^9}},ExpressionUUID->"17df4b74-b9c0-4db6-adae-\
0319e89f4218"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp14", ",", 
   RowBox[{"MaxDim", "\[Rule]", "896"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "30000"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.7836733043692265`*^9, {3.7836733457676725`*^9, 
   3.783673364634956*^9}},ExpressionUUID->"3e625eb4-bf46-4b59-92dc-\
e5b7d67d9b3f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "15"}],
   
   SequenceForm["Number of Tensor Products: ", 15],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61622635336782*^9, 3.7836733312572727`*^9, {3.7836733632635946`*^9, 
   3.78367338065211*^9}},ExpressionUUID->"d38e4574-eb01-4de9-8484-\
a9a26d693f32"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"13.7\"\>",
      13.6814888,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[13.6814888, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61622635336782*^9, 3.7836733312572727`*^9, {3.7836733632635946`*^9, 
   3.783673380655102*^9}},ExpressionUUID->"30e7cbe3-1d49-4e4b-a0a4-\
c268ef1a3524"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "31", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(14)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3094",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3094",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17850",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8568",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24570",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3094",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17850",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24570",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["17850",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24570",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24752",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6162192391326017`*^9, 3.616226359557969*^9, {3.783673335747401*^9, 
   3.783673363295518*^9}, 
   3.783673399775136*^9},ExpressionUUID->"57e67673-1e15-4b84-ba43-\
676cdcb1c76f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp16", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1344"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "400000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774614569063923*^9, 3.774614604915892*^9}, {
   3.782324706074567*^9, 3.7823247074708223`*^9}, 3.7823249578132715`*^9, 
   3.7823250436955357`*^9},ExpressionUUID->"8927ce9d-c34e-4489-9383-\
e960e2677230"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "21"}],
   
   SequenceForm["Number of Tensor Products: ", 21],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776736557909151*^9, 3.782324765870507*^9, 
  3.782325030690134*^9, 
  3.782325099587267*^9},ExpressionUUID->"12e3580a-5617-48e8-927f-\
f6ee0358e860"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"54.9\"\>",
      54.9370072,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[54.9370072, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.776736557909151*^9, 3.782324765870507*^9, 
  3.782325030690134*^9, 
  3.7823250995902824`*^9},ExpressionUUID->"b30cfed1-a450-4d7e-9115-\
e57eb6e90fcf"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "83", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(16)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6885",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6885",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6885",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3808",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["22848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36176",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["22848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["49248",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6188",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6885",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["53040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["88179",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["134368",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["49248",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["47600",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6885",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["169575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["258400",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54264",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["269892",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6885",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1344",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["22848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36176",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["47600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["49248",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1344",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["36176",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["47600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["49248",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["544",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["6885",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["9044",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["53040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["134368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["169575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["344064",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6885",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["9044",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["258400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["269892",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["344064",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["119",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["136",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3876",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["6885",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["9044",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["88179",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["134368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["169575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["258400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["269892",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["344064",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.77673655808867*^9, 3.7823249397306037`*^9, 
  3.782325030786293*^9, 
  3.782325677726986*^9},ExpressionUUID->"92a50cce-48a9-4cc0-a74f-\
92455454ee32"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp18", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1920"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "500000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783530752242884*^9, 3.7835307713688016`*^9}, {
  3.7836039143489666`*^9, 
  3.7836039345700417`*^9}},ExpressionUUID->"f6b96560-3667-4a63-afce-\
7771148f6012"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "16"}],
   
   SequenceForm["Number of Tensor Products: ", 16],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7836041992510977`*^9},ExpressionUUID->"765e647f-86a6-4c7e-a7a4-\
efc7e611aea9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"250.0\"\>",
      250.2031665,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[250.2031665, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7836041992550817`*^9},ExpressionUUID->"4b341571-c28b-489e-b159-\
177dd57a41af"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "8", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(18)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2907",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8568",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11305",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8568",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2907",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11305",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["67032",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["89964",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2907",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8568",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["121125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["186200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["290871",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5985",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["89964",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26334",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85272",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8568",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["152",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1920",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["43776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["67032",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85272",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["89964",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["171",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1920",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["67032",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85272",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["89964",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7836055010584717`*^9},ExpressionUUID->"825896e4-42f3-4cba-b76c-\
fee477483c33"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp20", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1120"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "500000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783605966755293*^9, 
  3.783605975711585*^9}},ExpressionUUID->"9573d445-11aa-47c4-b17d-\
59426f3717bf"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "9"}],
   SequenceForm["Number of Tensor Products: ", 9],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7836060103167524`*^9},ExpressionUUID->"a38e831a-2a55-40c9-b8e9-\
9912a40c6112"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"28.3\"\>",
      28.2931303,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[28.2931303, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7836060103197455`*^9},ExpressionUUID->"55186422-f2f3-4b4e-8d8a-\
b20ef38de45b"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "10", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(20)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4655",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17556",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17556",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8855",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21735",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4655",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17556",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["115920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["153824",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.783607625684206*^9},ExpressionUUID->"97873967-d895-4cbc-9c0d-\
54cd6c866df8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp22", ",", 
   RowBox[{"MaxDim", "\[Rule]", "7000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "500000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783606845445091*^9, 3.7836068549692965`*^9}, {
  3.783614395424547*^9, 3.7836144054577847`*^9}, {3.7836150008210907`*^9, 
  3.7836150021773586`*^9}},ExpressionUUID->"574b44d4-e184-4a5e-abf1-\
45c53f426b95"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of Tensor Products: ", 7],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7836079298646927`*^9, 
  3.7836150125765486`*^9},ExpressionUUID->"58501b5f-f5b3-45e9-af85-\
cf2e34346a97"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"5.6\"\>",
      5.6160242,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[5.6160242, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7836079298646927`*^9, 
  3.7836150125795407`*^9},ExpressionUUID->"4b77dfca-f3ed-4dd0-a72f-\
a24bdd99272e"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(22)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1518",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7084",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26082",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1518",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7084",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26082",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1518",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1518",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24794",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["129536",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26082",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31625",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["230",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1518",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3520",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["129536",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["230230",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["249480",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{3.7836143407391644`*^9, 
  3.783615784707275*^9},ExpressionUUID->"c4c087c3-426e-4167-8f32-\
b1c7af3f2bbc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp24", ",", 
   RowBox[{"MaxDim", "\[Rule]", "7000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "700000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7836068629547024`*^9, 3.783606866707303*^9}, {
  3.7836160409963665`*^9, 
  3.7836160530247164`*^9}},ExpressionUUID->"9af409ce-2a0b-446d-bb4b-\
cc2e076db06f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of Tensor Products: ", 7],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7836160634186783`*^9},ExpressionUUID->"82a719cb-c65f-43e1-bd4b-\
3696d4570206"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"9.2\"\>",
      9.2468799,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[9.2468799, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783616063434276*^9},ExpressionUUID->"bfb96305-9564-48db-9455-\
b41eb683669b"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(24)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37375",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2000",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37375",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2000",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["297000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37375",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4576",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["205920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["297000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["354200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["387504",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7836199650128345`*^9},ExpressionUUID->"54688d75-cf37-4bcf-ba0b-\
62d7d5d72027"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp26", ",", 
   RowBox[{"MaxDim", "\[Rule]", "2574"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "500000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7836068715113287`*^9, 3.783606877005007*^9}, 
   3.783621831286408*^9},ExpressionUUID->"3b2e0dd9-10fc-42ff-bfef-\
889dabb89147"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783621850976639*^9},ExpressionUUID->"932d5b8c-d9b7-48f6-ad91-\
eb68e76c1d4a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"11.4\"\>",
      11.4129104,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[11.4129104, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7836218509786325`*^9},ExpressionUUID->"b00be5d1-a4fa-463c-bc12-\
cc7f3a259fa5"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(26)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14625",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51975",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14625",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51975",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63180",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["314496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["447876",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7836223031287465`*^9},ExpressionUUID->"b030472b-b7bd-4c3c-aa23-\
552156eab8c0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp28", ",", 
   RowBox[{"MaxDim", "\[Rule]", "3248"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "500000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7836068833423014`*^9, 3.7836068937543287`*^9}, {
  3.783622669845171*^9, 
  3.7836226756756964`*^9}},ExpressionUUID->"494f481a-cd28-448d-be87-\
9842b8761819"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "4"}],
   SequenceForm["Number of Tensor Products: ", 4],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.783622693908308*^9},ExpressionUUID->"6f1d58c2-d4ad-4904-96da-\
5aee5d6b2373"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"16.8\"\>",
      16.8355085,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[16.8355085, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.7836226939113*^9},ExpressionUUID->"68fd0ceb-9e43-447a-894d-9e0987e9423a"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "8", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(28)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["377",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["377",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["377",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["377",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["377",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20097",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50778",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70470",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3248",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["377",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20097",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70470",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7836243532596416`*^9},ExpressionUUID->"baf05d7b-1e34-42ff-8a00-\
1291a8000a87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp30", ",", 
   RowBox[{"MaxDim", "\[Rule]", "434"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "188356"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7836069008250666`*^9, 3.7836069064758368`*^9}, {
   3.7836226824906445`*^9, 3.7836226831967363`*^9}, 3.78362444253325*^9, {
   3.7836262482144575`*^9, 3.7836262663061237`*^9}, {3.7836345288528285`*^9, 
   3.7836345570433636`*^9}, {3.783634688480343*^9, 
   3.7836346898047943`*^9}},ExpressionUUID->"c01ff666-4284-4895-be76-\
78a369eb56b6"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "3"}],
   SequenceForm["Number of Tensor Products: ", 3],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7836346598944397`*^9, 
  3.783634705354196*^9},ExpressionUUID->"9899455c-144e-41d6-8ea8-\
b4e485653f6f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"14.7\"\>",
      14.6902449,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[14.6902449, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.7836346598944397`*^9, 
  3.783634705384118*^9},ExpressionUUID->"022a44f5-bf39-4d91-8922-\
d10d500eed18"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "13", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox["\"Sp(30)\"", TraditionalForm], "\" Tensor Products\""}, 
         "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["434",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["434",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4030",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8960",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["434",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["434",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["434",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["465",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66990",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["93496",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.783626221842499*^9, {3.783628669798297*^9, 3.783628698453313*^9}, 
   3.7836346759143457`*^9, 
   3.783640931490011*^9},ExpressionUUID->"b6984007-6cf1-4f3f-8441-\
822e5e5a119f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exceptional Algebras", "Section",ExpressionUUID->"16e2101c-8afa-48c0-8c66-d4c668389ead"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"E6", ",", 
   RowBox[{"MaxDim", "\[Rule]", "2430"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1000000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7823259689876213`*^9, 3.782326052957167*^9}, {
  3.783603789745325*^9, 
  3.783603794458256*^9}},ExpressionUUID->"55814a22-57f8-4df0-be4b-\
e52c474acfbe"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "36"}],
   
   SequenceForm["Number of Tensor Products: ", 36],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226391738182*^9, {3.782325985263842*^9, 3.7823260107395782`*^9}, {
   3.7823260444407983`*^9, 3.782326061057968*^9}, 
   3.783603806965191*^9},ExpressionUUID->"ffdebefa-3d07-46c1-8300-\
7d0e1c03e28e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"11.9\"\>",
      11.897575,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[11.897575, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226391738182*^9, {3.782325985263842*^9, 3.7823260107395782`*^9}, {
   3.7823260444407983`*^9, 3.782326061057968*^9}, 
   3.783603806969179*^9},ExpressionUUID->"af31daf8-99e6-4542-8096-\
ffd5b9647cc7"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "6"], TraditionalForm], 
          "\" Tensor Products\""}, "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["19305", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34398", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["54054", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["51975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["54054", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["17550", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34398", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["51975", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78975",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["61425",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["351",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["7371",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51975",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["78",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2925",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3003", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5824",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5824", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78975",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["78975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["17550", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["19305", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["46332",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51975",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3003", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5824", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["78975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["146432", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["252252", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2925",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3003", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5824", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["78975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["252252", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["17550", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["46332", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["51975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["112320", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["359424", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["7371", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["17550", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["19305", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["46332", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["51975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["112320", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["314496", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["351",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["7371",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["7722",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17550",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34398",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["46332",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["51975",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["54054",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["314496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["359424",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["78",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2925",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5824",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5824", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["43758",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70070",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["78975",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["78975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85293",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105600",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["252252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["252252", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["812175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["852930",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox[
               OverscriptBox["351", "_"],
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["7371", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["17550", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["19305", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34398", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["46332", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["51975", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["61425", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["112320", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["314496", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["386100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["393822", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["459459", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["494208", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["46332",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43758",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105600",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34398",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["314496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["459459",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["46332",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51975",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["314496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["393822",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["252252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["252252", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["812175",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616219239157033*^9, 3.616226395800343*^9, {3.782325987935608*^9, 
   3.782326013166441*^9}, {3.78232604452557*^9, 3.7823260614101686`*^9}, 
   3.7836038100295043`*^9},ExpressionUUID->"b412934f-d5a1-44e5-b6a4-\
8782472deefa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"E7", ",", 
   RowBox[{"MaxDim", "\[Rule]", "6480"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "8000000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7836727639648633`*^9, 3.7836727651896005`*^9}, {
  3.783672806221101*^9, 3.7836728279632697`*^9}, {3.783672901897687*^9, 
  3.783672909414626*^9}},ExpressionUUID->"cb99b385-9a6a-498d-9f89-\
a8ebc924caed"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "21"}],
   
   SequenceForm["Number of Tensor Products: ", 21],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226436506714*^9, {3.7836727905619698`*^9, 3.783672831039048*^9}, {
   3.783672905301589*^9, 
   3.783672912388641*^9}},ExpressionUUID->"853e633d-84dc-4288-8490-\
f832b8d7f14e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"2.5\"\>",
      2.4935718,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[2.4935718, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226436506714*^9, {3.7836727905619698`*^9, 3.783672831039048*^9}, {
   3.783672905301589*^9, 
   3.783672912391633*^9}},ExpressionUUID->"8ed329eb-8599-4816-ae61-\
6a84d98f1516"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "21", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "7"], TraditionalForm], 
          "\" Tensor Products\""}, "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["86184",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["253935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["365750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["362880",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["885248",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["293930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["617253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["915705",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["6480",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["86184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["362880",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["861840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["915705",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["980343",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1539",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40755",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["365750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["617253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["980343",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["6480",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["86184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["362880",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1539",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8645",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40755",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["152152",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["365750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["573440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["980343",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3424256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["6480",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["24320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["51072",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["86184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["362880",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["861840",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["885248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2273920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4522000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["912",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["6480",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["24320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27664",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["51072",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["86184",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["320112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["362880",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["861840",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["885248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2282280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4522000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["133",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1463",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1539",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["7371",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["8645",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["40755",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["150822",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["152152",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["238602",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["253935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["365750",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["573440",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["617253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["915705",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["980343",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3424256",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6619239",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6760390",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7142499",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7482618",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616219239184465*^9, 3.6162264460519238`*^9, {3.7836727982115445`*^9, 
   3.7836728323555346`*^9}, {3.7836729053474655`*^9, 
   3.7836729137460117`*^9}},ExpressionUUID->"5102c62f-217f-42e0-9cc3-\
de820907c66c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"E8", ",", 
   RowBox[{"MaxDim", "\[Rule]", "30380"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "500000000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7823261746532984`*^9, 3.782326195664042*^9}, {
  3.7823262381962643`*^9, 3.7823262386619883`*^9}, {3.7823263047412972`*^9, 
  3.7823263211833696`*^9}, {3.782326419296889*^9, 
  3.7823264244217787`*^9}},ExpressionUUID->"bbdb212b-e22e-4a80-9d8e-\
e519fa261bb5"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "10"}],
   
   SequenceForm["Number of Tensor Products: ", 10],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226545207756*^9, {3.7823261840717335`*^9, 3.7823261976003623`*^9}, {
   3.782326282297326*^9, 3.7823263234131565`*^9}, 
   3.7823264483535533`*^9},ExpressionUUID->"2b3dd1b0-3641-4e7d-b75a-\
3a6528d6d39e"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"20.3\"\>",
      20.2766932,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[20.2766932, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.616226545207756*^9, {3.7823261840717335`*^9, 3.7823261976003623`*^9}, {
   3.782326282297326*^9, 3.7823263234131565`*^9}, 
   3.7823264483565493`*^9},ExpressionUUID->"0269224d-5fcd-47a6-b67c-\
0055dfc8ead2"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "98", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "8"], TraditionalForm], 
          "\" Tensor Products\""}, "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["147250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["779247",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["147250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["779247",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4881384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6696000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["779247",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1763125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["147250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["779247",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26411008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70680000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27000",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["779247",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1763125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096000",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4881384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70680000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76271625",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["79143000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["203205000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["281545875",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["147250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["779247",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["30380",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["147250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["779247",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2450240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6696000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26411008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76271625",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["30380",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["147250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["779247",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1763125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096000",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6696000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26411008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70680000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76271625",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["281545875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["344452500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3875",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27000",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["30380",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["147250",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["779247",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1763125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2450240",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096000",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4881384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6696000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["26411008",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70680000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76271625",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["146325270",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["203205000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["344452500",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6162192391880198`*^9, 3.616226545283214*^9, {3.7823261841335735`*^9, 
   3.782326197611332*^9}, {3.782326294894621*^9, 3.7823263177375884`*^9}, 
   3.782326405038836*^9, 
   3.78232644839242*^9},ExpressionUUID->"a58c532b-2d0f-48e6-bcba-\
27c1af25a0f0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"F4", ",", 
   RowBox[{"MaxDim", "\[Rule]", "4500"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "32000000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7823266116205807`*^9, 
  3.782326642316142*^9}},ExpressionUUID->"0f201873-c4d8-4c67-bc21-\
a7b60b705817"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61622655523326*^9, {3.782326618242755*^9, 3.782326645999339*^9}, 
   3.7836730122438617`*^9},ExpressionUUID->"20284784-7562-4120-aeb9-\
850f0cbfaa60"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"6.4\"\>",
      6.3612222,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[6.3612222, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.61622655523326*^9, {3.782326618242755*^9, 3.782326645999339*^9}, 
   3.783673012246854*^9},ExpressionUUID->"b0f672ef-41c2-4fb6-8adc-\
c953b9409e24"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "23", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox[
           SubscriptBox["\"F\"", "4"], TraditionalForm], 
          "\" Tensor Products\""}, "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["52",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["1053",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17901",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["184756",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["1053",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["100776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["226746",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["340119",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17901",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["340119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["1053",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["226746",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81081",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160056",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["412776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1002456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["76076",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["952952",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16302",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81081",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["205751",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["212992",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["342056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["412776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["629356",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1042899",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1341522",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"7", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17901",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["76076",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["107406",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160056",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["205751",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1327104",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17901",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["76076",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["107406",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160056",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["205751",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1118208",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16302",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17901",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["76076",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["81081",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["107406",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["160056",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["205751",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["212992",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["412776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["787644",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["952952",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1042899",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1118208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1341522",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["26",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["52",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"7", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["1053",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"10", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"9", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"9", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["16302",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["17901",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"9", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"7", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"10", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["76076",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["81081",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"10", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["107406",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["119119",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"6", "(", 
            FormBox[
             StyleBox["160056",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["160056",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["205751",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["212992",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["226746",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["379848",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["412776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["420147",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["629356",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["787644",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["952952",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1118208",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1341522",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6162192392131968`*^9, 3.6162265557180243`*^9, {3.7823266183743744`*^9, 
   3.78232664622773*^9}, 
   3.7836730126587505`*^9},ExpressionUUID->"6334d292-21fd-47e4-9d33-\
33180aa01144"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"G2", ",", 
   RowBox[{"MaxDim", "\[Rule]", "189"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "96000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.782326772117715*^9, 3.7823267848008084`*^9}, {
  3.783603834042036*^9, 
  3.7836038357564*^9}},ExpressionUUID->"a300d938-7260-487b-8dbf-be79dbe9c9d9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "36"}],
   
   SequenceForm["Number of Tensor Products: ", 36],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162265567165413`*^9, {3.7823267747506776`*^9, 3.782326786189125*^9}, 
   3.783603836961329*^9},ExpressionUUID->"41e243f0-88e7-4692-a1e0-\
7be166ccaf39"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.5\"\>",
      0.4620609,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.4620609, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{
  3.6162265567165413`*^9, {3.7823267747506776`*^9, 3.782326786189125*^9}, 
   3.783603836976918*^9},ExpressionUUID->"a1210b9a-3b20-4eb3-a0af-\
117e19e7f44c"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "7", "\": \""}, 
          "RowDefault"], Bold, StripOnInput -> False],TemplateBox[{
          FormBox[
           SubscriptBox["\"G\"", "2"], TraditionalForm], 
          "\" Tensor Products\""}, "RowDefault"]},
       "RowDefault"]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["14",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2926",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1254",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["714",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1254",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1547",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2079",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2926",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["714",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1254",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1547",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2926",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["14",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"6", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"6", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["714",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1254",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1547",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2926",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616219239238017*^9, 3.61622655685837*^9, {3.7823267748194914`*^9, 
   3.782326786384574*^9}, 
   3.7836038370706773`*^9},ExpressionUUID->"5f232356-136e-443b-819d-\
c03937d5006a"]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{734, 669},
WindowMargins->{{117, Automatic}, {Automatic, 42}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperOrientation"->"Portrait",
"PaperSize"->{594.75, 842.25},
"PostScriptOutputFile"->"/home/feger/print.pdf"},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> True}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 97, 0, 83, "Title", "ExpressionUUID" -> \
"e5d4ffd4-6386-4fac-bd70-0c1c800a6940"],
Cell[679, 24, 273, 8, 30, "Subsubtitle", "ExpressionUUID" -> \
"ace8d606-280f-4dbd-894e-acb0acdbcef8"],
Cell[CellGroupData[{
Cell[977, 36, 88, 0, 71, "Section", "ExpressionUUID" -> \
"d2eb2164-b67a-448d-b12b-54bc20cb8252"],
Cell[1068, 38, 143, 3, 29, "Input", "ExpressionUUID" -> \
"7fc4d170-2abe-4949-9fff-b187e818401e",
 InitializationCell->True],
Cell[1214, 43, 392, 11, 67, "Input", "ExpressionUUID" -> \
"180d65e1-1f5c-49e4-a566-061e1f02364a",
 InitializationCell->True],
Cell[1609, 56, 280, 6, 31, "Input", "ExpressionUUID" -> \
"9ef8c7e4-0b04-4a21-89c3-3f42ae86d650"]
}, Closed]],
Cell[CellGroupData[{
Cell[1926, 67, 79, 0, 41, "Section", "ExpressionUUID" -> \
"6d3278ed-ec18-4107-aa12-9cdb3be52c6c"],
Cell[CellGroupData[{
Cell[2030, 71, 449, 9, 29, "Input", "ExpressionUUID" -> \
"40ab07f8-738d-4ac0-9cdc-a65a3f17fe4c"],
Cell[2482, 82, 434, 11, 23, "Print", "ExpressionUUID" -> \
"5c78ba4c-b6ff-494c-98a0-afb3a3d4cac8"],
Cell[2919, 95, 589, 16, 23, "Print", "ExpressionUUID" -> \
"057545bc-987e-47b0-8440-e28dc904ba2f"],
Cell[3511, 113, 38843, 1370, 802, "Output", "ExpressionUUID" -> \
"299fb113-2e99-465e-ac84-57013b42149a"]
}, Open  ]],
Cell[42369, 1486, 421, 9, 29, "Input", "ExpressionUUID" -> \
"b80d58a5-50b4-453b-9b19-2b8551d60616"]
}, Open  ]]
}, Open  ]],
Cell[42817, 1499, 408, 10, 23, "Print", "ExpressionUUID" -> \
"53ea4f2d-1b23-4d64-974a-f0ee5ce9cc6d"],
Cell[43228, 1511, 561, 15, 23, "Print", "ExpressionUUID" -> \
"a47a0f33-944e-4fba-bf00-9a72c86110ae"],
Cell[43792, 1528, 94197, 3240, 1802, "Output", "ExpressionUUID" -> \
"fcfa0e7d-19aa-4cb0-a336-816ef31b400d"],
Cell[CellGroupData[{
Cell[138014, 4772, 299, 6, 29, "Input", "ExpressionUUID" -> \
"df39dbcc-4a8e-4f7a-8cae-84163e70f148"],
Cell[138316, 4780, 330, 9, 23, "Print", "ExpressionUUID" -> \
"6bf2bd36-439e-44da-880b-c3ac6ed6a296"],
Cell[138649, 4791, 595, 16, 23, "Print", "ExpressionUUID" -> \
"a7f67316-8609-41f2-aaea-d81a7b1dfdd1"],
Cell[139247, 4809, 91609, 3126, 1796, "Output", "ExpressionUUID" -> \
"9fefbf8e-53e1-4457-9aa1-aeee67f18689"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230893, 7940, 299, 6, 29, "Input", "ExpressionUUID" -> \
"90f411cd-e3ef-409e-8e53-94596560e0ef"],
Cell[231195, 7948, 330, 9, 23, "Print", "ExpressionUUID" -> \
"17c9f149-2484-4f43-8f1c-24ea5bb2513a"],
Cell[231528, 7959, 598, 16, 23, "Print", "ExpressionUUID" -> \
"aed12bd5-c14b-444b-a722-cb6a9146c3a6"],
Cell[232129, 7977, 88977, 3055, 1766, "Output", "ExpressionUUID" -> \
"652abb6e-085c-4372-ae08-4519cd48b629"]
}, Open  ]],
Cell[CellGroupData[{
Cell[321143, 11037, 300, 6, 29, "Input", "ExpressionUUID" -> \
"5df806de-7931-4477-bcf6-ddb842dc3c47"],
Cell[321446, 11045, 327, 8, 23, "Print", "ExpressionUUID" -> \
"0ef916c1-0e45-4cb7-a44f-96bc6defc877"],
Cell[321776, 11055, 591, 15, 23, "Print", "ExpressionUUID" -> \
"67e3a996-cb2a-4fc2-9838-9909a573df26"],
Cell[322370, 11072, 86293, 2940, 1760, "Output", "ExpressionUUID" -> \
"f1c060e7-3d43-49c9-99f6-4ee6f02dc6de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408700, 14017, 657, 12, 29, "Input", "ExpressionUUID" -> \
"c38f4105-d508-4328-b07d-a9b39f7824d1"],
Cell[409360, 14031, 517, 11, 23, "Print", "ExpressionUUID" -> \
"afee6ed5-14fb-4504-a492-d7860eaa1353"],
Cell[409880, 14044, 668, 15, 23, "Print", "ExpressionUUID" -> \
"1764a028-1cd2-41ec-94a4-88bc49434059"],
Cell[410551, 14061, 37951, 1298, 954, "Output", "ExpressionUUID" -> \
"36184501-a77c-4422-9cae-607aa680c622"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448539, 15364, 574, 11, 29, "Input", "ExpressionUUID" -> \
"4f4e35ce-17dd-43f4-b5e2-a984c104358a"],
Cell[449116, 15377, 474, 11, 23, "Print", "ExpressionUUID" -> \
"45db7b40-5ac9-4fb9-b919-5edd72100e76"],
Cell[449593, 15390, 634, 16, 23, "Print", "ExpressionUUID" -> \
"6f43fedf-2b2e-4f78-98fe-87b72cc828fa"],
Cell[450230, 15408, 41078, 1408, 1034, "Output", "ExpressionUUID" -> \
"8a410830-e6a5-4d96-80ed-0c5b2b01f18d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[491345, 16821, 420, 9, 29, "Input", "ExpressionUUID" -> \
"53878ede-4051-4fab-a88b-e3c31c6497a6"],
Cell[491768, 16832, 427, 10, 23, "Print", "ExpressionUUID" -> \
"818af2b8-42b4-4a26-b939-ac66c40397a0"],
Cell[492198, 16844, 588, 15, 23, "Print", "ExpressionUUID" -> \
"52247f10-c75e-4a92-bec2-7027e2bb7c57"],
Cell[492789, 16861, 28619, 986, 788, "Output", "ExpressionUUID" -> \
"3096c180-83f4-4cc9-b23c-a71b9fd5b46f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[521445, 17852, 301, 6, 29, "Input", "ExpressionUUID" -> \
"b4722304-037a-4c61-b392-60840c4e4790"],
Cell[521749, 17860, 332, 9, 23, "Print", "ExpressionUUID" -> \
"cbdfe3c7-485d-4943-b876-09f74146e212"],
Cell[522084, 17871, 591, 15, 23, "Print", "ExpressionUUID" -> \
"0191cb55-bbce-484d-ab36-29873ddb0b61"],
Cell[522678, 17888, 10219, 349, 310, "Output", "ExpressionUUID" -> \
"10ca03b7-44e7-41f5-bee1-a9da75a59b52"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532934, 18242, 301, 6, 29, "Input", "ExpressionUUID" -> \
"e9cd2577-7eaf-47ce-a843-9ff39e5f98ac"],
Cell[533238, 18250, 324, 8, 23, "Print", "ExpressionUUID" -> \
"63f61bf5-4b58-4a45-ae1c-0866503bb08a"],
Cell[533565, 18260, 591, 15, 23, "Print", "ExpressionUUID" -> \
"63d67840-beb2-4ef8-9c5e-17f57c9b33a3"],
Cell[534159, 18277, 5366, 178, 164, "Output", "ExpressionUUID" -> \
"cdbf481f-bf83-4719-b8a3-5d3a3afaf7b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539562, 18460, 301, 6, 29, "Input", "ExpressionUUID" -> \
"8a4bb30e-3510-4f70-a053-4b4c661e8c1c"],
Cell[539866, 18468, 326, 8, 23, "Print", "ExpressionUUID" -> \
"67191569-3884-4607-9e49-3c7456d16459"],
Cell[540195, 18478, 601, 16, 23, "Print", "ExpressionUUID" -> \
"7f4a714d-8c68-4982-841b-f30e0020fa74"],
Cell[540799, 18496, 5367, 178, 164, "Output", "ExpressionUUID" -> \
"fe3ed4f5-0a42-418e-b595-8433b03e4801"]
}, Open  ]],
Cell[CellGroupData[{
Cell[546203, 18679, 473, 9, 29, "Input", "ExpressionUUID" -> \
"bfe47237-cebc-4496-9e52-b2ac46dc58db"],
Cell[546679, 18690, 374, 8, 23, "Print", "ExpressionUUID" -> \
"1a94eb90-9ea4-44f1-88d9-5b72dec117d9"],
Cell[547056, 18700, 541, 14, 23, "Print", "ExpressionUUID" -> \
"835ce9db-18a2-4601-a087-e6879b8c62f1"],
Cell[547600, 18716, 5397, 177, 164, "Output", "ExpressionUUID" -> \
"42b5f1fc-35e5-4502-ac55-f66143b4df67"]
}, Open  ]],
Cell[CellGroupData[{
Cell[553034, 18898, 466, 9, 29, "Input", "ExpressionUUID" -> \
"6e172edf-26d1-48b3-a68b-327477b634b5"],
Cell[553503, 18909, 434, 11, 23, "Print", "ExpressionUUID" -> \
"f742ccce-8987-4252-bf5c-ee581ab89f59"],
Cell[553940, 18922, 594, 16, 23, "Print", "ExpressionUUID" -> \
"fe3ae5da-336b-412a-ac4c-fb43a1fb19ba"],
Cell[554537, 18940, 8628, 289, 240, "Output", "ExpressionUUID" -> \
"0f7acd41-503a-421b-8c08-745a6b853241"]
}, Open  ]],
Cell[CellGroupData[{
Cell[563202, 19234, 373, 8, 29, "Input", "ExpressionUUID" -> \
"b8db2eab-d5fe-42aa-8e1c-c250d188648b"],
Cell[563578, 19244, 352, 9, 23, "Print", "ExpressionUUID" -> \
"82aff1a3-cb5e-459a-83f6-1ab109f815e6"],
Cell[563933, 19255, 512, 14, 23, "Print", "ExpressionUUID" -> \
"af475e40-6916-40b5-88b6-38bde0125d8f"],
Cell[564448, 19271, 8570, 288, 240, "Output", "ExpressionUUID" -> \
"b0f15af7-973a-4d75-a61e-ea3821f5a407"]
}, Open  ]],
Cell[CellGroupData[{
Cell[573055, 19564, 451, 10, 29, "Input", "ExpressionUUID" -> \
"c8bfe028-9fb8-47ea-921f-0565a32b3263"],
Cell[573509, 19576, 326, 8, 23, "Print", "ExpressionUUID" -> \
"7d21fa0a-17c5-4d85-9245-468316c7eda8"],
Cell[573838, 19586, 490, 14, 23, "Print", "ExpressionUUID" -> \
"3e6f18b6-40ba-41e5-b218-9ba8da86e958"],
Cell[574331, 19602, 4189, 136, 128, "Output", "ExpressionUUID" -> \
"708e7974-08bb-4472-af2b-bb59acb1078f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[578557, 19743, 79, 0, 71, "Section", "ExpressionUUID" -> \
"d371eded-dfa3-4fcb-92c2-e205d3da51b7"],
Cell[CellGroupData[{
Cell[578661, 19747, 300, 6, 29, "Input", "ExpressionUUID" -> \
"a0c96267-4ca8-40be-8e66-1e3ba42023aa"],
Cell[578964, 19755, 354, 9, 23, "Print", "ExpressionUUID" -> \
"2c64429c-56b5-4704-8a7e-bfe9f8290e1a"],
Cell[579321, 19766, 612, 15, 23, "Print", "ExpressionUUID" -> \
"12cafcec-3793-4939-9b8b-103764844d23"],
Cell[579936, 19783, 102057, 3483, 1580, "Output", "ExpressionUUID" -> \
"a24daaf6-6fd7-4676-bba6-57b4058f9690"]
}, Open  ]],
Cell[CellGroupData[{
Cell[682030, 23271, 300, 6, 29, "Input", "ExpressionUUID" -> \
"93a4c5d6-5579-40c6-adb8-37e19451015f"],
Cell[682333, 23279, 330, 9, 23, "Print", "ExpressionUUID" -> \
"c27024c3-cff7-4d22-ac39-33ade91fc1b8"],
Cell[682666, 23290, 592, 16, 23, "Print", "ExpressionUUID" -> \
"fdbd4f7f-d834-46a3-aa3d-c62cafda40de"],
Cell[683261, 23308, 110788, 3729, 1672, "Output", "ExpressionUUID" -> \
"39c9c31c-f5b1-4329-ab31-2174034e8785"]
}, Open  ]],
Cell[CellGroupData[{
Cell[794086, 27042, 301, 6, 29, "Input", "ExpressionUUID" -> \
"07801df0-2bc4-44b4-9bbc-91122aa857f3"],
Cell[794390, 27050, 330, 9, 23, "Print", "ExpressionUUID" -> \
"81ecee6d-77c5-4eab-9863-d29db18eccac"],
Cell[794723, 27061, 591, 15, 23, "Print", "ExpressionUUID" -> \
"8737cee0-b739-429e-9413-bf976e376df9"],
Cell[795317, 27078, 98489, 3380, 1582, "Output", "ExpressionUUID" -> \
"b825f0d9-1ade-438c-99dd-2a52844067bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[893843, 30463, 302, 6, 29, "Input", "ExpressionUUID" -> \
"ba056756-7f1d-45df-8fcd-26618e30daab"],
Cell[894148, 30471, 330, 9, 23, "Print", "ExpressionUUID" -> \
"4fd909fa-0001-479b-9bde-0e59a5f8b3b7"],
Cell[894481, 30482, 591, 15, 23, "Print", "ExpressionUUID" -> \
"302b8e2e-4441-4519-b27c-175929fae27f"],
Cell[895075, 30499, 104815, 3564, 1766, "Output", "ExpressionUUID" -> \
"f38cfafe-36cf-415b-80a4-194cae4f2550"]
}, Open  ]],
Cell[CellGroupData[{
Cell[999927, 34068, 302, 6, 29, "Input", "ExpressionUUID" -> \
"a2f05b34-4f1c-4c81-92bd-888c6e8a832c"],
Cell[1000232, 34076, 330, 9, 23, "Print", "ExpressionUUID" -> \
"160fbade-e511-4f55-b5b1-3dab21aeaa24"],
Cell[1000565, 34087, 593, 15, 23, "Print", "ExpressionUUID" -> \
"4ef275ca-3931-4363-b92e-117f1dd4ac73"],
Cell[1001161, 34104, 48403, 1671, 868, "Output", "ExpressionUUID" -> \
"16c20894-6449-46e4-9e0f-1acf1d5900b3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1049601, 35780, 652, 12, 29, "Input", "ExpressionUUID" -> \
"c84e3bb5-5241-4ad2-8945-1f90b04da381"],
Cell[1050256, 35794, 526, 11, 23, "Print", "ExpressionUUID" -> \
"1c269f81-c5c1-4136-a765-9e387eb7748c"],
Cell[1050785, 35807, 682, 16, 23, "Print", "ExpressionUUID" -> \
"50435ee2-257a-4820-91f5-aa2c4b93cdb7"],
Cell[1051470, 35825, 64137, 2186, 1136, "Output", "ExpressionUUID" -> \
"a9aa4356-753c-4405-a70c-3edd36e669fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1115644, 38016, 554, 10, 29, "Input", "ExpressionUUID" -> \
"ede2f952-ddb2-44d9-b668-f8c48e657257"],
Cell[1116201, 38028, 449, 10, 23, "Print", "ExpressionUUID" -> \
"9eb0e8ad-a5f0-4033-9807-8c0583de34e9"],
Cell[1116653, 38040, 607, 15, 23, "Print", "ExpressionUUID" -> \
"79b245c9-2b3b-4685-9f3d-d4239a734eaa"],
Cell[1117263, 38057, 28954, 998, 576, "Output", "ExpressionUUID" -> \
"f3a3d216-19eb-458c-8000-7b12e170f3c8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1146254, 39060, 374, 8, 29, "Input", "ExpressionUUID" -> \
"92bc05d4-6ff7-4ea5-bd59-e145e1c9ac7c"],
Cell[1146631, 39070, 356, 9, 23, "Print", "ExpressionUUID" -> \
"669cb79c-d4bf-49ee-8f8a-2dc297d3c24b"],
Cell[1146990, 39081, 511, 14, 23, "Print", "ExpressionUUID" -> \
"48088893-d67c-443e-a292-72cbf00866f5"],
Cell[1147504, 39097, 9364, 317, 228, "Output", "ExpressionUUID" -> \
"7bbdc2a1-7d50-464e-9aa6-371470b188e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1156905, 39419, 302, 6, 29, "Input", "ExpressionUUID" -> \
"59057413-748a-4c01-bae6-bdf411d4618b"],
Cell[1157210, 39427, 332, 9, 23, "Print", "ExpressionUUID" -> \
"b223fad6-be58-4c7b-bdfb-aa527d3a037b"],
Cell[1157545, 39438, 490, 14, 23, "Print", "ExpressionUUID" -> \
"d19ff8c1-3019-4c1a-8eeb-d920fd5171ce"],
Cell[1158038, 39454, 9939, 338, 224, "Output", "ExpressionUUID" -> \
"22daf28a-64e4-48b8-acdd-45e051c352ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1168014, 39797, 375, 8, 29, "Input", "ExpressionUUID" -> \
"45ad9805-9904-41a8-9ab6-e81b6beb4350"],
Cell[1168392, 39807, 352, 9, 23, "Print", "ExpressionUUID" -> \
"ddd034cf-9323-45ce-a6d3-6860093faeca"],
Cell[1168747, 39818, 510, 14, 23, "Print", "ExpressionUUID" -> \
"2b6da083-ebed-4998-b394-5551a6c853a3"],
Cell[1169260, 39834, 11948, 407, 282, "Output", "ExpressionUUID" -> \
"2975874e-5c49-454d-851a-2b6d0f575eef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1181245, 40246, 375, 8, 29, "Input", "ExpressionUUID" -> \
"676ce662-c7bb-4613-b5bf-240e4ffa6f32"],
Cell[1181623, 40256, 356, 9, 23, "Print", "ExpressionUUID" -> \
"a53065e9-3c7f-437a-bd3c-0ff001138155"],
Cell[1181982, 40267, 509, 14, 23, "Print", "ExpressionUUID" -> \
"4e8c5399-7939-47b8-b320-09894e86141f"],
Cell[1182494, 40283, 10736, 364, 240, "Output", "ExpressionUUID" -> \
"acbd7e8e-29ad-47a5-9684-f41109eda627"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1193267, 40652, 552, 10, 29, "Input", "ExpressionUUID" -> \
"c5551688-ac18-4b66-a850-ebf850d1f0bd"],
Cell[1193822, 40664, 451, 10, 23, "Print", "ExpressionUUID" -> \
"02f0c2bd-f46b-439f-97f7-58c9bbdb1661"],
Cell[1194276, 40676, 610, 15, 23, "Print", "ExpressionUUID" -> \
"f8ee3e34-cab0-4e1d-8327-e956efe0ac0e"],
Cell[1194889, 40693, 17670, 601, 388, "Output", "ExpressionUUID" -> \
"5228b17f-eaa3-4623-aa62-b935b7298575"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1212596, 41299, 303, 6, 29, "Input", "ExpressionUUID" -> \
"9242ff4c-341a-4a09-93a4-e556d5f324a9"],
Cell[1212902, 41307, 330, 9, 23, "Print", "ExpressionUUID" -> \
"c93397f5-ccab-4130-a636-aec9e1577301"],
Cell[1213235, 41318, 488, 14, 23, "Print", "ExpressionUUID" -> \
"0d00a32c-d1f0-4bac-9ec9-18713d47b95f"],
Cell[1213726, 41334, 13868, 474, 292, "Output", "ExpressionUUID" -> \
"55cac42a-8217-4fb6-9da0-3d01d9625701"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1227631, 41813, 305, 6, 29, "Input", "ExpressionUUID" -> \
"c94dac0d-c199-4642-9e3d-2cace2d0ef9f"],
Cell[1227939, 41821, 332, 9, 23, "Print", "ExpressionUUID" -> \
"a1924bfe-cc8d-4bb3-b6e5-67ba8fb58b2c"],
Cell[1228274, 41832, 490, 14, 23, "Print", "ExpressionUUID" -> \
"b408b3bc-69d8-43f5-a368-b0a00a98b08b"],
Cell[1228767, 41848, 14538, 496, 316, "Output", "ExpressionUUID" -> \
"f8a7b61b-cde9-4c79-b501-086338b3bdee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1243342, 42349, 305, 6, 29, "Input", "ExpressionUUID" -> \
"2448ed5f-cbcd-45a3-a30e-bac6f7b93dc7"],
Cell[1243650, 42357, 332, 9, 23, "Print", "ExpressionUUID" -> \
"63dcbe97-752b-4252-9f30-85e823255721"],
Cell[1243985, 42368, 493, 14, 23, "Print", "ExpressionUUID" -> \
"ab6f951e-8a3a-4da7-b087-5ac0e4e0e6b2"],
Cell[1244481, 42384, 23777, 811, 450, "Output", "ExpressionUUID" -> \
"c5470ec1-833c-40fd-9cc3-ca2c2b6d63e0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1268295, 43200, 403, 9, 29, "Input", "ExpressionUUID" -> \
"e63cfbf1-fd64-43c5-a7ab-a11fda8cb941"],
Cell[1268701, 43211, 376, 9, 23, "Print", "ExpressionUUID" -> \
"953ff989-ee3d-4eab-84ba-013d0f100e12"],
Cell[1269080, 43222, 534, 14, 23, "Print", "ExpressionUUID" -> \
"f8817cae-fb0e-4b6e-8298-6ca61859aac6"],
Cell[1269617, 43238, 11667, 390, 246, "Output", "ExpressionUUID" -> \
"084e1b41-0742-4558-aea5-3eee790cc7f0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1281321, 43633, 307, 6, 29, "Input", "ExpressionUUID" -> \
"f6b4181a-c588-41c9-ba2e-f9763fa182f0"],
Cell[1281631, 43641, 332, 9, 23, "Print", "ExpressionUUID" -> \
"fb482fc1-1003-4924-a6a9-f58c2000031c"],
Cell[1281966, 43652, 493, 14, 23, "Print", "ExpressionUUID" -> \
"3130a8c4-2588-4657-a026-b5769a1e9531"],
Cell[1282462, 43668, 11587, 393, 258, "Output", "ExpressionUUID" -> \
"c79f2017-0cfa-46f4-ad48-e9d99ab0b0b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1294086, 44066, 307, 6, 29, "Input", "ExpressionUUID" -> \
"6e45c10e-0fd0-4614-aa5a-2e66f2e8e8b3"],
Cell[1294396, 44074, 330, 9, 23, "Print", "ExpressionUUID" -> \
"37e4cdbd-cfe7-437c-b7fd-53f81a4647b0"],
Cell[1294729, 44085, 487, 13, 23, "Print", "ExpressionUUID" -> \
"95c82327-1f51-4fef-b3a7-8b6a796bd5d1"],
Cell[1295219, 44100, 11795, 399, 262, "Output", "ExpressionUUID" -> \
"fab02d63-c52e-4d8b-a532-a909269de8f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1307051, 44504, 401, 9, 29, "Input", "ExpressionUUID" -> \
"81ffc95b-57e4-4043-a216-2fce92aaccd9"],
Cell[1307455, 44515, 324, 8, 23, "Print", "ExpressionUUID" -> \
"bcffac61-e058-4ae6-8885-e1af16d8a827"],
Cell[1307782, 44525, 488, 14, 23, "Print", "ExpressionUUID" -> \
"0c927fa2-ceeb-426e-918f-f8bd3a4330ad"],
Cell[1308273, 44541, 5251, 172, 122, "Output", "ExpressionUUID" -> \
"d4503551-6879-4a36-8308-93537d6b45c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1313561, 44718, 352, 8, 29, "Input", "ExpressionUUID" -> \
"6d790813-b4af-4278-adc8-41650a4d16bf"],
Cell[1313916, 44728, 372, 8, 23, "Print", "ExpressionUUID" -> \
"ceb2a6b0-8ac9-4edb-b3ff-c885664a4820"],
Cell[1314291, 44738, 638, 16, 23, "Print", "ExpressionUUID" -> \
"fec21fcd-d7b5-4d37-b00e-48262e14774a"],
Cell[1314932, 44756, 5277, 173, 122, "Output", "ExpressionUUID" -> \
"1820677d-2e60-4c29-a857-16ac33af900b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1320258, 44935, 426, 9, 29, "Input", "ExpressionUUID" -> \
"75f98951-1bec-4bd5-89f1-cba9c11768d9"],
Cell[1320687, 44946, 324, 8, 23, "Print", "ExpressionUUID" -> \
"25a42df3-3871-4d30-9799-cf22caf06982"],
Cell[1321014, 44956, 488, 14, 23, "Print", "ExpressionUUID" -> \
"a8785466-bf40-4356-a787-557a7bd550a2"],
Cell[1321505, 44972, 5229, 172, 122, "Output", "ExpressionUUID" -> \
"6d4233d1-2bf6-415c-a259-dde5bbe23cc9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1326771, 45149, 305, 6, 29, "Input", "ExpressionUUID" -> \
"c195bbb4-c7e6-43bd-836f-6f1948924d09"],
Cell[1327079, 45157, 324, 8, 23, "Print", "ExpressionUUID" -> \
"b6766fa4-69ef-4c90-8304-feebc20d2f71"],
Cell[1327406, 45167, 488, 14, 23, "Print", "ExpressionUUID" -> \
"5f985b7e-1525-4d34-a80a-0cc798935305"],
Cell[1327897, 45183, 5231, 172, 122, "Output", "ExpressionUUID" -> \
"107c34cd-6abe-48ef-8c46-d46ac47788d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1333165, 45360, 401, 8, 29, "Input", "ExpressionUUID" -> \
"6bc89afa-0c4c-4955-996e-4410a5077310"],
Cell[1333569, 45370, 350, 8, 23, "Print", "ExpressionUUID" -> \
"c649f900-daac-44c8-bb09-7b5f8626f5d4"],
Cell[1333922, 45380, 512, 14, 23, "Print", "ExpressionUUID" -> \
"56911eaf-66fd-4864-8a95-a20cc0df3f42"],
Cell[1334437, 45396, 5256, 172, 122, "Output", "ExpressionUUID" -> \
"8f0322b4-f5ec-47b7-8408-05bba2b372a6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1339730, 45573, 521, 10, 29, "Input", "ExpressionUUID" -> \
"9b6b7ab9-1ee2-4b66-aef5-0e6dbab5f7f7"],
Cell[1340254, 45585, 374, 8, 23, "Print", "ExpressionUUID" -> \
"11649daa-daa6-447b-95e3-ab3c78a7ba63"],
Cell[1340631, 45595, 538, 14, 23, "Print", "ExpressionUUID" -> \
"75e21ead-eaff-4a9c-8092-9e8748f1e525"],
Cell[1341172, 45611, 5253, 172, 122, "Output", "ExpressionUUID" -> \
"9eee4ff7-8054-4f60-9560-447510e4318b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1346462, 45788, 540, 11, 48, "Input", "ExpressionUUID" -> \
"5e9f7f6d-5094-447c-869c-816254ff57cc"],
Cell[1347005, 45801, 324, 8, 23, "Print", "ExpressionUUID" -> \
"537d5310-f97d-4f70-96ce-72a40b177ae5"],
Cell[1347332, 45811, 488, 14, 23, "Print", "ExpressionUUID" -> \
"3ab08816-db6d-4276-b214-b1a753b8d4d0"],
Cell[1347823, 45827, 5236, 172, 122, "Output", "ExpressionUUID" -> \
"cd3a2807-c2dd-490f-8553-dcfc8eca9e23"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1353096, 46004, 549, 16, 29, "Input", "ExpressionUUID" -> \
"22ad743d-9e50-4883-b849-4ba78c892bd7"],
Cell[1353648, 46022, 433, 17, 30, "Output", "ExpressionUUID" -> \
"2c10be6e-1004-4319-ae15-dc520076ecca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1354118, 46044, 499, 15, 29, "Input", "ExpressionUUID" -> \
"612beb4f-1afa-4de6-bfb2-a5f88b00a581"],
Cell[1354620, 46061, 417, 17, 30, "Output", "ExpressionUUID" -> \
"c69be5cc-1563-4448-803c-5c8dc8c88510"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1355074, 46083, 79, 0, 71, "Section", "ExpressionUUID" -> \
"23407dd1-953a-419c-952b-0e9b7142e493"],
Cell[CellGroupData[{
Cell[1355178, 46087, 421, 9, 29, "Input", "ExpressionUUID" -> \
"9c5c7e4a-f76e-4e59-85d8-ff554f277703"],
Cell[1355602, 46098, 405, 10, 23, "Print", "ExpressionUUID" -> \
"4ca7d217-896f-42e4-bbb3-9faf52ce109b"],
Cell[1356010, 46110, 560, 15, 23, "Print", "ExpressionUUID" -> \
"4c4afb14-e17e-4f57-8d9c-160dd97f295b"],
Cell[1356573, 46127, 48003, 1656, 804, "Output", "ExpressionUUID" -> \
"010ccd07-dfd2-48f2-b846-329662fd1881"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1404613, 47788, 520, 10, 29, "Input", "ExpressionUUID" -> \
"4dbb660e-7225-4ffe-bbad-b1274c0d9b3b"],
Cell[1405136, 47800, 436, 11, 23, "Print", "ExpressionUUID" -> \
"477d1e2d-aaa0-4436-801c-fe75fbcc8132"],
Cell[1405575, 47813, 591, 16, 23, "Print", "ExpressionUUID" -> \
"5f130c4c-79dc-4fff-8e5c-edcdad62f46b"],
Cell[1406169, 47831, 50568, 1737, 802, "Output", "ExpressionUUID" -> \
"8d37c469-dc30-4095-b60e-7357f077f8d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1456774, 49573, 522, 10, 29, "Input", "ExpressionUUID" -> \
"cd6af121-8253-4417-babf-095a4ac5eb55"],
Cell[1457299, 49585, 422, 10, 23, "Print", "ExpressionUUID" -> \
"375c51a3-6384-493b-bfc9-04ab8bf275b5"],
Cell[1457724, 49597, 575, 15, 23, "Print", "ExpressionUUID" -> \
"674d616f-8cab-46a5-b534-e5ad0f2076cd"],
Cell[1458302, 49614, 48732, 1673, 836, "Output", "ExpressionUUID" -> \
"68629fac-513f-440f-bc0e-dcd78b08f12d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1507071, 51292, 421, 9, 29, "Input", "ExpressionUUID" -> \
"9441210d-7e4e-4338-bd03-59b54dec59d2"],
Cell[1507495, 51303, 399, 10, 23, "Print", "ExpressionUUID" -> \
"f7da22ac-3481-4165-b406-fdfd4b31d3a8"],
Cell[1507897, 51315, 557, 15, 23, "Print", "ExpressionUUID" -> \
"884db197-3a62-4783-a942-95574856706a"],
Cell[1508457, 51332, 54185, 1872, 964, "Output", "ExpressionUUID" -> \
"c79d2fee-b29d-4b36-bfc4-fa30f2ab7b50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1562679, 53209, 374, 8, 29, "Input", "ExpressionUUID" -> \
"7c0d839c-3787-45b2-b693-95c637d136d0"],
Cell[1563056, 53219, 384, 10, 23, "Print", "ExpressionUUID" -> \
"978317a7-dea9-4e09-ae09-32de7d545686"],
Cell[1563443, 53231, 537, 15, 23, "Print", "ExpressionUUID" -> \
"12c6141a-45ad-47b4-a8e6-14606e5e8fd9"],
Cell[1563983, 53248, 25157, 863, 478, "Output", "ExpressionUUID" -> \
"17df4b74-b9c0-4db6-adae-0319e89f4218"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1589177, 54116, 401, 9, 29, "Input", "ExpressionUUID" -> \
"3e625eb4-bf46-4b59-92dc-e5b7d67d9b3f"],
Cell[1589581, 54127, 404, 10, 23, "Print", "ExpressionUUID" -> \
"d38e4574-eb01-4de9-8484-a9a26d693f32"],
Cell[1589988, 54139, 563, 15, 23, "Print", "ExpressionUUID" -> \
"30e7cbe3-1d49-4e4b-a0a4-c268ef1a3524"],
Cell[1590554, 54156, 14358, 490, 292, "Output", "ExpressionUUID" -> \
"57e67673-1e15-4b84-ba43-676cdcb1c76f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1604961, 54652, 474, 9, 29, "Input", "ExpressionUUID" -> \
"8927ce9d-c34e-4489-9383-e960e2677230"],
Cell[1605438, 54663, 399, 10, 23, "Print", "ExpressionUUID" -> \
"12e3580a-5617-48e8-927f-f6ee0358e860"],
Cell[1605840, 54675, 559, 15, 23, "Print", "ExpressionUUID" -> \
"b30cfed1-a450-4d7e-9115-e57eb6e90fcf"],
Cell[1606402, 54692, 23432, 799, 416, "Output", "ExpressionUUID" -> \
"92a50cce-48a9-4cc0-a74f-92455454ee32"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1629871, 55496, 428, 9, 29, "Input", "ExpressionUUID" -> \
"f6b96560-3667-4a63-afce-7771148f6012"],
Cell[1630302, 55507, 332, 9, 23, "Print", "ExpressionUUID" -> \
"765e647f-86a6-4c7e-a7a4-efc7e611aea9"],
Cell[1630637, 55518, 493, 14, 23, "Print", "ExpressionUUID" -> \
"4b341571-c28b-489e-b159-177dd57a41af"],
Cell[1631133, 55534, 15778, 539, 308, "Output", "ExpressionUUID" -> \
"825896e4-42f3-4cba-b76c-fee477483c33"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1646948, 56078, 373, 8, 29, "Input", "ExpressionUUID" -> \
"9573d445-11aa-47c4-b17d-59426f3717bf"],
Cell[1647324, 56088, 326, 8, 23, "Print", "ExpressionUUID" -> \
"a38e831a-2a55-40c9-b8e9-9912a40c6112"],
Cell[1647653, 56098, 490, 14, 23, "Print", "ExpressionUUID" -> \
"55186422-f2f3-4b4e-8d8a-b20ef38de45b"],
Cell[1648146, 56114, 8425, 284, 190, "Output", "ExpressionUUID" -> \
"97873967-d895-4cbc-9c0d-54cd6c866df8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1656608, 56403, 476, 9, 29, "Input", "ExpressionUUID" -> \
"574b44d4-e184-4a5e-abf1-45c53f426b95"],
Cell[1657087, 56414, 350, 8, 23, "Print", "ExpressionUUID" -> \
"58501b5f-f5b3-45e9-af85-cf2e34346a97"],
Cell[1657440, 56424, 511, 14, 23, "Print", "ExpressionUUID" -> \
"4b77dfca-f3ed-4dd0-a72f-a24bdd99272e"],
Cell[1657954, 56440, 7426, 247, 156, "Output", "ExpressionUUID" -> \
"c4c087c3-426e-4167-8f32-b1c7af3f2bbc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1665417, 56692, 428, 9, 29, "Input", "ExpressionUUID" -> \
"9af409ce-2a0b-446d-bb4b-cc2e076db06f"],
Cell[1665848, 56703, 326, 8, 23, "Print", "ExpressionUUID" -> \
"82a719cb-c65f-43e1-bd4b-3696d4570206"],
Cell[1666177, 56713, 485, 14, 23, "Print", "ExpressionUUID" -> \
"bfb96305-9564-48db-9455-b41eb683669b"],
Cell[1666665, 56729, 7406, 247, 156, "Output", "ExpressionUUID" -> \
"54688d75-cf37-4bcf-ba0b-62d7d5d72027"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1674108, 56981, 398, 8, 29, "Input", "ExpressionUUID" -> \
"3b2e0dd9-10fc-42ff-bfef-889dabb89147"],
Cell[1674509, 56991, 324, 8, 23, "Print", "ExpressionUUID" -> \
"932d5b8c-d9b7-48f6-ad91-eb68e76c1d4a"],
Cell[1674836, 57001, 490, 14, 23, "Print", "ExpressionUUID" -> \
"b00be5d1-a4fa-463c-bc12-cc7f3a259fa5"],
Cell[1675329, 57017, 5230, 172, 122, "Output", "ExpressionUUID" -> \
"b030472b-b7bd-4c3c-aa23-552156eab8c0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1680596, 57194, 428, 9, 29, "Input", "ExpressionUUID" -> \
"494f481a-cd28-448d-be87-9842b8761819"],
Cell[1681027, 57205, 324, 8, 23, "Print", "ExpressionUUID" -> \
"6f1d58c2-d4ad-4904-96da-5aee5d6b2373"],
Cell[1681354, 57215, 484, 13, 23, "Print", "ExpressionUUID" -> \
"68fd0ceb-9e43-447a-894d-9e0987e9423a"],
Cell[1681841, 57230, 4221, 137, 104, "Output", "ExpressionUUID" -> \
"baf05d7b-1e34-42ff-8a00-1291a8000a87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1686099, 57372, 608, 11, 29, "Input", "ExpressionUUID" -> \
"c01ff666-4284-4895-be76-78a369eb56b6"],
Cell[1686710, 57385, 348, 8, 23, "Print", "ExpressionUUID" -> \
"9899455c-144e-41d6-8ea8-b4e485653f6f"],
Cell[1687061, 57395, 512, 14, 23, "Print", "ExpressionUUID" -> \
"022a44f5-bf39-4d91-8922-d10d500eed18"],
Cell[1687576, 57411, 3665, 116, 88, "Output", "ExpressionUUID" -> \
"b6984007-6cf1-4f3f-8441-822e5e5a119f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1691278, 57532, 94, 0, 71, "Section", "ExpressionUUID" -> \
"16e2101c-8afa-48c0-8c66-d4c668389ead"],
Cell[CellGroupData[{
Cell[1691397, 57536, 423, 9, 29, "Input", "ExpressionUUID" -> \
"55814a22-57f8-4df0-be4b-e52c474acfbe"],
Cell[1691823, 57547, 456, 11, 23, "Print", "ExpressionUUID" -> \
"ffdebefa-3d07-46c1-8300-7d0e1c03e28e"],
Cell[1692282, 57560, 612, 16, 23, "Print", "ExpressionUUID" -> \
"af31daf8-99e6-4542-8096-ffd5b9647cc7"],
Cell[1692897, 57578, 51577, 1722, 860, "Output", "ExpressionUUID" -> \
"b412934f-d5a1-44e5-b6a4-8782472deefa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1744511, 59305, 473, 9, 29, "Input", "ExpressionUUID" -> \
"cb99b385-9a6a-498d-9f89-a8ebc924caed"],
Cell[1744987, 59316, 432, 11, 23, "Print", "ExpressionUUID" -> \
"853e633d-84dc-4288-8490-f832b8d7f14e"],
Cell[1745422, 59329, 587, 16, 23, "Print", "ExpressionUUID" -> \
"8ed329eb-8599-4816-ae61-6a84d98f1516"],
Cell[1746012, 59347, 28944, 975, 522, "Output", "ExpressionUUID" -> \
"5102c62f-217f-42e0-9cc3-de820907c66c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1774993, 60327, 531, 10, 29, "Input", "ExpressionUUID" -> \
"bbdb212b-e22e-4a80-9d8e-e519fa261bb5"],
Cell[1775527, 60339, 460, 11, 23, "Print", "ExpressionUUID" -> \
"2b3dd1b0-3641-4e7d-b75a-3a6528d6d39e"],
Cell[1775990, 60352, 618, 16, 23, "Print", "ExpressionUUID" -> \
"0269224d-5fcd-47a6-b67c-0055dfc8ead2"],
Cell[1776611, 60370, 17262, 570, 314, "Output", "ExpressionUUID" -> \
"a58c532b-2d0f-48e6-bcba-27c1af25a0f0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1793910, 60945, 375, 8, 29, "Input", "ExpressionUUID" -> \
"0f201873-c4d8-4c67-bc21-a7b60b705817"],
Cell[1794288, 60955, 403, 10, 23, "Print", "ExpressionUUID" -> \
"20284784-7562-4120-aeb9-850f0cbfaa60"],
Cell[1794694, 60967, 556, 15, 23, "Print", "ExpressionUUID" -> \
"b0f672ef-41c2-4fb6-8adc-c953b9409e24"],
Cell[1795253, 60984, 104422, 3466, 1722, "Output", "ExpressionUUID" -> \
"6334d292-21fd-47e4-9d33-33180aa01144"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1899712, 64455, 416, 8, 29, "Input", "ExpressionUUID" -> \
"a300d938-7260-487b-8dbf-be79dbe9c9d9"],
Cell[1900131, 64465, 406, 10, 23, "Print", "ExpressionUUID" -> \
"41e243f0-88e7-4692-a1e0-7be166ccaf39"],
Cell[1900540, 64477, 561, 15, 23, "Print", "ExpressionUUID" -> \
"a1210b9a-3b20-4eb3-a0af-117e19e7f44c"],
Cell[1901104, 64494, 67666, 2266, 908, "Output", "ExpressionUUID" -> \
"5f232356-136e-443b-819d-c03937d5006a"]
}, Open  ]]
}, Open  ]]
}
]
*)

